@@ -18,8 +18,7 @@ real(8), parameter :: eps=1.d-5
 ! allocatable arrays
 real(8), allocatable :: x(:,:)
 ! external functions
-complex(8) zfpole
-external zfpole
+complex(8), external :: zfpole
 n=2*npole+1
 n2=2*n
 allocate(x(n2,n2+1))
@@ -65,6 +64,5 @@ do iw=1,nwplot
   zr(iw)=zfpole(x(:,1),zwr(iw))
 end do
 deallocate(x)
-return
 end subroutine
 
