@@ -19,7 +19,7 @@ if ((abs(fsmtype).eq.1).or.(abs(fsmtype).eq.3)) then
       npc=npcmt(is)
       bsqmt(1:npc,ias,idm,1)=bsqmt(1:npc,ias,idm,1)+t1
     end do
-    bsqir(:,idm,1)=bsqir(:,idm,1)+t1*cfunir(:)
+    bsqir(1:ngtot,idm,1)=bsqir(1:ngtot,idm,1)+t1*cfunir(1:ngtot)
   end do
 end if
 ! add the muffin-tin fields
@@ -33,6 +33,5 @@ if ((abs(fsmtype).eq.2).or.(abs(fsmtype).eq.3)) then
     end do
   end do
 end if
-return
 end subroutine
 
