@@ -199,10 +199,10 @@ real(8) sm
 g(1)=0.d0
 sm=wp(5)*f(1)+wp(6)*f(2)+wp(7)*f(3)+wp(8)*f(4)
 g(2)=sm
-do i=3,n-1
-  j=(i-1)*4+1
-  sm=sm+wp(j)*f(i-2)+wp(j+1)*f(i-1)+wp(j+2)*f(i)+wp(j+3)*f(i+1)
-  g(i)=sm
+do i=2,n-2
+  j=i*4+1
+  sm=sm+wp(j)*f(i-1)+wp(j+1)*f(i)+wp(j+2)*f(i+1)+wp(j+3)*f(i+2)
+  g(i+1)=sm
 end do
 j=(n-1)*4+1
 g(n)=sm+wp(j)*f(n-3)+wp(j+1)*f(n-2)+wp(j+2)*f(n-1)+wp(j+3)*f(n)
