@@ -6,7 +6,7 @@
 !BOP
 ! !ROUTINE: axangrot
 ! !INTERFACE:
-subroutine axangrot(v,th,rot)
+pure subroutine axangrot(v,th,rot)
 ! !INPUT/OUTPUT PARAMETERS:
 !   v   : axis vector (in,real)
 !   th  : rotation angle (in,real)
@@ -52,7 +52,6 @@ rot(3,2)=yz*t1+x*sn
 rot(1,3)=xz*t1+y*sn
 rot(2,3)=yz*t1-x*sn
 rot(3,3)=cs+z2*t1
-return
 end subroutine
 !EOC
 
