@@ -28,7 +28,7 @@ implicit none
 ! local variables
 integer ik,ist,ispn,is,ia,ias
 integer lmax,lmmax,l,m,lm,iv,nthd
-real(8) emin,emax,sm
+real(8) emin,emax,sm,t1
 character(256) fname
 ! allocatable arrays
 real(8), allocatable :: evalfv(:,:),e(:,:)
@@ -103,8 +103,8 @@ do ik=1,nkpt
 ! average band character over spin and m for all atoms
     do ias=1,natmtot
 ! generate the diagonal of the density matrix
-      call gendmatk(.true.,.true.,0,lmax,ias,ngk(:,ik),apwalm,evecfv,evecsv, &
-       lmmax,dmat)
+      call gendmatk(.true.,.true.,0,lmax,ias,nstsv,0,ngk(:,ik),apwalm,evecfv, &
+       evecsv,lmmax,dmat)
       do ist=1,nstsv
         if (task.eq.21) then
 ! l character of band
@@ -156,8 +156,9 @@ deallocate(evalfv,evecfv,evecsv)
 if (task.ge.21) deallocate(dmat,apwalm)
 !$OMP END PARALLEL
 call freethd(nthd)
-emax=emax+(emax-emin)*0.5d0
-emin=emin-(emax-emin)*0.5d0
+t1=(emax-emin)*0.5d0
+emin=emin-t1
+emax=emax+t1
 ! output the band structure
 if (task.eq.20) then
   open(50,file='BAND.OUT',form='FORMATTED',action='WRITE')
