@@ -6,6 +6,7 @@
 subroutine chargeu
 use modmain
 use modulr
+use modtest
 implicit none
 ! local variables
 integer ifq,is,ias
@@ -36,5 +37,8 @@ t1=ddot(ngtc,rhoqir(:,1),2,cfrc,1)
 chgir=t1*omega/dble(ngtc)
 ! total calculated charge
 chgcalc=chgmttot+chgir
+! write muffin-tin charges to file
+call writetest(730,'ULR muffin-tin charges',nv=natmtot*nqpt,tol=2.d-5, &
+ rva=chgmtru)
 end subroutine
 
