@@ -28,6 +28,7 @@ integer is,js
 real(8) dmin,t1,t2
 ! automatic arrays
 real(8) rmt0(nspecies)
+if (nspecies.le.0) return
 rmt0(1:nspecies)=rmt(1:nspecies)
 10 continue
 ! find the minimum distance between muffin-tin surfaces
@@ -59,7 +60,7 @@ do is=1,nspecies
   end if
 end do
 ! write to VARIABLES.OUT
-call writevars('rmt',nv=nspecies,rva=rmt)
+if (wrtvars) call writevars('rmt',nv=nspecies,rva=rmt)
 end subroutine
 !EOC
 
