@@ -49,8 +49,8 @@ zvclmt(1:np,iasph)=gzfmt(1:np,ipph)
 tphdyn=.true.
 ! zero the interstitial density
 zrhoir(:)=0.d0
-call zpotcoul(nrmt,nrmti,npmt,npmti,nrmtmax,rlmt,ngridg,igfft,ngvec,gqc,gclgq, &
- ngvec,jlgqrmt,ylmgq,sfacgq,zrhoir,npmtmax,zvclmt,zvclir)
+call zpotcoul(nrmt,nrmti,npmt,nrmtmax,rlmt,ngridg,igfft,ngvec,gqc,gclgq,ngvec, &
+ jlgqrmt,ylmgq,sfacgq,zrhoir,npmtmax,zvclmt,zvclir)
 zfmt(1:np)=zvnmt(1:np)
 ! multiply with density derivative and integrate
 z1=0.d0
@@ -66,8 +66,8 @@ dyn(ipph,iasph)=-z1
 ! compute the lattice-periodic nuclear Coulomb potential derivative
 zvclmt(:,:)=0.d0
 zvclmt(1:np,iasph)=gzfmt(1:np,ipph)
-call zpotcoul(nrmt,nrmti,npmt,npmti,nrmtmax,rlmt,ngridg,igfft,ngvec,gc,gclg, &
- ngvec,jlgrmt,ylmg,sfacg,zrhoir,npmtmax,zvclmt,zvclir)
+call zpotcoul(nrmt,nrmti,npmt,nrmtmax,rlmt,ngridg,igfft,ngvec,gc,gclg,ngvec, &
+ jlgrmt,ylmg,sfacg,zrhoir,npmtmax,zvclmt,zvclir)
 tphdyn=.false.
 ! multiply with density gradient and integrate
 z1=0.d0
