@@ -9,8 +9,9 @@
 subroutine dielectric
 ! !USES:
 use modmain
-use modtest
+use modmpi
 use modomp
+use modtest
 ! !DESCRIPTION:
 !   Computes the dielectric tensor, optical conductivity and plasma frequency.
 !   The formulae are taken from {\it Physica Scripta} {\bf T109}, 170 (2004).
@@ -27,7 +28,7 @@ implicit none
 ! local variables
 logical tssr
 integer ik,jk,ist,jst
-integer iw,i,j,l,nthd
+integer iw,ioc,i,j,nthd
 real(8) w1,w2,wplas,x
 real(8) ei,ej,eji,t1,t2
 complex(8) eta,z1
@@ -43,10 +44,8 @@ call init1
 ! read Fermi energy from file
 call readfermi
 ! get the eigenvalues and occupancies from file
-do ik=1,nkpt
-  call getevalsv(filext,ik,vkl(:,ik),evalsv(:,ik))
-  call getoccsv(filext,ik,vkl(:,ik),occsv(:,ik))
-end do
+call readevalsv
+call readoccsv
 ! allocate local arrays
 allocate(w(nwplot),sigma(nwplot))
 ! generate energy grid (always non-negative)
@@ -65,9 +64,9 @@ else
   tssr=.false.
 end if
 ! loop over dielectric tensor components
-do l=1,noptcomp
-  i=optcomp(1,l)
-  j=optcomp(2,l)
+do ioc=1,noptcomp
+  i=optcomp(1,ioc)
+  j=optcomp(2,ioc)
   wplas=0.d0
   sigma(:)=0.d0
 ! parallel loop over non-reduced k-points
@@ -80,6 +79,11 @@ do l=1,noptcomp
   allocate(pmat(nstsv,nstsv,3))
 !$OMP DO
   do ik=1,nkptnr
+! distribute among MPI processes
+    if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
+!$OMP CRITICAL(dielectric_)
+    write(*,'("Info(dielectric): ",I6," of ",I6," k-points")') ik,nkptnr
+!$OMP END CRITICAL(dielectric_)
 ! equivalent reduced k-point
     jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
 ! read in the momentum matrix elements
@@ -121,8 +125,16 @@ do l=1,noptcomp
   deallocate(pmat)
 !$OMP END PARALLEL
   call freethd(nthd)
+! multiply response function by prefactor
   z1=zi*wkptnr/omega
   sigma(:)=z1*sigma(:)
+! add response function and plasma frequency from each process and redistribute
+  if (np_mpi.gt.1) then
+    call mpi_allreduce(mpi_in_place,sigma,nwplot,mpi_double_complex,mpi_sum, &
+     mpicom,ierror)
+    call mpi_allreduce(mpi_in_place,wplas,1,mpi_double_precision,mpi_sum, &
+     mpicom,ierror)
+  end if
 ! intraband contribution
   if (intraband) then
     if (i.eq.j) then
@@ -167,17 +179,19 @@ do l=1,noptcomp
   close(50)
 ! end loop over tensor components
 end do
-write(*,*)
-write(*,'("Info(dielectric):")')
-write(*,'(" dielectric tensor written to EPSILON_ij.OUT")')
-write(*,'(" optical conductivity written to SIGMA_ij.OUT")')
-if (intraband) then
-  write(*,'(" plasma frequency written to PLASMA_ij.OUT")')
+if (mp_mpi) then
+  write(*,*)
+  write(*,'("Info(dielectric):")')
+  write(*,'(" dielectric tensor written to EPSILON_ij.OUT")')
+  write(*,'(" optical conductivity written to SIGMA_ij.OUT")')
+  if (intraband) then
+    write(*,'(" plasma frequency written to PLASMA_ij.OUT")')
+  end if
+  write(*,'(" for components")')
+  do ioc=1,noptcomp
+    write(*,'("  i = ",I1,", j = ",I1)') optcomp(1:2,ioc)
+  end do
 end if
-write(*,'(" for components")')
-do l=1,noptcomp
-  write(*,'("  i = ",I1,", j = ",I1)') optcomp(1:2,l)
-end do
 ! write sigma to test file if required
 call writetest(121,'optical conductivity',nv=nwplot,tol=1.d-2,zva=sigma)
 deallocate(w,sigma)
