@@ -10,7 +10,7 @@ implicit none
 ! local variables
 integer a1,a2,ik1,jk1
 integer i1,j1,ist1,jst1
-integer iw,i,j,l
+integer iw,ioc,i,j
 integer ios,nmbse_
 real(8) e,eji,t1,t2
 complex(8) eta,zv(3),z1
@@ -98,9 +98,9 @@ end do
 z1=zi*occmax*wkptnr/omega
 sigma(:,:,:)=z1*sigma(:,:,:)
 ! loop over tensor components
-do l=1,noptcomp
-  i=optcomp(1,l)
-  j=optcomp(2,l)
+do ioc=1,noptcomp
+  i=optcomp(1,ioc)
+  j=optcomp(2,ioc)
   t1=0.d0
   if (i.eq.j) t1=1.d0
   write(fname,'("EPSILON_BSE_",2I1,".OUT")') i,j
@@ -120,8 +120,8 @@ write(*,*)
 write(*,'("Info(dielectric_bse):")')
 write(*,'(" dielectric tensor written to EPSILON_BSE_ij.OUT")')
 write(*,'(" for components")')
-do l=1,noptcomp
-  write(*,'("  i = ",I1,", j = ",I1)') optcomp(1:2,l)
+do ioc=1,noptcomp
+  write(*,'("  i = ",I1,", j = ",I1)') optcomp(1:2,ioc)
 end do
 ! write sigma to test file
 call writetest(187,'BSE optical conductivity',nv=nwplot,tol=1.d-3,zva=sigma)
