@@ -8,8 +8,7 @@ use modmain
 use modtddft
 implicit none
 ! local variables
-integer nts,its0,its
-integer iw,i,j
+integer its,iw,i,j
 real(8) w1,w2,a0,t0,t1,t2
 complex(8) eta,z1,z2
 character(256) fname
@@ -30,18 +29,9 @@ do iw=1,nwplot
 end do
 ! i divided by the complex relaxation time
 eta=cmplx(0.d0,swidth,8)
-! find the starting time step for the Fourier transform
-its0=1
-do its=2,ntimes
-  if (times(its).gt.t0tdlr) then
-    its0=its-1
-    exit
-  end if
-end do
-nts=ntimes-its0+1
 ! determine the weights for the spline integration
 allocate(wt(ntimes))
-call wsplint(nts,times(its0),wt(its0))
+call wsplint(ntimes,times,wt)
 ! compute the electric field from E = -1/c dA/dt and Fourier transform
 allocate(f1(ntimes),f2(ntimes),g(ntimes))
 allocate(ew(nwplot,3))
@@ -54,14 +44,14 @@ do i=1,3
   if (task.eq.480) then
 ! Fourier transform E(t) numerically
     do iw=1,nwplot
-      do its=its0,ntimes
+      do its=1,ntimes
         t1=g(its)
         t2=w(iw)*times(its)
         f1(its)=t1*cos(t2)
         f2(its)=t1*sin(t2)
       end do
-      t1=dot_product(wt(its0:ntimes),f1(its0:ntimes))
-      t2=dot_product(wt(its0:ntimes),f2(its0:ntimes))
+      t1=dot_product(wt(:),f1(:))
+      t2=dot_product(wt(:),f2(:))
       ew(iw,i)=t0*cmplx(t1+a0,t2,8)
     end do
   else
@@ -75,25 +65,23 @@ allocate(jt(3,ntimes))
 call readjtot(jt)
 ! divide by the unit cell volume
 jt(:,:)=jt(:,:)/omega
-! filter the high-frequency components from the current using an exponentially
-! decaying function
-do its=its0,ntimes
-  t1=times(its)-t0tdlr
-  t1=exp(-swidth*t1)
+! filter the high-frequency components from the current
+do its=1,ntimes
+  t1=exp(-swidth*times(its))
   jt(:,its)=t1*jt(:,its)
 end do
 ! Fourier transform the current
 allocate(jw(nwplot,3))
 do i=1,3
   do iw=1,nwplot
-    do its=its0,ntimes
+    do its=1,ntimes
       t1=jt(i,its)
       t2=w(iw)*times(its)
       f1(its)=t1*cos(t2)
       f2(its)=t1*sin(t2)
     end do
-    t1=dot_product(wt(its0:ntimes),f1(its0:ntimes))
-    t2=dot_product(wt(its0:ntimes),f2(its0:ntimes))
+    t1=dot_product(wt(:),f1(:))
+    t2=dot_product(wt(:),f2(:))
     jw(iw,i)=cmplx(t1,t2,8)
   end do
 end do
