@@ -3,7 +3,7 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine dmatch(ias,ip,ngp,vgpc,apwalm,dapwalm)
+pure subroutine dmatch(ias,ip,ngp,vgpc,apwalm,dapwalm)
 use modmain
 implicit none
 ! arguments
@@ -12,14 +12,12 @@ real(8), intent(in) :: vgpc(3,ngkmax)
 complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot)
 complex(8), intent(out) :: dapwalm(ngkmax,apwordmax,lmmaxapw)
 ! local variables
-integer is,l,m,lm,io,igp
+integer is,l,lm,io,igp
 complex(8) z1
 ! take derivative with respect to atomic displacement
 is=idxis(ias)
-lm=0
 do l=0,lmaxapw
-  do m=-l,l
-    lm=lm+1
+  do lm=l**2+1,(l+1)**2
     do io=1,apword(l,is)
       do igp=1,ngp
         z1=apwalm(igp,io,lm,ias)
@@ -28,6 +26,5 @@ do l=0,lmaxapw
     end do
   end do
 end do
-return
 end subroutine
 
