@@ -3,7 +3,7 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine dolpistl(ngp,ngpq,igpig,igpqig,ld,od)
+pure subroutine dolpistl(ngp,ngpq,igpig,igpqig,ld,od)
 use modmain
 use modphonon
 implicit none
@@ -24,6 +24,5 @@ do j=1,ngp
     od(i,j)=od(i,j)+dcfunig(ivgig(i1,i2,i3))
   end do
 end do
-return
 end subroutine
 
