@@ -53,6 +53,7 @@ real(8) dw,th,sps(2),vl(3),vc(3)
 real(8) v1(3),v2(3),v3(3),t1
 complex(8) su2(2,2),b(2,2),c(2,2)
 character(256) fname
+! allocatable arrays
 ! low precision for band/spin character array saves memory
 real(4), allocatable :: bc(:,:,:,:,:),sc(:,:,:)
 real(8), allocatable :: w(:),e(:,:,:),f(:,:),g(:)
@@ -144,9 +145,9 @@ do ik=1,nkptnr
   do is=1,nspecies
     do ia=1,natoms(is)
       ias=idxas(ia,is)
-! generate the density matrix
-      call gendmatk(.false.,.false.,0,lmaxdos,ias,ngk(:,ik),apwalm,evecfv, &
-       evecsv,lmmax,dmat)
+! generate the density matrix for all states
+      call gendmatk(.false.,.false.,0,lmaxdos,ias,nstsv,0,ngk(:,ik),apwalm, &
+       evecfv,evecsv,lmmax,dmat)
 ! convert (l,m) part to an irreducible representation if required
       if (lmirep) then
         do ist=1,nstsv
