@@ -9,7 +9,7 @@ use modphonon
 implicit none
 ! arguments
 complex(8), intent(in) :: ev(nbph,nbph)
-complex(8), intent(in) :: a(nbph,nbph)
+complex(8), intent(inout) :: a(nbph,nbph)
 real(8), intent(out) :: w(nbph)
 ! local variables
 integer i,j,k
