@@ -17,8 +17,7 @@ real(8) v1(3),v2(3)
 real(8) w(3),work(9)
 ! allocatable arrays
 integer, allocatable :: ipiv(:)
-real(8), allocatable :: a(:,:),b(:,:,:,:),c(:,:,:)
-real(8), allocatable :: evalfv(:,:)
+real(8), allocatable :: a(:,:),b(:,:,:,:),c(:,:,:),evalfv(:,:)
 complex(8), allocatable :: evecfv(:,:,:),evecsv(:,:)
 ! initialise universal variables
 call init0
@@ -175,6 +174,5 @@ write(*,'("  for k-point (lattice) ",3G18.10)') vklem
 ! write the effective mass eigenvalues of the last state to test file
 call writetest(25,'effective mass',nv=3,tol=1.d-6,rva=w)
 deallocate(ipiv,a,b,c)
-return
 end subroutine
 
