@@ -36,7 +36,7 @@ use modmain
 implicit none
 ! local variables
 integer ik,is,ias
-integer nr,nri,ir
+integer nr,nri,ir,npc
 integer ig,ifg,i
 real(8) r,t1,t2
 complex(8) z1
@@ -45,7 +45,6 @@ real(8), allocatable :: gwf2mt(:,:),gwf2ir(:)
 real(8), allocatable :: rfmt1(:),rfmt2(:),grfir(:)
 real(8), allocatable :: grfmt1(:,:),grfmt2(:,:)
 real(8), allocatable :: elfmt(:,:),elfir(:)
-complex(8), allocatable :: evecfv(:,:),evecsv(:,:)
 complex(8), allocatable :: zfft1(:),zfft2(:)
 ! initialise universal variables
 call init0
@@ -55,7 +54,6 @@ allocate(gwf2mt(npmtmax,natmtot),gwf2ir(ngtot))
 allocate(rfmt1(npmtmax),rfmt2(npmtmax),grfir(ngtot))
 allocate(grfmt1(npmtmax,3),grfmt2(npmtmax,3))
 allocate(elfmt(npmtmax,natmtot),elfir(ngtot))
-allocate(evecfv(nmatmax,nstfv),evecsv(nstsv,nstsv))
 allocate(zfft1(ngtot),zfft2(ngtot))
 ! read density and potentials from file
 call readstate
@@ -69,17 +67,35 @@ call linengy
 call genapwfr
 ! generate the local-orbital radial functions
 call genlofr
-! set the gradient squared to zero
+! get the occupancies from file
+call readoccsv
+! set the wavefunction gradient squared to zero
 gwf2mt(:,:)=0.d0
 gwf2ir(:)=0.d0
 do ik=1,nkpt
-! get the eigenvectors and occupancies from file
-  call getoccsv(filext,ik,vkl(:,ik),occsv(:,ik))
-  call getevecfv(filext,ik,vkl(:,ik),vgkl(:,:,:,ik),evecfv)
-  call getevecsv(filext,ik,vkl(:,ik),evecsv)
-! add the valence wavefunction gradient squared
-  call gradwf2(ik,evecfv,evecsv,gwf2mt,gwf2ir)
+! add to the valence wavefunction gradient squared
+  call gradwf2(ik,gwf2mt,gwf2ir)
 end do
+! convert muffin-tin gradient squared to spherical harmonics
+do ias=1,natmtot
+  is=idxis(ias)
+  npc=npcmt(is)
+  rfmt1(1:npc)=gwf2mt(1:npc,ias)
+  call rfsht(nrcmt(is),nrcmti(is),rfmt1,gwf2mt(:,ias))
+end do
+! symmetrise the wavefunction gradient squared
+call symrf(nrcmt,nrcmti,npcmt,ngdgc,ngtc,ngvc,igfc,npmtmax,gwf2mt,gwf2ir)
+! convert back to spherical coordinates
+do ias=1,natmtot
+  is=idxis(ias)
+  npc=npcmt(is)
+  rfmt1(1:npc)=gwf2mt(1:npc,ias)
+  call rbsht(nrcmt(is),nrcmti(is),rfmt1,gwf2mt(:,ias))
+end do
+! convert from coarse to fine muffin-tin radial mesh
+call rfmtctof(gwf2mt)
+! convert from coarse to fine interstitial grid
+call rfirctof(gwf2ir,gwf2ir)
 ! add core wavefunction gradient squared
 call gradwfcr2(gwf2mt)
 !------------------------!
@@ -142,8 +158,6 @@ do ir=1,ngtot
 ! ELF function
   elfir(ir)=1.d0/(1.d0+(t1/t2)**2)
 end do
-! symmetrise the ELF
-call symrf(nrmt,nrmti,npmt,ngridg,ngtot,ngvec,igfft,npmtmax,elfmt,elfir)
 ! plot the ELF to file
 select case(task)
 case(51)
@@ -171,7 +185,7 @@ case(53)
 end select
 deallocate(gwf2mt,gwf2ir,rfmt1,rfmt2,grfir)
 deallocate(grfmt1,grfmt2,elfmt,elfir)
-deallocate(evecfv,evecsv,zfft1,zfft2)
+deallocate(zfft1,zfft2)
 end subroutine
 !EOC
 
