@@ -35,7 +35,7 @@ real(8), parameter :: eps=1.d-12
 real(8), parameter :: beta=0.5d0
 real(8) lambda,wlog,wrms,tc
 real(8) wfmax,tmin,tmax,dtemp,temp
-real(8) dw,dmu,sum,a,b,t0,t1
+real(8) dw,dmu,sm,a,b,t0,t1
 ! allocatable arrays
 real(8), allocatable :: w(:),a2f(:),wf(:),l(:)
 real(8), allocatable :: d0(:),d(:),z0(:),z(:),r(:)
@@ -117,21 +117,19 @@ do itemp=1,ntemp
     wf(m)=t0*dble(2*m+1)
   end do
 ! compute lambda
-  call holdthd(2*nwf+1,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(t1,sum,i) &
+  call holdthd(4*nwf+1,nthd)
+!$OMP PARALLEL DO DEFAULT(SHARED) &
+!$OMP PRIVATE(t1,sm,i) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
   do m=-2*nwf,2*nwf
     t1=(t0*dble(2*m))**2
-    sum=0.d0
+    sm=0.d0
     do i=1,nwplot
-      sum=sum+w(i)*a2f(i)/(w(i)**2+t1)
+      sm=sm+w(i)*a2f(i)/(w(i)**2+t1)
     end do
-    l(m)=2.d0*sum*dw
+    l(m)=2.d0*sm*dw
   end do
-!$OMP END DO
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
   call freethd(nthd)
 ! begin iteration loop
   do it=1,maxit
@@ -139,11 +137,11 @@ do itemp=1,ntemp
       r(m)=sqrt((wf(m)**2+d0(m)**2)*z0(m)**2)
     end do
     do n=0,nwf
-      sum=0.d0
+      sm=0.d0
       do m=0,nwf-1
-        sum=sum+(l(n-m)-l(n+m+1))*z0(m)*wf(m)/r(m)
+        sm=sm+(l(n-m)-l(n+m+1))*z0(m)*wf(m)/r(m)
       end do
-      z(n)=t0*sum/wf(n)
+      z(n)=t0*sm/wf(n)
     end do
     z(0:nwf)=z(0:nwf)+1.d0
     z0(0:nwf)=z(0:nwf)
@@ -155,21 +153,21 @@ do itemp=1,ntemp
     dmu=dmu*2.d0
 ! Gap
     do n=0,nwf
-      sum=0.d0
+      sm=0.d0
       do m=0,nwf-1
-        sum=sum+(l(n-m)+l(n+m+1))*d0(m)*z(m)/r(m)
+        sm=sm+(l(n-m)+l(n+m+1))*d0(m)*z(m)/r(m)
       end do
-      d(n)=t0*(sum-dmu)/z(n)
+      d(n)=t0*(sm-dmu)/z(n)
     end do
 ! mix old and new gap functions
     d(0:nwf)=beta*d(0:nwf)+(1.d0-beta)*d0(0:nwf)
-    sum=0.d0
+    sm=0.d0
     do m=0,nwf
-      sum=sum+abs(d0(m)-d(m))
+      sm=sm+abs(d0(m)-d(m))
     end do
-    sum=sum/dble(2*nwf)
+    sm=sm/dble(2*nwf)
     d0(0:nwf)=d(0:nwf)
-    if (sum.le.eps) then
+    if (sm.le.eps) then
       write(62,'("Eliashberg equations converged in ",I6," iterations")') it
       goto 10
     end if
@@ -230,7 +228,6 @@ write(*,'(" Z function on the real axis written to ELIASHBERG_Z_RA.OUT")')
 deallocate(w,a2f,wf,l)
 deallocate(d0,d,z0,z,r)
 deallocate(zin,uin,zout,uout)
-return
 end subroutine
 !EOC
 
