@@ -13,7 +13,6 @@ use modramdisk
 implicit none
 ! local variables
 logical exist
-integer itask
 ! initialise MPI execution environment
 call mpi_init(ierror)
 ! duplicate mpi_comm_world
@@ -48,13 +47,7 @@ if (mp_mpi) then
   write(*,'("Maximum OpenMP nesting level : ",I4)') maxlvl
   write(*,'("Number of OpenMP threads at first nesting level : ",I4)') maxthd1
   write(*,'("Number of MKL threads : ",I4)') maxthdmkl
-end if
-! delete the VARIABLES.OUT file
-call delvars
-! write version number to VARIABLES.OUT
-call writevars('version',nv=3,iva=version)
 ! check if Elk is already running in this directory
-if (mp_mpi) then
   inquire(file='RUNNING',exist=exist)
   if (exist) then
     write(*,*)
@@ -65,6 +58,19 @@ if (mp_mpi) then
     open(50,file='RUNNING')
     close(50)
   end if
+  if (batch) then
+    wrtvars=.true.
+    write(*,*)
+    write(*,'("Batch mode enabled")')
+  end if
+  if (wrtvars) then
+! delete the VARIABLES.OUT file
+    call delvars
+! write version number to VARIABLES.OUT
+    call writevars('version',nv=3,iva=version)
+  end if
+else
+  wrtvars=.false.
 end if
 ! initialise the RAM disk if required
 if (ramdisk) then
@@ -72,7 +78,14 @@ if (ramdisk) then
   if (mp_mpi) then
     write(*,*)
     write(*,'("RAM disk enabled")')
+    if (.not.wrtdsk) then
+      write(*,*)
+      write(*,'("Warning(elk): Some direct access files may not be written to &
+       &disk")')
+    end if
   end if
+else
+  wrtdsk=.true.
 end if
 ! perform the tasks
 do itask=1,ntasks
@@ -81,14 +94,16 @@ do itask=1,ntasks
     write(*,*)
     write(*,'("Info(elk): current task : ",I6)') task
   end if
+! increment the batch variables if required
+  if (batch) call batchdv
 ! synchronise MPI processes
   call mpi_barrier(mpicom,ierror)
 ! check if task can be run with MPI
   if (lp_mpi.gt.0) then
-    if (any(task.eq.[0,1,2,3,5,15,16,28,29,61,62,63,110,120,135,136,162,170, &
-     180,185,188,200,201,205,208,240,241,270,271,300,320,330,331,350,351,371, &
-     372,373,440,460,461,462,463,471,478,600,610,620,630,640,700,701,800, &
-     801])) then
+    if (any(task.eq.[0,1,2,3,5,15,16,28,29,61,62,63,110,120,121,125,135,136, &
+     162,170,180,185,188,200,201,205,208,240,241,270,271,300,320,330,331,350, &
+     351,371,372,373,440,460,461,462,463,471,478,600,610,620,630,640,700,701]))&
+     then
       continue
     else
       write(*,'("Info(elk): MPI process ",I6," idle for task ",I6)') lp_mpi,task
@@ -96,7 +111,7 @@ do itask=1,ntasks
     end if
   end if
 ! write task to VARIABLES.OUT
-  call writevars('task',iv=task)
+  if (wrtvars) call writevars('task',iv=task)
   select case(task)
   case(0,1)
     call gndstate
@@ -217,7 +232,7 @@ do itask=1,ntasks
   case(371,372,373)
     call jprplot
   case(400)
-    call writetmdu
+    call writetm
   case(430)
     call writestrain
   case(440)
@@ -229,7 +244,7 @@ do itask=1,ntasks
   case(471)
     call rhosplot
   case(478)
-    call bornectd
+    call bornecdyn
   case(480,481)
     call dielectric_tdrt
   case(500)
@@ -254,9 +269,6 @@ do itask=1,ntasks
     call potuplot
   case(771,772,773)
     call maguplot
-  case(800,801)
-!***********
-
   case default
     write(*,*)
     write(*,'("Error(elk): task not defined : ",I8)') task
@@ -279,7 +291,7 @@ call mpi_finalize(ierror)
 end program
 
 !BOI
-! !TITLE: {\huge{\sc The Elk Code Manual}}\\ \Large{\sc Version 7.2.42}\\ \vskip 20pt \includegraphics[height=1cm]{elk_silhouette.pdf}
+! !TITLE: {\huge{\sc The Elk Code Manual}}\\ \Large{\sc Version 8.4.30}\\ \vskip 20pt \includegraphics[height=1cm]{elk_silhouette.pdf}
 ! !AUTHORS: {\sc J. K. Dewhurst, S. Sharma} \\ {\sc L. Nordstr\"{o}m, F. Cricchio, O. Gr\aa n\"{a}s} \\ {\sc E. K. U. Gross}
 ! !AFFILIATION:
 ! !INTRODUCTION: Introduction
@@ -315,13 +327,14 @@ end program
 !   Livas, Stefaan Cottenier, Yasushi Shinohara, Michael Fechner, Yaroslav
 !   Kvashnin, Tristan M\"uller, Arsenii Gerasimov, Manh Duc Le, Jon Lafuente
 !   Bartolom\'{e}, Ren\'{e} Wirnata, Jagdish Kumar, Andrew Shyichuk, Nisha
-!   Singh, Pietro Bonfa, Ronald Cohen and Alyn James. Special mention of David
-!   Singh's very useful book on the LAPW method\footnote{D. J. Singh,
-!   {\it Planewaves, Pseudopotentials and the LAPW Method} (Kluwer Academic
-!   Publishers, Boston, 1994).} must also be made. Finally we would like to
-!   acknowledge the generous support of Karl-Franzens-Universit\"{a}t Graz, the
-!   EU Marie-Curie Research Training Networks initiative, the Max Born Institute
-!   and the Max Planck Society.
+!   Singh, Pietro Bonfa, Ronald Cohen, Alyn James, Chung-Yu Wang, Leon Kerber,
+!   Yunfan Liang and Xavier Gonze. Special mention of David Singh's very useful
+!   book on the LAPW method\footnote{D. J. Singh, {\it Planewaves,
+!   Pseudopotentials and the LAPW Method} (Kluwer Academic Publishers, Boston,
+!   1994).} must also be made. Finally we would like to acknowledge the generous
+!   support of Karl-Franzens-Universit\"{a}t Graz, the EU Marie-Curie Research
+!   Training Networks initiative, the Max Born Institute and the Max Planck
+!   Society.
 !
 !   \vspace{24pt}
 !   Kay Dewhurst\newline
@@ -332,7 +345,7 @@ end program
 !   Hardy Gross
 !
 !   \vspace{12pt}
-!   Berlin, Halle, Jerusalem and Uppsala, June 2021
+!   Berlin, Halle, Jerusalem and Uppsala, May 2022
 !   \newpage
 !
 !   \section{Units}
@@ -459,9 +472,10 @@ end program
 !   the complete set of LDA and GGA functionals available in Libxc as well as
 !   the potential-only metaGGA's. In order to enable this, first download and
 !   compile Libxc version 5. This should have produced the files {\tt libxc.a}
-!   and {\tt libxcf90.a}. Copy these files to the {\tt elk/src} directory and
-!   then uncomment the lines indicated for Libxc in the file {\tt elk/make.inc}.
-!   Once this is done, run {\tt make clean} followed by {\tt make}. To select a
+!   and {\tt libxcf90.a}. Copy these files and the file {\tt libxcf90.f90} from
+!   the Libxc {\tt src} directory to the {\tt elk/src} directory and then
+!   uncomment the lines indicated for Libxc in the file {\tt elk/make.inc}. Once
+!   this is done, run {\tt make clean} followed by {\tt make}. To select a
 !   particular functional of Libxc, use the block
 !   \begin{verbatim}
 !     xctype
@@ -903,8 +917,7 @@ end program
 !   {\tt ftmtype} & 1 to enable a fixed tensor moment (FTM) calculation,
 !    0 otherwise & integer & 0}
 !   If {\tt ftmtype} is $-1$ then the symmetry corresponding to the tensor
-!   moment is broken but no FTM calculation is performed. See {\it Phys. Rev.
-!   Lett.} {\bf 103}, 107202 (2009) and also {\tt tmomfix}.
+!   moment is broken but no FTM calculation is performed. See also {\tt tm3fix}.
 !
 !   \block{fxclrc}{
 !   {\tt fxclrc} & parameters for the dynamical long-range contribution (LRC) to
@@ -1646,27 +1659,19 @@ end program
 !   this case, a real symmetric (instead of complex Hermitian) eigenvalue solver
 !   can be used. This makes the calculation about three times faster.
 !
-!   \block{tmomfix}{
+!   \block{tm3fix}{
 !   {\tt ntmfix} & number of tensor moments (TM) to be fixed & integer & 0 \\
 !   \hline
 !   {\tt is(i)} & species number for entry $i$ & integer & - \\
 !   {\tt ia(i)} & atom number & integer & - \\
-!   {\tt (l, n)(i)} & $l$ and $n$ indices of TM & integer & - \\
+!   {\tt l(i)} & $l$ of TM & integer & - \\
 !   \hline
-!   {\tt (k, p, x, y)(i)} or & & & \\
-!    {\tt (k, p, r, t)(i)} & indices for the 2-index or 3-index TM,
-!    respectively & integer & - \\
+!   {\tt (k, p, r, t)(i)} & indices for the 3-index TM & integer & - \\
 !   \hline
-!   {\tt z(i)} & complex TM value & complex & - \\
-!   \hline
-!   {\tt p(i)} & parity of spatial rotation & integer & - \\
-!   {\tt aspl(i)} & Euler angles of spatial rotation & real(3) & - \\
-!   {\tt aspn(i)} & Euler angles of spin rotation & real(3) & - }
+!   {\tt wkpr(t)(i)} & real TM value & real & - }
 !   This block sets up the fixed tensor moment (FTM). There should be as many
-!   TM entries as {\tt ntmfix}. See {\it Phys. Rev. Lett.} {\bf 103}, 107202
-!   (2009) for the tensor moment indexing convention. This is a highly
-!   complicated feature of the code, and should only be attempted with a full
-!   understanding of tensor moments.
+!   TM entries as {\tt ntmfix}. See the routine {\tt tm3todm} for the tensor
+!   moment indexing convention.
 !
 !   \block{tmwrite}{
 !   {\tt tmwrite} & set to {\tt .true.} if the tensor moments and the
@@ -1823,8 +1828,8 @@ end program
 !   original mathematics. We would also appreciate the following conventions
 !   being adhered to:
 !   \begin{itemize}
-!   \item Strict Fortran 2003 should be used. Features which are marked as
-!    obsolescent in Fortran 2003 should be avoided. These include assigned
+!   \item Strict Fortran 2008 should be used. Features which are marked as
+!    obsolescent in Fortran 2008 should be avoided. These include assigned
 !    format specifiers, labeled do-loops, computed goto statements and statement
 !    functions.
 !   \item Modules should be used in place of common blocks for declaring
