@@ -53,8 +53,7 @@ end do
 allocate(jlgqr(njcmax,nspecies))
 allocate(ylmgq(lmmaxo),sfacgq(natmtot))
 allocate(expmt(npcmtmax,natmtot))
-ngrf=1
-call gengqrf(vecqc,vgqc,gqc,jlgqr,ylmgq,sfacgq)
+call gengqf(1,vecqc,vgqc,gqc,jlgqr,ylmgq,sfacgq)
 call genexpmt(1,jlgqr,ylmgq,1,sfacgq,expmt)
 deallocate(jlgqr,ylmgq,sfacgq)
 allocate(e(nstsv,nstsv,nkptnr),f(nstsv,nstsv,nkptnr))
@@ -119,6 +118,5 @@ write(*,'(" ELNES double differential cross-section written to ELNES.OUT")')
 ! write ELNES distribution to test file
 call writetest(140,'ELNES cross-section',nv=nwplot,tol=1.d-2,rva=ddcs)
 deallocate(e,f,ddcs,expmt)
-return
 end subroutine
 
