@@ -8,7 +8,6 @@ use modmain
 use modphonon
 use modmpi
 use modomp
-use modstore
 implicit none
 ! local variables
 integer iq,ik,jk,jkq
@@ -26,7 +25,7 @@ complex(8), allocatable :: ephmat(:,:,:)
 ! external functions
 real(8), external :: sdelta
 ! increase the angular momentum cut-off on the inner part of the muffin-tin
-lmaxi_=lmaxi
+lmaxi0=lmaxi
 lmaxi=max(lmaxi,4)
 ! initialise universal variables
 call init0
@@ -60,10 +59,10 @@ call genapwlofr
 call gensocfr
 call genevfsv
 ! precise determination of the Fermi energy
-swidth_=swidth
+swidth0=swidth
 swidth=1.d-5
 call occupy
-swidth=swidth_
+swidth=swidth0
 ! restore the speed of light
 solsc=sol
 ! read in the dynamical matrices
@@ -187,6 +186,6 @@ deallocate(dvsbs)
 deallocate(gq,dynq,ev,a)
 deallocate(dvmt,dvir,zfmt,gzfmt)
 ! restore original input parameters
-lmaxi=lmaxi_
+lmaxi=lmaxi0
 end subroutine
 
