@@ -13,27 +13,27 @@ complex(8), intent(in) :: h(*),o(*)
 real(8), intent(out) :: evalfv(nstfv)
 complex(8), intent(out) :: evecfv(nmatmax,nstfv)
 ! local variables
-integer i,m,nthd
 integer lwork,info
+integer m,i,nthd,nts
 real(8) vl,vu
 real(8) ts0,ts1
+! automatic arrays
+integer iwork(5*nmatp),ifail(nmatp)
 ! allocatable arrays
-integer, allocatable :: iwork(:),ifail(:)
 real(8), allocatable :: w(:),rwork(:)
 complex(8), allocatable :: work(:)
 call timesec(ts0)
-allocate(iwork(5*nmatp),ifail(nmatp))
 allocate(w(nmatp),rwork(7*nmatp))
 lwork=2*nmatp
 allocate(work(lwork))
 ! enable MKL parallelism
 call holdthd(maxthdmkl,nthd)
-call mkl_set_num_threads(nthd)
+nts=mkl_set_num_threads_local(nthd)
 ! diagonalise the matrix
 call zhegvx(1,'V','I','U',nmatp,h,nmatp,o,nmatp,vl,vu,1,nstfv,evaltol,m,w, &
  evecfv,nmatmax,work,lwork,rwork,iwork,ifail,info)
+nts=mkl_set_num_threads_local(0)
 call freethd(nthd)
-call mkl_set_num_threads(1)
 if (info.ne.0) then
   write(*,*)
   write(*,'("Error(eveqnfvz): diagonalisation failed")')
@@ -48,10 +48,9 @@ if (info.ne.0) then
   stop
 end if
 evalfv(1:nstfv)=w(1:nstfv)
-deallocate(iwork,ifail,w,rwork,work)
+deallocate(w,rwork,work)
 call timesec(ts1)
 !$OMP ATOMIC
 timefv=timefv+ts1-ts0
-return
 end subroutine
 
