@@ -13,7 +13,8 @@ real(8), intent(in) :: vmt(npcmtmax,natmtot),vir(ngtot)
 real(8), intent(in) :: bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag)
 complex(8), intent(inout) :: evecsvp(nstsv,nstsv)
 ! local variables
-integer ik,jk,ist1,ist2,ist3
+integer ik,jk,nst
+integer ist1,ist2,ist3,jst3
 integer iv(3),iq,ig,nthd
 real(8) vc(3),t1
 complex(8) z1
@@ -47,12 +48,8 @@ allocate(zrhomt(npcmtmax,natmtot,nstsv),zrhoir(ngtc,nstsv))
 call getevecfv(filext,ikp,vkl(:,ikp),vgkl(:,:,1,ikp),evecfv)
 ! find the matching coefficients
 call match(ngk(1,ikp),vgkc(:,:,1,ikp),gkc(:,1,ikp),sfacgk(:,:,1,ikp),apwalm)
-! index to all states
-do ist1=1,nstsv
-  idx(ist1)=ist1
-end do
 ! calculate the wavefunctions for all states of the input k-point
-call genwfsv(.false.,.true.,nstsv,idx,ngdgc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
+call genwfsv(.false.,.true.,nstsv,0,ngdgc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
  apwalm,evecfv,evecsvp,wfmt1,ngtc,wfir1)
 !-----------------------------------------!
 !     local potential matrix elements     !
@@ -87,7 +84,7 @@ do ik=1,nkptnr
   iv(:)=modulo(iv(:),ngridk(:))
 ! check if the q-point is in user-defined set
   iv(:)=iv(:)*ngridq(:)
-  if (any(modulo(iv(:),ngridk(:)).ne.0)) cycle
+  if (any(mod(iv(:),ngridk(:)).ne.0)) cycle
   iv(:)=iv(:)/ngridk(:)
   iq=ivqiq(iv(1),iv(2),iv(3))
   vc(:)=vkc(:,ikp)-vkc(:,ik)
@@ -110,11 +107,19 @@ do ik=1,nkptnr
 ! get the eigenvectors from file for non-reduced k-point
   call getevecfv(filext,0,vkl(:,ik),vgkl(:,:,1,ik),evecfv)
   call getevecsv(filext,0,vkl(:,ik),evecsv)
-! calculate the wavefunctions for all states
-  call genwfsv(.false.,.false.,nstsv,idx,ngdgc,igfc,ngk(1,ik),igkig(:,1,ik), &
-   apwalm,evecfv,evecsv,wfmt2,ngtc,wfir2)
+! count and index occupied states
+  nst=0
   do ist3=1,nstsv
-    if (abs(occsv(ist3,jk)).lt.epsocc) cycle
+    if (abs(occsv(ist3,jk)).gt.epsocc) then
+      nst=nst+1
+      idx(nst)=ist3
+    end if
+  end do
+! calculate the wavefunctions for occupied states
+  call genwfsv(.false.,.false.,nst,idx,ngdgc,igfc,ngk(1,ik),igkig(:,1,ik), &
+   apwalm,evecfv,evecsv,wfmt2,ngtc,wfir2)
+  do ist3=1,nst
+    jst3=idx(ist3)
 ! calculate the complex overlap densities for all states (T. McQueen)
     call holdthd(nstsv,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
@@ -125,7 +130,7 @@ do ik=1,nkptnr
     end do
 !$OMP END PARALLEL DO
     call freethd(nthd)
-    t1=wqptnr*occsv(ist3,jk)/occmax
+    t1=wqptnr*occsv(jst3,jk)/occmax
     call holdthd(nstsv,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(zvclmt,zvclir) &
@@ -137,9 +142,8 @@ do ik=1,nkptnr
 ! calculate the Coulomb potential
       call genzvclmt(nrcmt,nrcmti,nrcmtmax,rlcmt,wprcmt,npcmtmax, &
        zrhomt(:,:,ist2),zvclmt)
-      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rlcmt,ngdgc,igfc,ngvc, &
-       gqc,gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir(:,ist2),npcmtmax,zvclmt, &
-       zvclir)
+      call zpotcoul(nrcmt,nrcmti,npcmt,nrcmtmax,rlcmt,ngdgc,igfc,ngvc,gqc, &
+       gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir(:,ist2),npcmtmax,zvclmt,zvclir)
       zvclir(:)=zvclir(:)*cfrc(:)
       do ist1=1,ist2
         z1=zfinp(zrhomt(:,:,ist1),zrhoir(:,ist1),zvclmt,zvclir)
