@@ -16,8 +16,8 @@ complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot)
 real(8), intent(out) :: evalfv(nstfv)
 complex(8), intent(out) :: evecfv(nmatmax,nstfv)
 ! local variables
-integer n2,ns,ist,i
-integer is,ias,it,nthd
+integer ns,ist,it,i
+integer is,ias,nthd
 integer lwork,info
 real(8) rmax,t1
 real(8) ts1,ts0
@@ -28,7 +28,6 @@ complex(8), allocatable :: u(:,:),hu(:,:),ou(:,:)
 complex(8), allocatable :: hs(:,:),os(:,:),work(:)
 ! external functions
 complex(8), external :: zdotc
-n2=2*nmatp
 ns=2*nstfv
 if (iscl.ge.2) then
 ! read in the eigenvalues/vectors from file
@@ -98,8 +97,8 @@ do it=1,maxitefv
     t1=dble(zdotc(nmatp,evecfv(:,ist),1,ov(:,ist),1))
     if (t1.gt.0.d0) then
       t1=1.d0/sqrt(t1)
-      call dscal(n2,t1,evecfv(:,ist),1)
-      call dscal(n2,t1,ov(:,ist),1)
+      call zdscal(nmatp,t1,evecfv(:,ist),1)
+      call zdscal(nmatp,t1,ov(:,ist),1)
     end if
 ! operate with H on the current eigenvector
     call zhemv('U',nmatp,zone,h,nmatp,evecfv(:,ist),1,zzero,hv(:,ist),1)
@@ -112,19 +111,19 @@ do it=1,maxitefv
     end if
 ! compute the residual |u> = (H - eO)|v>
     call zcopy(nmatp,hv(:,ist),1,u(:,ist),1)
-    call daxpy(n2,-evalfv(ist),ov(:,ist),1,u(:,ist),1)
+    t1=-evalfv(ist)
+    u(:,ist)=u(:,ist)+t1*ov(:,ist)
 ! apply the overlap matrix to the residual
     call zhemv('U',nmatp,zone,o,nmatp,u(:,ist),1,zzero,ou(:,ist),1)
 ! compute the overlap of the residual with itself
     t1=dble(zdotc(nmatp,u(:,ist),1,ou(:,ist),1))
-!$OMP CRITICAL(eveqnit_)
-    if (t1.gt.rmax) rmax=t1
-!$OMP END CRITICAL(eveqnit_)
+!$OMP ATOMIC
+    rmax=max(rmax,t1)
 ! normalise the residual
     if (t1.gt.0.d0) then
       t1=1.d0/sqrt(t1)
-      call dscal(n2,t1,u(:,ist),1)
-      call dscal(n2,t1,ou(:,ist),1)
+      call zdscal(nmatp,t1,u(:,ist),1)
+      call zdscal(nmatp,t1,ou(:,ist),1)
     end if
 ! apply the Hamiltonian matrix to the residual
     call zhemv('U',nmatp,zone,h,nmatp,u(:,ist),1,zzero,hu(:,ist),1)
