@@ -66,8 +66,8 @@ do ias=1,natmtot
     if (ssdph.and.(ispn.eq.2)) zq=conjg(zq)
 !$OMP DO
     do ist=1,nstfv
-      call wavefmt(lradstp,ias,ngp(ispn),apwalm(:,:,:,ias,ispn), &
-       evecfv(:,ist,ispn),wfmt1(:,ist,ispn))
+      call wfmtfv(ias,ngp(ispn),apwalm(:,:,:,ias,ispn),evecfv(:,ist,ispn), &
+       wfmt1(:,ist,ispn))
 ! de-phase if required
       if (ssdph) wfmt1(1:npc,ist,ispn)=zq*wfmt1(1:npc,ist,ispn)
     end do
@@ -86,7 +86,7 @@ do ias=1,natmtot
     call zfsht(nrc,nrci,wfmt4,wfmt32)
     wfmt4(1:npc)=cmplx(bsmt(1:npc,ias,1),-bsmt(1:npc,ias,2),8)*wfmt2(1:npc,2)
     call zfsht(nrc,nrci,wfmt4,wfmt33)
-! apply muffin-tin potential matrix if required
+! apply muffin-tin DFT+U potential matrix if required
     if (tvmatmt) then
       do l=0,lmaxdm
         if (tvmmt(l,ias)) then
