@@ -21,21 +21,24 @@ complex(8), intent(out) :: evecsv(nstsv,nstsv)
 logical todsb,socz
 integer ld,ist,jst,ispn,is,ias
 integer nrc,nrci,nrco,irco,irc
-integer l,lm,nm,npc,npci,ipco
-integer igp,i,j,k,nthd
+integer l,lm,nm,npc,npc2,npci,ipco
+integer ngp2,igp,i,j,k,nthd
 real(8) a1,a2,a3,t1
 real(8) ts0,ts1
 complex(8) z1
 ! automatic arrays
 complex(8) wfmt2(npcmtmax)
 complex(8) wfmt31(npcmtmax),wfmt32(npcmtmax),wfmt33(npcmtmax)
+complex(8) wfmt4(npcmtmax,3)
 complex(4) wfmt5(npcmtmax)
 complex(8) wfgp1(ngkmax),wfgp2(ngkmax),wfgp3(ngkmax)
 ! allocatable arrays
-complex(8), allocatable :: wfmt1(:,:),wfmt4(:,:)
-complex(4), allocatable :: wfmt6(:,:),gwfmt(:,:,:)
-complex(8), allocatable :: wfir1(:),wfir2(:),gwfgp(:,:)
+complex(8), allocatable :: wfmt1(:,:)
+complex(4), allocatable :: wfmt6(:,:)
+complex(8), allocatable :: wfir1(:),wfir2(:)
 ! external functions
+real(4), external :: sdot
+real(8), external :: ddot
 complex(4), external :: cdotc
 complex(8), external :: zdotc
 ! no calculation of second-variational eigenvectors
@@ -74,15 +77,13 @@ evecsv(:,:)=0.d0
 !     muffin-tin part     !
 !-------------------------!
 allocate(wfmt1(npcmtmax,nstfv),wfmt6(npcmtmax,nstfv))
-if (xcgrad.eq.4) allocate(gwfmt(npcmtmax,3,nstfv))
 call holdthd(nstfv,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(wfmt2,wfmt31,wfmt32,wfmt33,wfmt4,wfmt5) &
 !$OMP PRIVATE(ias,is,nrc,nrci,nrco,irco) &
-!$OMP PRIVATE(npc,npci,ipco,ist,jst,i,j,k) &
-!$OMP PRIVATE(irc,t1,l,nm,lm,z1) &
+!$OMP PRIVATE(npc,npc2,npci,ipco,ist,jst) &
+!$OMP PRIVATE(i,j,k,irc,t1,l,nm,lm,z1) &
 !$OMP NUM_THREADS(nthd)
-allocate(wfmt4(npcmtmax,3))
 ! begin loop over atoms
 do ias=1,natmtot
   is=idxis(ias)
@@ -91,13 +92,14 @@ do ias=1,natmtot
   nrco=nrc-nrci
   irco=nrci+1
   npc=npcmt(is)
+  npc2=npc*2
   npci=npcmti(is)
   ipco=npci+1
 ! compute the first-variational wavefunctions
 !$OMP DO
   do ist=1,nstfv
-    call wavefmt(lradstp,ias,ngp,apwalm(:,:,:,ias),evecfv(:,ist),wfmt1(:,ist))
-! make a single-precision copy of the wavefuntion
+    call wfmtfv(ias,ngp,apwalm(:,:,:,ias),evecfv(:,ist),wfmt1(:,ist))
+! make a single-precision copy of the wavefunction
     wfmt6(1:npc,ist)=wfmt1(1:npc,ist)
   end do
 !$OMP END DO
@@ -152,7 +154,7 @@ do ias=1,natmtot
     else
       wfmt31(1:npc)=0.d0
     end if
-! apply muffin-tin potential matrix if required
+! apply muffin-tin DFT+U potential matrix if required
     if (tvmatmt) then
       do l=0,lmaxdm
         if (tvmmt(l,ias)) then
@@ -198,17 +200,19 @@ do ias=1,natmtot
 ! add to second-variational Hamiltonian matrix
 ! upper diagonal block
     call zcfmtwr(nrc,nrci,wrcmt(:,is),wfmt31,wfmt5)
-    do ist=1,jst
+    do ist=1,jst-1
       evecsv(ist,jst)=evecsv(ist,jst)+cdotc(npc,wfmt6(:,ist),1,wfmt5,1)
     end do
+    evecsv(jst,jst)=evecsv(jst,jst)+sdot(npc2,wfmt6(:,jst),1,wfmt5,1)
     if (spinpol) then
       j=jst+nstfv
 ! lower diagonal block
       call zcfmtwr(nrc,nrci,wrcmt(:,is),wfmt32,wfmt5)
-      do ist=1,jst
+      do ist=1,jst-1
         i=ist+nstfv
         evecsv(i,j)=evecsv(i,j)+cdotc(npc,wfmt6(:,ist),1,wfmt5,1)
       end do
+      evecsv(j,j)=evecsv(j,j)+sdot(npc2,wfmt6(:,jst),1,wfmt5,1)
 ! off-diagonal block
       if (todsb) then
         call zcfmtwr(nrc,nrci,wrcmt(:,is),wfmt33,wfmt5)
@@ -220,52 +224,17 @@ do ias=1,natmtot
 ! end loop over states
   end do
 !$OMP END DO
-! apply meta-GGA non-multiplicative potential if required
-  if (xcgrad.eq.4) then
-!$OMP DO
-    do ist=1,nstfv
-! compute gradient of wavefunction
-      call gradzfmt(nrc,nrci,rlcmt(:,-1,is),wcrcmt(:,:,is),wfmt1(:,ist), &
-       npcmtmax,wfmt4)
-! store in single-precision array
-      gwfmt(1:npc,:,ist)=wfmt4(1:npc,:)
-    end do
-!$OMP END DO
-    do k=1,3
-!$OMP DO
-      do jst=1,nstfv
-        wfmt31(1:npc)=gwfmt(1:npc,k,jst)
-        call zbsht(nrc,nrci,wfmt31,wfmt2)
-        wfmt2(1:npc)=wsmt(1:npc,ias)*wfmt2(1:npc)
-        call zfsht(nrc,nrci,wfmt2,wfmt31)
-        call zcfmtwr(nrc,nrci,wrcmt(:,is),wfmt31,wfmt5)
-        do ist=1,jst
-          z1=cdotc(npc,gwfmt(:,k,ist),1,wfmt5,1)
-          z1=0.5d0*z1
-          evecsv(ist,jst)=evecsv(ist,jst)+z1
-          if (spinpol) then
-            i=ist+nstfv
-            j=jst+nstfv
-            evecsv(i,j)=evecsv(i,j)+z1
-          end if
-        end do
-      end do
-!$OMP END DO
-    end do
-  end if
 ! end loop over atoms
 end do
-deallocate(wfmt4)
 !$OMP END PARALLEL
 call freethd(nthd)
 deallocate(wfmt1,wfmt6)
-if (xcgrad.eq.4) deallocate(gwfmt)
 !---------------------------!
 !     interstitial part     !
 !---------------------------!
-if (spinpol.or.tafield.or.(xcgrad.eq.4)) then
+if (spinpol.or.tafield) then
   if (socz) todsb=.false.
-  if (xcgrad.eq.4) allocate(gwfgp(ngkmax,nstfv))
+  ngp2=ngp*2
   call holdthd(nstfv,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(wfir1,wfir2,wfgp1,wfgp2,wfgp3) &
@@ -276,25 +245,19 @@ if (spinpol.or.tafield.or.(xcgrad.eq.4)) then
 !$OMP DO
   do jst=1,nstfv
     wfir1(:)=0.d0
-    do igp=1,ngp
-      wfir1(igfft(igpig(igp)))=evecfv(igp,jst)
-    end do
+    wfir1(igfft(igpig(1:ngp)))=evecfv(1:ngp,jst)
 ! Fourier transform wavefunction to real-space
     call zfftifc(3,ngridg,1,wfir1)
 ! multiply with magnetic field and transform to G-space
     if (spinpol) then
       wfir2(1:ngtot)=bsir(1:ngtot,ndmag)*wfir1(1:ngtot)
       call zfftifc(3,ngridg,-1,wfir2)
-      do igp=1,ngp
-        wfgp1(igp)=wfir2(igfft(igpig(igp)))
-      end do
+      wfgp1(1:ngp)=wfir2(igfft(igpig(1:ngp)))
       wfgp2(1:ngp)=-wfgp1(1:ngp)
       if (ncmag) then
         wfir2(1:ngtot)=cmplx(bsir(1:ngtot,1),-bsir(1:ngtot,2),8)*wfir1(1:ngtot)
         call zfftifc(3,ngridg,-1,wfir2)
-        do igp=1,ngp
-          wfgp3(igp)=wfir2(igfft(igpig(igp)))
-        end do
+        wfgp3(1:ngp)=wfir2(igfft(igpig(1:ngp)))
       end if
     else
       wfgp1(1:ngp)=0.d0
@@ -317,16 +280,18 @@ if (spinpol.or.tafield.or.(xcgrad.eq.4)) then
     end if
 ! add to second-variational Hamiltonian matrix
 ! upper diagonal block
-    do ist=1,jst
+    do ist=1,jst-1
       evecsv(ist,jst)=evecsv(ist,jst)+zdotc(ngp,evecfv(:,ist),1,wfgp1,1)
     end do
+    evecsv(jst,jst)=evecsv(jst,jst)+ddot(ngp2,evecfv(:,jst),1,wfgp1,1)
     if (spinpol) then
       j=jst+nstfv
 ! lower diagonal block
-      do ist=1,jst
+      do ist=1,jst-1
         i=ist+nstfv
         evecsv(i,j)=evecsv(i,j)+zdotc(ngp,evecfv(:,ist),1,wfgp2,1)
       end do
+      evecsv(j,j)=evecsv(j,j)+ddot(ngp2,evecfv(:,jst),1,wfgp2,1)
 ! off-diagonal block
       if (todsb) then
         do ist=1,nstfv
@@ -337,47 +302,9 @@ if (spinpol.or.tafield.or.(xcgrad.eq.4)) then
 ! end loop over states
   end do
 !$OMP END DO
-! apply meta-GGA non-multiplicative potential if required
-  if (xcgrad.eq.4) then
-    do k=1,3
-! determine the gradient of the wavefunctions
-!$OMP DO
-      do ist=1,nstfv
-        do igp=1,ngp
-          z1=evecfv(igp,ist)
-          gwfgp(igp,ist)=vgpc(k,igp)*cmplx(-aimag(z1),dble(z1),8)
-        end do
-      end do
-!$OMP END DO
-!$OMP DO
-      do jst=1,nstfv
-        wfir1(:)=0.d0
-        do igp=1,ngp
-          wfir1(igfft(igpig(igp)))=gwfgp(igp,jst)
-        end do
-        call zfftifc(3,ngridg,1,wfir1)
-        wfir1(1:ngtot)=wsir(1:ngtot)*wfir1(1:ngtot)
-        call zfftifc(3,ngridg,-1,wfir1)
-        do igp=1,ngp
-          wfgp1(igp)=wfir1(igfft(igpig(igp)))
-        end do
-        do ist=1,jst
-          z1=0.5d0*zdotc(ngp,gwfgp(:,ist),1,wfgp1,1)
-          evecsv(ist,jst)=evecsv(ist,jst)+z1
-          if (spinpol) then
-            i=ist+nstfv
-            j=jst+nstfv
-            evecsv(i,j)=evecsv(i,j)+z1
-          end if
-        end do
-      end do
-!$OMP END DO
-    end do
-  end if
   deallocate(wfir1,wfir2)
 !$OMP END PARALLEL
   call freethd(nthd)
-  if (xcgrad.eq.4) deallocate(gwfgp)
 end if
 ! add the diagonal first-variational part
 i=0
