@@ -3,12 +3,12 @@
 ! E. K. U. Gross. This file is distributed under the terms of the GNU General
 ! Public License. See the file COPYING for license details.
 
-subroutine eveqnuv(n,au,bv,w,vn)
+subroutine eveqnuv(n,au,bv,w)
 implicit none
 ! arguments
 integer, intent(in) :: n
 complex(8), intent(inout) :: au(n,n),bv(n,n)
-real(8), intent(out) :: w(n),vn(n)
+real(8), intent(out) :: w(n)
 ! local variables
 integer n2,i,j
 ! allocatable arrays
@@ -37,8 +37,6 @@ do i=1,n
   w(i)=w2(j)
   call zcopy(n,h(1,j),1,au(1,i),1)
   call zcopy(n,h(n+1,j),1,bv(1,i),1)
-! store the V-norm
-  vn(i)=dot_product(bv(:,i),bv(:,i))
 end do
 deallocate(w2,h)
 end subroutine
