@@ -17,8 +17,7 @@ complex(8) z1
 complex(8), allocatable :: wfcr1(:,:),wfcr2(:,:)
 complex(8), allocatable :: zrhomt(:),zvclmt(:),zfmt(:)
 ! external functions
-complex(8) zfmtinp
-external zfmtinp
+complex(8), external :: zfmtinp
 allocate(wfcr1(npcmtmax,2),wfcr2(npcmtmax,2))
 allocate(zrhomt(npcmtmax),zvclmt(npcmtmax),zfmt(npcmtmax))
 ! zero the exchange energy
@@ -86,13 +85,12 @@ return
 
 contains
 
-subroutine zrho2(n,x1,x2,y1,y2,z)
+pure subroutine zrho2(n,x1,x2,y1,y2,z)
 implicit none
 integer, intent(in) :: n
 complex(8), intent(in) :: x1(n),x2(n),y1(n),y2(n)
 complex(8), intent(out) :: z(n)
 z(:)=conjg(x1(:))*y1(:)+conjg(x2(:))*y2(:)
-return
 end subroutine
 
 end subroutine
