@@ -24,23 +24,14 @@ integer, intent(in) :: n,d
 ! local variables
 integer i
 ! external functions
-real(8) factnm
-external factnm
+real(8), external :: factnm
 if (d.eq.1) then
   factr=factnm(n,1)
   return
 end if
-if (n.lt.0) then
-  write(*,*)
-  write(*,'("Error(factr): n < 0 : ",I8)') n
-  write(*,*)
-  stop
-end if
-if (d.lt.0) then
-  write(*,*)
-  write(*,'("Error(factr): d < 0 : ",I8)') d
-  write(*,*)
-  stop
+if ((n.lt.0).or.(d.lt.0)) then
+  factr=0.d0
+  return
 end if
 if (n.lt.d) then
   factr=dble(n+1)
@@ -56,7 +47,6 @@ else
     factr=factr*dble(i)
   end do
 end if
-return
 end function
 !EOC
 
