@@ -8,13 +8,14 @@ use modmain
 use modomp
 implicit none
 ! local variables
-integer ik,jk,nst,ist
+integer ik,nst,ist
 integer ist0,ist1,jst0,jst1
-integer i1,i2,i3,nf,f,nthd
-real(8) e0,e1,prd
+integer i1,i2,i3,nf,f
+integer np,i,nthd
+real(8) e0,e1,prd,v(3)
 ! allocatable arrays
 integer, allocatable :: idx(:)
-real(8), allocatable :: evalfv(:,:),e(:)
+real(8), allocatable :: evalfv(:,:),e(:),vpc(:,:)
 complex(8), allocatable :: evecfv(:,:,:)
 complex(8), allocatable :: evecsv(:,:)
 ! initialise universal variables
@@ -59,12 +60,19 @@ if (tefvit.and.(.not.spinpol)) then
   do ik=1,nkpt
     e(:)=evalsv(:,ik)
     call sortidx(nstsv,e,idx)
-    do ist=1,nstsv
-      evalsv(ist,ik)=e(idx(ist))
-    end do
+    evalsv(1:nstsv,ik)=e(idx(1:nstsv))
   end do
   deallocate(idx,e)
 end if
+! generate the plotting point grid in Cartesian coordinates (this has the same
+! arrangement as the k-point grid)
+np=np3d(1)*np3d(2)*np3d(3)
+allocate(vpc(3,np))
+call plotpt3d(vpc)
+do i=1,np
+  v(:)=vpc(:,i)
+  call r3mv(bvec,v,vpc(:,i))
+end do
 ! number of files to plot (2 for collinear magnetism, 1 otherwise)
 if (ndmag.eq.1) then
   nf=2
@@ -74,14 +82,14 @@ end if
 do f=1,nf
   if (nf.eq.2) then
     if (f.eq.1) then
-      open(50,file='FERMISURF_UP.OUT',form='FORMATTED')
+      open(50,file='FERMISURF_UP.OUT',form='FORMATTED',action='WRITE')
       jst0=1; jst1=nstfv
     else
-      open(50,file='FERMISURF_DN.OUT',form='FORMATTED')
+      open(50,file='FERMISURF_DN.OUT',form='FORMATTED',action='WRITE')
       jst0=nstfv+1; jst1=2*nstfv
     end if
   else
-    open(50,file='FERMISURF.OUT',form='FORMATTED')
+    open(50,file='FERMISURF.OUT',form='FORMATTED',action='WRITE')
     jst0=1; jst1=nstsv
   end if
 ! find the range of eigenvalues which contribute to the Fermi surface (Lars)
@@ -97,28 +105,27 @@ do f=1,nf
   if (task.eq.100) then
 ! write product of eigenstates minus the Fermi energy
     write(50,'(3I6," : grid size")') np3d(:)
+    i=0
     do i3=0,ngridk(3)-1
       do i2=0,ngridk(2)-1
         do i1=0,ngridk(1)-1
-          ik=ivkiknr(i1,i2,i3)
-          jk=ivkik(i1,i2,i3)
-          prd=1.d0
-          do ist=ist0,ist1
-            prd=prd*(evalsv(ist,jk)-efermi)
-          end do
-          write(50,'(4G18.10)') vkc(:,ik),prd
+          i=i+1
+          ik=ivkik(i1,i2,i3)
+          prd=product(evalsv(ist0:ist1,ik)-efermi)
+          write(50,'(4G18.10)') vpc(:,i),prd
         end do
       end do
     end do
   else
 ! write the eigenvalues minus the Fermi energy separately
     write(50,'(4I6," : grid size, number of states")') np3d(:),nst
+    i=0
     do i3=0,ngridk(3)-1
       do i2=0,ngridk(2)-1
         do i1=0,ngridk(1)-1
-          ik=ivkiknr(i1,i2,i3)
-          jk=ivkik(i1,i2,i3)
-          write(50,'(3G18.10,40F14.8)') vkc(:,ik),evalsv(ist0:ist1,jk)-efermi
+          i=i+1
+          ik=ivkik(i1,i2,i3)
+          write(50,'(3G18.10,40F14.8)') vpc(:,i),evalsv(ist0:ist1,ik)-efermi
         end do
       end do
     end do
@@ -138,6 +145,6 @@ if (task.eq.100) then
 else
   write(*,'(" in terms of separate eigenvalues minus the Fermi energy")')
 end if
-return
+deallocate(vpc)
 end subroutine
 
