@@ -10,14 +10,14 @@ implicit none
 real(8), intent(in) :: vpl(3)
 integer, intent(out) :: isym,ik
 ! local variables
-integer ivp(3),lspl
+integer i1,i2,i3,lspl
 real(8) v1(3),v2(3),t1
 v1(:)=vpl(:)-vkloff(:)/dble(ngridk(:))
-ivp(:)=nint(v1(:)*ngridk(:))
-ivp(:)=modulo(ivp(:),ngridk(:))
-ik=ivkik(ivp(1),ivp(2),ivp(3))
+i1=modulo(nint(v1(1)*ngridk(1)),ngridk(1))
+i2=modulo(nint(v1(2)*ngridk(2)),ngridk(2))
+i3=modulo(nint(v1(3)*ngridk(3)),ngridk(3))
+ik=ivkik(i1,i2,i3)
 v1(:)=vkl(:,ik)
-call r3frac(epslat,v1)
 ! find the symmetry which rotates vkl to vpl
 do isym=1,nsymcrys
   lspl=lsplsymc(isym)
