@@ -10,11 +10,12 @@ implicit none
 real(8), intent(in) :: vpl(3)
 integer, intent(out) :: isym,iq
 ! local variables
-integer ivp(3),lspl
+integer i1,i2,i3,lspl
 real(8) v1(3),v2(3),t1
-ivp(:)=nint(vpl(:)*ngridq(:))
-ivp(:)=modulo(ivp(:),ngridq(:))
-iq=iqmap(ivp(1),ivp(2),ivp(3))
+i1=modulo(nint(vpl(1)*ngridq(1)),ngridq(1))
+i2=modulo(nint(vpl(2)*ngridq(2)),ngridq(2))
+i3=modulo(nint(vpl(3)*ngridq(3)),ngridq(3))
+iq=ivqiq(i1,i2,i3)
 v1(:)=vql(:,iq)
 call r3frac(epslat,v1)
 ! find the symmetry which rotates vql to vpl
