@@ -3,13 +3,12 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine findscq(iq,avec0,nsc,vsc)
+subroutine findscq(iq,nsc,vsc)
 use modmain
 use modphonon
 implicit none
 ! arguments
 integer, intent(in) :: iq
-real(8), intent(in) :: avec0(3,3)
 integer, intent(out) :: nsc
 real(8), intent(out) :: vsc(3,nqptnr)
 ! local variables
