@@ -79,13 +79,12 @@ use modomp
 !BOC
 implicit none
 ! local variables
-integer ik,idm,ispn
-integer is,ias,nr,nri
-integer np,i,j,nthd
-real(8) ca,t1,t2
+integer ik,idm,is,ias
+integer nr,nri,i,j,nthd
+real(8) fav(3),ca,t1,t2
 real(8) ts0,ts1
 ! allocatable arrays
-real(8), allocatable :: rfmt1(:,:),rfmt2(:),grfmt(:,:)
+real(8), allocatable :: rfmt(:,:),grfmt(:,:)
 complex(8), allocatable :: zfmt(:),gzfmt(:,:)
 ! external functions
 real(8), external :: rfmtinp,rfmtint
@@ -158,13 +157,13 @@ do ias=1,natmtot
 end do
 ! integral of Kohn-Sham magnetic field with magnetisation gradient
 if (spinpol) then
-  allocate(rfmt1(npmtmax,natmtot))
+  allocate(rfmt(npmtmax,natmtot))
   do idm=1,ndmag
     do ias=1,natmtot
       is=idxis(ias)
-      call rfsht(nrcmt(is),nrcmti(is),bsmt(:,ias,idm),rfmt1(:,ias))
+      call rfsht(nrcmt(is),nrcmti(is),bsmt(:,ias,idm),rfmt(:,ias))
     end do
-    call rfmtctof(rfmt1)
+    call rfmtctof(rfmt)
     do ias=1,natmtot
       is=idxis(ias)
       nr=nrmt(is)
@@ -172,36 +171,12 @@ if (spinpol) then
       call gradrfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),magmt(:,ias,idm), &
        npmtmax,grfmt)
       do i=1,3
-        t1=rfmtinp(nr,nri,wrmt(:,is),rfmt1(:,ias),grfmt(:,i))
+        t1=rfmtinp(nr,nri,wrmt(:,is),rfmt(:,ias),grfmt(:,i))
         forceibs(i,ias)=forceibs(i,ias)+t1
       end do
     end do
   end do
-  deallocate(rfmt1)
-end if
-! integral of Kohn-Sham meta-GGA potential with kinetic energy density gradient
-if (xcgrad.eq.4) then
-  allocate(rfmt1(npmtmax,natmtot),rfmt2(npmtmax))
-  do ias=1,natmtot
-    is=idxis(ias)
-    call rfsht(nrcmt(is),nrcmti(is),wsmt(:,ias),rfmt1(:,ias))
-  end do
-  call rfmtctof(rfmt1)
-  do ispn=1,nspinor
-    do ias=1,natmtot
-      is=idxis(ias)
-      nr=nrmt(is)
-      nri=nrmti(is)
-      np=npmt(is)
-      rfmt2(1:np)=taumt(1:np,ias,ispn)-taucr(1:np,ias,ispn)
-      call gradrfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),rfmt2,npmtmax,grfmt)
-      do i=1,3
-        t1=rfmtinp(nr,nri,wrmt(:,is),rfmt1(:,ias),grfmt(:,i))
-        forceibs(i,ias)=forceibs(i,ias)+t1
-      end do
-    end do
-  end do
-  deallocate(rfmt1,rfmt2)
+  deallocate(rfmt)
 end if
 ! time-dependent vector potential times integral of the gradient of the current
 ! density over the muffin-tin
@@ -229,18 +204,15 @@ do ias=1,natmtot
 end do
 ! symmetrise total forces
 call symveca(forcetot)
-! compute the average force
-do i=1,3
-  forceav(i)=0.d0
-  do ias=1,natmtot
-    forceav(i)=forceav(i)+forcetot(i,ias)
-  end do
-  forceav(i)=forceav(i)/dble(natmtot)
-end do
 ! remove the average force, if required, to prevent translation of atomic basis
 if (tfav0) then
+  fav(:)=0.d0
   do ias=1,natmtot
-    forcetot(:,ias)=forcetot(:,ias)-forceav(:)
+    fav(:)=fav(:)+forcetot(:,ias)
+  end do
+  fav(:)=fav(:)/dble(natmtot)
+  do ias=1,natmtot
+    forcetot(:,ias)=forcetot(:,ias)-fav(:)
   end do
 end if
 ! zero force on atoms with negative mass
