@@ -32,10 +32,10 @@ implicit none
 ! local variables
 integer its,i
 real(8) a0(3),t0,d,w,phi,rc
-real(8) gs,ppd,s,t,t1,t2,t3
+real(8) ft,ppd,s,t,t1,t2,t3,t4
 ! conversion factor of power density to W/cm^2
 real(8), parameter :: cpd=ha_si/(t_si*(100.d0*br_si)**2)
-! generate the time-step grid
+! generate the time step grid
 call gentimes
 open(50,file='TD_INFO.OUT',form='FORMATTED')
 write(50,*)
@@ -88,16 +88,16 @@ do i=1,npulse
   t1=a0(1)**2+a0(2)**2+a0(3)**2
   ppd=t1*(w**2)/(8.d0*pi*solsc)
   write(50,'(" peak laser power density : ",G18.10)') ppd
-  write(50,'("  in W/cm^2               : ",G18.10)') ppd*cpd
+  write(50,'("  in W/cm²                : ",G18.10)') ppd*cpd
 ! loop over time steps
   do its=1,ntimes
     t=times(its)
     t1=t-t0
     t2=-0.5d0*(t1/s)**2
     t3=w*t1+phi*pi/180.d0+0.5d0*rc*t**2
-    gs=exp(t2)*sin(t3)
-    if (abs(gs).lt.1.d-20) gs=0.d0
-    afieldt(:,its)=afieldt(:,its)+a0(:)*gs
+    ft=exp(t2)*sin(t3)
+    if (abs(ft).lt.1.d-20) ft=0.d0
+    afieldt(:,its)=afieldt(:,its)+a0(:)*ft
   end do
 end do
 ! loop over ramps
@@ -110,17 +110,22 @@ do i=1,nramp
   t1=ramp(5,i)
 ! quadratic coefficient
   t2=ramp(6,i)
+! cubic coefficient
+  t3=ramp(7,i)
+! quartic coefficient
+  t4=ramp(8,i)
 ! write information to TD_INFO.OUT
   write(50,*)
   write(50,'("Ramp : ",I6)') i
   write(50,'(" vector amplitude : ",3G18.10)') a0(:)
   write(50,'(" ramp start time : ",G18.10)') t0
+  write(50,'(" coefficients : ",4G18.10)') t1,t2,t3,t4
 ! loop over time steps
   do its=1,ntimes
-    t=times(its)
-    if (t.gt.t0) then
-      t3=t1*(t-t0)+t2*(t-t0)**2
-      afieldt(:,its)=afieldt(:,its)+a0(:)*t3
+    t=times(its)-t0
+    if (t.gt.0.d0) then
+      ft=t*(t1+t*(t2+t*(t3+t*t4)))
+      afieldt(:,its)=afieldt(:,its)+a0(:)*ft
     end if
   end do
 end do
@@ -141,7 +146,6 @@ write(*,'(" 1 atomic unit of time is ",G18.10," attoseconds")') t_si*1.d18
 write(*,'(" Total simulation time : ",G18.10)') tstime
 write(*,'("  in attoseconds       : ",G18.10)') tstime*t_si*1.d18
 deallocate(times,afieldt)
-return
 end subroutine
 !EOC
 
