@@ -28,8 +28,8 @@ use modmain
 implicit none
 ! local variables
 integer is,ia,ja,ias,jas
-integer nr,nri,ir,i
-integer nn,l,io,jo
+integer nr,nri,iro,ir
+integer i0,i1,nn,l,io,jo
 real(8) e,t1
 ! automatic arrays
 logical done(natmmax)
@@ -41,20 +41,17 @@ real(8), external :: splint
 do is=1,nspecies
   nr=nrmt(is)
   nri=nrmti(is)
+  iro=nri+1
   done(:)=.false.
   do ia=1,natoms(is)
     if (done(ia)) cycle
     ias=idxas(ia,is)
 ! use spherical part of potential
-    i=1
-    do ir=1,nri
-      vr(ir)=vsmt(i,ias)*y00
-      i=i+lmmaxi
-    end do
-    do ir=nri+1,nr
-      vr(ir)=vsmt(i,ias)*y00
-      i=i+lmmaxo
-    end do
+    i1=lmmaxi*(nri-1)+1
+    vr(1:nri)=vsmt(1:i1:lmmaxi,ias)*y00
+    i0=i1+lmmaxi
+    i1=lmmaxo*(nr-iro)+i0
+    vr(iro:nr)=vsmt(i0:i1:lmmaxo,ias)*y00
     do l=0,lmaxapw
       do io=1,apword(l,is)
 ! linearisation energy accounting for energy derivative
@@ -67,16 +64,16 @@ do is=1,nspecies
         fr(1:nr)=p0(1:nr,io)**2
         t1=splint(nr,rlmt(:,1,is),fr)
         t1=1.d0/sqrt(abs(t1))
-        call dscal(nr,t1,p0(:,io),1)
+        p0(1:nr,io)=t1*p0(1:nr,io)
         p1s(io)=t1*p1(nr)
-        call dscal(nr,t1,ep0(:,io),1)
+        ep0(1:nr,io)=t1*ep0(1:nr,io)
 ! subtract linear combination of previous vectors
         do jo=1,io-1
           fr(1:nr)=p0(1:nr,io)*p0(1:nr,jo)
           t1=-splint(nr,rlmt(:,1,is),fr)
-          call daxpy(nr,t1,p0(:,jo),1,p0(:,io),1)
+          p0(1:nr,io)=p0(1:nr,io)+t1*p0(1:nr,jo)
           p1s(io)=p1s(io)+t1*p1s(jo)
-          call daxpy(nr,t1,ep0(:,jo),1,ep0(:,io),1)
+          ep0(1:nr,io)=ep0(1:nr,io)+t1*ep0(1:nr,jo)
         end do
 ! normalise radial functions again
         fr(1:nr)=p0(1:nr,io)**2
@@ -93,9 +90,9 @@ do is=1,nspecies
           stop
         end if
         t1=1.d0/sqrt(t1)
-        call dscal(nr,t1,p0(:,io),1)
+        p0(1:nr,io)=t1*p0(1:nr,io)
         p1s(io)=t1*p1s(io)
-        call dscal(nr,t1,ep0(:,io),1)
+        ep0(1:nr,io)=t1*ep0(1:nr,io)
 ! divide by r and store in global array
         do ir=1,nr
           t1=rlmt(ir,-1,is)
@@ -113,8 +110,7 @@ do is=1,nspecies
         jas=idxas(ja,is)
         do l=0,lmaxapw
           do io=1,apword(l,is)
-            call dcopy(nr,apwfr(:,1,io,l,ias),1,apwfr(:,1,io,l,jas),1)
-            call dcopy(nr,apwfr(:,2,io,l,ias),1,apwfr(:,2,io,l,jas),1)
+            apwfr(1:nr,1:2,io,l,jas)=apwfr(1:nr,1:2,io,l,ias)
             apwdfr(io,l,jas)=apwdfr(io,l,ias)
           end do
         end do
