@@ -13,9 +13,12 @@ logical, intent(in) :: tspndg,tlmdg
 integer, intent(in) :: lmin,lmax,ld
 complex(8), intent(out) :: dmat(ld,nspinor,ld,nspinor,natmtot)
 ! local variables
-integer ik,ispn,ist
+integer ik,ispn
+integer nst,ist,jst
 integer ias,n,nthd
 real(8) wo
+! automatic arrays
+integer idx(nstsv)
 ! allocatable arrays
 complex(8), allocatable :: apwalm(:,:,:,:,:),evecfv(:,:,:),evecsv(:,:)
 complex(8), allocatable :: dmatk(:,:,:,:,:)
@@ -24,8 +27,8 @@ dmat(:,:,:,:,:)=0.d0
 ! begin parallel loop over k-points
 call holdthd(nkpt/np_mpi,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(apwalm,evecfv,evecsv,dmatk) &
-!$OMP PRIVATE(ispn,ias,ist,wo) &
+!$OMP PRIVATE(idx,apwalm,evecfv,evecsv,dmatk) &
+!$OMP PRIVATE(ispn,nst,ist,jst,ias,wo) &
 !$OMP NUM_THREADS(nthd)
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
 allocate(evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv))
@@ -42,14 +45,21 @@ do ik=1,nkpt
 ! get the eigenvectors from file
   call getevecfv(filext,ik,vkl(:,ik),vgkl(:,:,:,ik),evecfv)
   call getevecsv(filext,ik,vkl(:,ik),evecsv)
+! index to occupied states
+  nst=0
+  do ist=1,nstsv
+    if (abs(occsv(ist,ik)).gt.epsocc) then
+      nst=nst+1
+      idx(nst)=ist
+    end if
+  end do
 ! begin loop over atoms and species
   do ias=1,natmtot
-    call gendmatk(tspndg,tlmdg,lmin,lmax,ias,ngk(:,ik),apwalm,evecfv,evecsv, &
-     ld,dmatk)
-    do ist=1,nstsv
-      wo=occsv(ist,ik)
-      if (abs(wo).lt.epsocc) cycle
-      wo=wo*wkpt(ik)
+    call gendmatk(tspndg,tlmdg,lmin,lmax,ias,nst,idx,ngk(:,ik),apwalm,evecfv, &
+     evecsv,ld,dmatk)
+    do ist=1,nst
+      jst=idx(ist)
+      wo=occsv(jst,ik)*wkpt(ik)
 !$OMP CRITICAL(gendmat_)
       dmat(:,:,:,:,ias)=dmat(:,:,:,:,ias)+wo*dmatk(:,:,:,:,ist)
 !$OMP END CRITICAL(gendmat_)
