@@ -58,10 +58,10 @@ do is=1,nspecies
             if (abs(dble(z1))+abs(aimag(z1)).gt.epsocc) then
               if (.not.done(ist)) then
                 if (tsh) then
-                  call wavefmt(lradstp,ias,ngp(jspn),apwalmq(:,:,:,ias,jspn), &
+                  call wfmtfv(ias,ngp(jspn),apwalmq(:,:,:,ias,jspn), &
                    evecfv(:,ist,jspn),wfmt1(:,ist))
                 else
-                  call wavefmt(lradstp,ias,ngp(jspn),apwalmq(:,:,:,ias,jspn), &
+                  call wfmtfv(ias,ngp(jspn),apwalmq(:,:,:,ias,jspn), &
                    evecfv(:,ist,jspn),wfmt2)
                   call zbsht(nrc,nrci,wfmt2,wfmt1(:,ist))
                 end if
@@ -73,11 +73,11 @@ do is=1,nspecies
             if (abs(dble(z1))+abs(aimag(z1)).gt.epsocc) then
               if (.not.ddone(ist)) then
                 if (tsh) then
-                  call dwavefmt(lradstp,ias,ngp(jspn),ngpq(jspn), &
+                  call dwfmtfv(ias,ngp(jspn),ngpq(jspn), &
                    apwalmq(:,:,:,ias,jspn),dapwalm(:,:,:,jspn), &
                    evecfv(:,ist,jspn),devecfv(:,ist,jspn),dwfmt1(:,ist))
                 else
-                  call dwavefmt(lradstp,ias,ngp(jspn),ngpq(jspn), &
+                  call dwfmtfv(ias,ngp(jspn),ngpq(jspn), &
                    apwalmq(:,:,:,ias,jspn),dapwalm(:,:,:,jspn), &
                    evecfv(:,ist,jspn),devecfv(:,ist,jspn),wfmt2)
                   call zbsht(nrc,nrci,wfmt2,dwfmt1(:,ist))
@@ -90,11 +90,11 @@ do is=1,nspecies
         end do
       else
         if (tsh) then
-          call dwavefmt(lradstp,ias,ngp,ngpq,apwalmq(:,:,:,ias,1),dapwalm, &
-           evecfv(:,k,1),devecfv(:,k,1),dwfmt(:,ias,1,j))
+          call dwfmtfv(ias,ngp,ngpq,apwalmq(:,:,:,ias,1),dapwalm,evecfv(:,k,1),&
+           devecfv(:,k,1),dwfmt(:,ias,1,j))
         else
-          call dwavefmt(lradstp,ias,ngp,ngpq,apwalmq(:,:,:,ias,1),dapwalm, &
-           evecfv(:,k,1),devecfv(:,k,1),wfmt2)
+          call dwfmtfv(ias,ngp,ngpq,apwalmq(:,:,:,ias,1),dapwalm,evecfv(:,k,1),&
+           devecfv(:,k,1),wfmt2)
           call zbsht(nrc,nrci,wfmt2,dwfmt(:,ias,1,j))
         end if
       end if
