@@ -3,7 +3,7 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine gengclgq(treg,iq,ngq,gqc,gclgq)
+pure subroutine gengclgq(treg,iq,ngq,gqc,gclgq)
 use modmain
 implicit none
 ! arguments
@@ -21,8 +21,10 @@ if (treg) then
     t2=gqc(ig)
     if (abs(t1-t2).lt.epslat) then
       gclgq(ig)=gclq(iq)
-    else
+    else if (t2.gt.epslat) then
       gclgq(ig)=fourpi/t2**2
+    else
+      gclgq(ig)=0.d0
     end if
   end do
 else
@@ -36,6 +38,5 @@ else
     end if
   end do
 end if
-return
 end subroutine
 
