@@ -11,13 +11,14 @@ implicit none
 integer, intent(in) :: iq
 ! local variables
 integer is,ig
-! loop over G-vectors
 do ig=1,ngtot
 ! G+q-vector in Cartesian coordinates
-  vgqc(:,ig)=vgc(:,ig)+vqc(:,iq)
+  vgqc(1:3,ig)=vgc(1:3,ig)+vqc(1:3,iq)
 ! G+q-vector length
   gqc(ig)=sqrt(vgqc(1,ig)**2+vgqc(2,ig)**2+vgqc(3,ig)**2)
+end do
 ! spherical harmonics for G+q-vectors
+do ig=1,ngvec
   call genylmv(lmaxo,vgqc(:,ig),ylmgq(:,ig))
 end do
 ! compute the spherical Bessel functions j_l(|G+q|R_mt)
@@ -28,6 +29,5 @@ call gensfacgp(ngvec,vgqc,ngvec,sfacgq)
 do is=1,nspecies
   call genffacgp(is,gqc,ffacgq(:,is))
 end do
-return
 end subroutine
 
