@@ -9,8 +9,8 @@ use modtddft
 implicit none
 ! local variables
 integer is,ias
-integer nr,nri,ir
-integer np,i
+integer nr,nri,iro
+integer np,i0,i1
 ! automatic arrays
 real(8) rfmt(npmtmax)
 complex(8) zrhomt(npmtmax),zvclmt(npmtmax)
@@ -22,6 +22,7 @@ do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
   nri=nrmti(is)
+  iro=nri+1
   np=npmt(is)
 ! take the average of the static density over the three directions
   rfmt(1:np)=(1.d0/3.d0) &
@@ -31,15 +32,11 @@ do ias=1,natmtot
 ! solve Poisson's equation in the muffin-tin
   call zpotclmt(nr,nri,nrmtmax,rlmt(:,:,is),wprmt(:,:,is),zrhomt,zvclmt)
 ! add the nuclear Coulomb potential
-  i=1
-  do ir=1,nri
-    zvclmt(i)=zvclmt(i)+vcln(ir,is)
-    i=i+lmmaxi
-  end do
-  do ir=nri+1,nr
-    zvclmt(i)=zvclmt(i)+vcln(ir,is)
-    i=i+lmmaxo
-  end do
+  i1=lmmaxi*(nri-1)+1
+  zvclmt(1:i1:lmmaxi)=zvclmt(1:i1:lmmaxi)+vcln(1:nri,is)
+  i0=i1+lmmaxi
+  i1=lmmaxo*(nr-iro)+i0
+  zvclmt(i0:i1:lmmaxo)=zvclmt(i0:i1:lmmaxo)+vcln(iro:nr,is)
 ! compute the gradient of the potential and store in global array
   call gradzfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),zvclmt,npmtmax, &
    gvclns(:,:,ias))
