@@ -27,8 +27,8 @@ implicit none
 integer ig,jg,i1,i2,i3,j1,j2,j3
 real(8) v1(3),v2(3),v3(3)
 ! allocatable arrays
-integer, allocatable :: idx(:),ivg0(:,:)
-real(8), allocatable :: vgc0(:,:),gc0(:)
+integer, allocatable :: idx(:),ivg1(:,:)
+real(8), allocatable :: vgc1(:,:),gc1(:)
 if (gmaxvr.lt.0.d0) gmaxvr=abs(gmaxvr)*gkmax
 ! ensure |G| cut-off is at least twice |G+k| cut-off
 gmaxvr=max(gmaxvr,2.d0*gkmax+epslat)
@@ -47,8 +47,8 @@ allocate(vgc(3,ngtot))
 if (allocated(gc)) deallocate(gc)
 allocate(gc(ngtot))
 ! allocate local arrays
-allocate(idx(ngtot),ivg0(3,ngtot))
-allocate(vgc0(3,ngtot),gc0(ngtot))
+allocate(idx(ngtot),ivg1(3,ngtot))
+allocate(vgc1(3,ngtot),gc1(ngtot))
 ig=0
 do i1=intgv(1,1),intgv(2,1)
   v1(:)=dble(i1)*bvec(:,1)
@@ -58,24 +58,24 @@ do i1=intgv(1,1),intgv(2,1)
       v3(:)=v2(:)+dble(i3)*bvec(:,3)
       ig=ig+1
 ! map from G-vector to (i1,i2,i3) index
-      ivg0(1,ig)=i1
-      ivg0(2,ig)=i2
-      ivg0(3,ig)=i3
+      ivg1(1,ig)=i1
+      ivg1(2,ig)=i2
+      ivg1(3,ig)=i3
 ! G-vector in Cartesian coordinates
-      vgc0(:,ig)=v3(:)
+      vgc1(:,ig)=v3(:)
 ! length of each G-vector
-      gc0(ig)=sqrt(v3(1)**2+v3(2)**2+v3(3)**2)
+      gc1(ig)=sqrt(v3(1)**2+v3(2)**2+v3(3)**2)
     end do
   end do
 end do
 ! sort by vector length
-call sortidx(ngtot,gc0,idx)
+call sortidx(ngtot,gc1,idx)
 ! reorder arrays
 do ig=1,ngtot
   jg=idx(ig)
-  ivg(1:3,ig)=ivg0(1:3,jg)
-  gc(ig)=gc0(jg)
-  vgc(1:3,ig)=vgc0(1:3,jg)
+  ivg(1:3,ig)=ivg1(1:3,jg)
+  gc(ig)=gc1(jg)
+  vgc(1:3,ig)=vgc1(1:3,jg)
 end do
 ! find the number of vectors with G < gmaxvr
 ngvec=1
@@ -110,7 +110,7 @@ do ig=1,ngtot
   end if
   igfft(ig)=j3*ngridg(2)*ngridg(1)+j2*ngridg(1)+j1+1
 end do
-deallocate(idx,ivg0,gc0,vgc0)
+deallocate(idx,ivg1,vgc1,gc1)
 end subroutine
 !EOC
 
