@@ -15,10 +15,8 @@ real(8), intent(in) :: bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag)
 complex(8), intent(in) :: kmat(nstsv,nstsv),pmat(nstsv,nstsv,3)
 complex(8), intent(out) :: h(nstsv,nstsv)
 ! local variables
-integer ist,i
+integer i
 real(8) ca,t1
-! automatic arrays
-integer idx(nstsv)
 ! allocatable arrays
 complex(8), allocatable :: apwalm(:,:,:,:),evecfv(:,:),evecsv(:,:)
 complex(8), allocatable :: wfmt(:,:,:,:),wfgk(:,:,:)
@@ -29,13 +27,9 @@ call getevecsv('.OUT',ik,vkl(:,ik),evecsv)
 ! find the matching coefficients
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot))
 call match(ngk(1,ik),vgkc(:,:,1,ik),gkc(:,1,ik),sfacgk(:,:,1,ik),apwalm)
-! index to all states
-do ist=1,nstsv
-  idx(ist)=ist
-end do
 ! calculate the wavefunctions for all states of the input k-point
 allocate(wfmt(npcmtmax,natmtot,nspinor,nstsv),wfgk(ngkmax,nspinor,nstsv))
-call genwfsv(.false.,.true.,nstsv,idx,ngridg,igfft,ngk(:,ik),igkig(:,:,ik), &
+call genwfsv(.false.,.true.,nstsv,0,ngridg,igfft,ngk(:,ik),igkig(:,:,ik), &
  apwalm,evecfv,evecsv,wfmt,ngkmax,wfgk)
 deallocate(apwalm,evecfv,evecsv)
 ! Kohn-Sham potential and magnetic field matrix elements
@@ -44,8 +38,6 @@ if (spinpol) then
 else
   call genvmatk(vmt,vir,ngk(:,ik),igkig(:,:,ik),wfmt,ngkmax,wfgk,h)
 end if
-! add the DFT+U matrix elements if required
-call genvmmtsv(wfmt,h)
 deallocate(wfmt,wfgk)
 ! add the kinetic matrix elements in the second-variational basis
 h(:,:)=h(:,:)+kmat(:,:)
