@@ -16,11 +16,11 @@ integer ik,ist,jst,ispn,nthd
 integer ikpa,jkpa,iq,ifq,ngk0,igk
 integer i1,i2,i3,j1,j2,j3,i,j
 ! automatic arrays
-integer idx(nstsv)
 complex(8) vmat(nstsv,nstsv)
 ! allocatable arrays
 complex(8), allocatable :: apwalm(:,:,:,:),evecfv(:,:),evecsv(:,:)
-complex(8), allocatable :: wfmt(:,:,:,:),wfir(:,:,:),wfgk(:,:,:)
+complex(4), allocatable :: wfmt(:,:,:,:)
+complex(8), allocatable :: wfir(:,:,:),wfgk(:,:,:)
 complex(8), allocatable :: hdb(:,:,:)
 ! central k-point
 ik=(ik0-1)*nkpa+1
@@ -33,13 +33,9 @@ call getevecsv('.OUT',ik,vkl(:,ik),evecsv)
 ! find the matching coefficients
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot))
 call match(ngk0,vgkc(:,:,1,ik),gkc(:,1,ik),sfacgk(:,:,1,ik),apwalm)
-! index to all states
-do ist=1,nstsv
-  idx(ist)=ist
-end do
 ! calculate the wavefunctions for all states of the central k-point
 allocate(wfmt(npcmtmax,natmtot,nspinor,nstsv),wfgk(ngk0,nspinor,nstsv))
-call genwfsv(.false.,.true.,nstsv,idx,ngridg,igfft,ngk0,igkig(:,1,ik),apwalm, &
+call genwfsv_sp(.false.,.true.,nstsv,0,ngridg,igfft,ngk0,igkig(:,1,ik),apwalm, &
  evecfv,evecsv,wfmt,ngk0,wfgk)
 deallocate(apwalm,evecfv,evecsv)
 ! determine the interstitial wavefunctions in real-space (without 1/sqrt(omega))
