@@ -40,7 +40,7 @@ h(:,:)=0.d0
 p=1
 do l=0,lmax
   n=2*l+1
-  lm=l*(l+1)-l+1
+  lm=l**2+1
   do i=lm,lm+n-1
     do j=i,lm+n-1
 ! Park and Miller linear congruential generator
@@ -68,7 +68,7 @@ do is=1,nspecies
 ! block diagonalise symmetrised H
     do l=0,lmax
       n=2*l+1
-      lm=l*(l+1)-l+1
+      lm=l**2+1
       call zheev('V','U',n,b(lm,lm),lmmax,elm(lm,ias),work,lwork,rwork,info)
     end do
 ! the unitary matrix U is the transpose of the eigenvector array
