@@ -136,29 +136,32 @@ end do
 !-----------------------------------!
 !     interstitial contribution     !
 !-----------------------------------!
-allocate(gwfir(ngtot,3))
+allocate(gwfir(ngtc,3))
+
+!********* print and check!
+
 do jst=1,nstsv
   do ispn=1,nspinor
     jspn=jspnfv(ispn)
 ! compute the gradient
     gwfir(:,:)=0.d0
     do igp=1,ngp(jspn)
-      ifg=igfft(igpig(igp,jspn))
+      ifg=igfc(igpig(igp,jspn))
       z1=wfgp(igp,ispn,jst)
       gwfir(ifg,1:3)=vgpc(1:3,igp,jspn)*cmplx(-aimag(z1),dble(z1),8)
     end do
     do i=1,3
 ! Fourier transform to real-space
-      call zfftifc(3,ngridg,1,gwfir(:,i))
-! multiply by characteristic function
-      gwfir(:,i)=gwfir(:,i)*cfunir(:)
+      call zfftifc(3,ngdgc,1,gwfir(:,i))
+! multiply by coarse characteristic function
+      gwfir(:,i)=gwfir(:,i)*cfrc(:)
 ! Fourier transform back to G-space
-      call zfftifc(3,ngridg,-1,gwfir(:,i))
+      call zfftifc(3,ngdgc,-1,gwfir(:,i))
     end do
 ! find the overlaps
     do i=1,3
       do igp=1,ngp(jspn)
-        ifg=igfft(igpig(igp,jspn))
+        ifg=igfc(igpig(igp,jspn))
         z(igp)=gwfir(ifg,i)
       end do
       do ist=1,jst
@@ -171,12 +174,13 @@ deallocate(gwfir)
 ! multiply by -i and set lower triangular part
 do i=1,3
   do jst=1,nstsv
-    do ist=1,jst
+    do ist=1,jst-1
       z1=pmat(ist,jst,i)
       z1=cmplx(aimag(z1),-dble(z1),8)
       pmat(ist,jst,i)=z1
       pmat(jst,ist,i)=conjg(z1)
     end do
+    pmat(jst,jst,i)=aimag(pmat(jst,jst,i))
   end do
 end do
 end subroutine
