@@ -98,7 +98,7 @@ do ias=1,natmtot
 ! convert to spherical harmonics if required
         call rfsht(nr,nri,fxc(:,i,j),fxcmt(:,ias,i,j))
       else
-        call dcopy(np,fxc(:,i,j),fxcmt(:,ias,i,j),1)
+        fxcmt(1:np,ias,i,j)=fxc(1:np,i,j)
       end if
     end do
   end do
