@@ -9,10 +9,8 @@ implicit none
 ! local variables
 integer i,j,k
 real(8) a(3,3),b(3,3),t1
-! external functions
-real(8), external :: ddot,dnrm2
 ! set first strain equal to isotropic scaling
-t1=dnrm2(9,avec,1)
+t1=norm2(avec(:,:))
 strain(:,:,1)=avec(:,:)/t1
 nstrain=1
 do i=1,3
@@ -26,11 +24,11 @@ do i=1,3
     call r3mtm(ainv,a,b)
 ! orthogonalise strain tensor to previous tensors
     do k=1,nstrain
-      t1=-ddot(9,strain(:,:,k),1,b,1)
-      call daxpy(9,t1,strain(:,:,k),1,b,1)
+      t1=sum(b(:,:)*strain(:,:,k))
+      b(:,:)=b(:,:)-t1*strain(:,:,k)
     end do
 ! compute the norm
-    t1=dnrm2(9,b,1)
+    t1=norm2(b(:,:))
     if (t1.lt.epslat) cycle
 ! normalise tensor and store in global array
     nstrain=nstrain+1
