@@ -6,14 +6,13 @@
 subroutine genstress
 use modmain
 use modmpi
-use modstore
 implicit none
 ! local variables
 integer i
 real(8) et0,t1
 ! store original parameters
-avec_(:,:)=avec(:,:)
-tforce_=tforce
+avec0(:,:)=avec(:,:)
+tforce0=tforce
 tforce=.false.
 ! restore original symmetries
 call symmetry
@@ -35,7 +34,7 @@ do istrain=1,nstrain
     write(*,'("Info(genstress): strain tensor ",I1," of ",I1)') istrain,nstrain
   end if
 ! restore the lattice vectors
-  avec(:,:)=avec_(:,:)
+  avec(:,:)=avec0(:,:)
 ! run the ground-state calculation
   call gndstate
 ! check for stop signal
@@ -52,7 +51,7 @@ do i=1,nstrain
   if (t1.gt.stressmax) stressmax=t1
 end do
 ! restore original parameters
-avec(:,:)=avec_(:,:)
-tforce=tforce_
+avec(:,:)=avec0(:,:)
+tforce=tforce0
 end subroutine
 
