@@ -39,7 +39,7 @@ allocate(rfmt(npcmtmax,natmtot))
 do ispn=1,nspinor
   do ias=1,natmtot
     is=idxis(ias)
-    call dcopy(npcmt(is),taumt(:,ias,ispn),1,rfmt,1)
+    rfmt(1:npcmt(is),1)=taumt(1:npcmt(is),ias,ispn)
     call rfsht(nrcmt(is),nrcmti(is),rfmt,taumt(:,ias,ispn))
   end do
 end do
