@@ -64,7 +64,7 @@ call freethd(nthd)
 do ispn=1,nspinor
   do ias=1,natmtot
     is=idxis(ias)
-    call dcopy(npmt(is),taucr(:,ias,ispn),1,rfmt,1)
+    rfmt(1:npmt(is))=taucr(1:npmt(is),ias,ispn)
     call rfsht(nrmt(is),nrmti(is),rfmt,taucr(:,ias,ispn))
   end do
 end do
