@@ -9,14 +9,19 @@ use modtddft
 implicit none
 ! local variables
 integer its
+if (tstime.lt.dtimes) then
+  write(*,*)
+  write(*,'("Error(gentimes): tstime < dtimes : ",2G18.10)') tstime,dtimes
+  write(*,*)
+  stop
+end if
 ! number of time steps
-ntimes=int(tstime/dtimes)+1
-! generate the time-step array
+ntimes=nint(tstime/dtimes)+1
+! generate the time step array
 if (allocated(times)) deallocate(times)
 allocate(times(ntimes))
 do its=1,ntimes
   times(its)=dble(its-1)*dtimes
 end do
-return
 end subroutine
 
