@@ -5,6 +5,7 @@
 
 subroutine genvbmatk(vmt,vir,bmt,bir,ngp,igpig,wfmt,ld,wfgp,vbmat)
 use modmain
+use moddftu
 use modomp
 implicit none
 ! arguments
@@ -19,46 +20,93 @@ complex(8), intent(in) :: wfgp(ld,nspinor,nstsv)
 complex(8), intent(out) :: vbmat(nstsv,nstsv)
 ! local variables
 integer ist,jst,ispn,jspn
-integer is,ias,npc,igp,nthd
+integer is,ias,nrc,nrci,nrco
+integer npc,npc2,npc4,ipco
+integer igp,nthd
 ! automatic arrays
-complex(8) wfmt2(npcmtmax,nspinor),z(ngkmax)
+complex(4) wfmt4(2*npcmtmax)
+complex(8) wfmt2(2*npcmtmax),wfmt3(2*npcmtmax),z(ngkmax)
 ! allocatable arrays
+complex(4), allocatable :: wfmt1(:,:)
 complex(8), allocatable :: wfir1(:,:),wfir2(:,:)
 ! external functions
+real(4), external :: sdot
+real(8), external :: ddot
+complex(4), external :: cdotc
 complex(8), external :: zdotc
 ! zero the matrix elements
 vbmat(:,:)=0.d0
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
+allocate(wfmt1(2*npcmtmax,nstsv))
 call holdthd(nstsv,nthd)
+do ias=1,natmtot
+  is=idxis(ias)
+  nrc=nrcmt(is)
+  nrci=nrcmti(is)
+  nrco=nrc-nrci
+  npc=npcmt(is)
+  npc2=npc*2
+  npc4=npc*4
+  ipco=npcmti(is)+1
+! make single-precision copy of wavefunction
+  wfmt1(1:npc,:)=wfmt(1:npc,ias,1,:)
+  wfmt1(npc+1:npc2,:)=wfmt(1:npc,ias,2,:)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
-!$OMP PRIVATE(wfmt2,ias,is,npc,ist) &
+!$OMP PRIVATE(wfmt2,wfmt3,wfmt4,ist) &
 !$OMP NUM_THREADS(nthd)
-do jst=1,nstsv
-  do ias=1,natmtot
-    is=idxis(ias)
-    npc=npcmt(is)
+  do jst=1,nstsv
 ! apply local potential and magnetic field to spinor wavefunction
     if (ncmag) then
 ! non-collinear case
       call vbmk1(npc,vmt(:,ias),bmt(:,ias,1),bmt(:,ias,2),bmt(:,ias,3), &
-       wfmt(:,ias,1,jst),wfmt(:,ias,2,jst),wfmt2,wfmt2(:,2))
+       wfmt(:,ias,1,jst),wfmt(:,ias,2,jst),wfmt2,wfmt2(npc+1))
     else
 ! collinear case
       call vbmk2(npc,vmt(:,ias),bmt(:,ias,1),wfmt(:,ias,1,jst), &
-       wfmt(:,ias,2,jst),wfmt2,wfmt2(:,2))
+       wfmt(:,ias,2,jst),wfmt2,wfmt2(npc+1))
     end if
+! apply muffin-tin DFT+U potential matrix if required
+    if (dftu.ne.0) then
+      if (any(tvmmt(0:lmaxdm,ias))) then
+! multiply wavefunction by radial integration weights
+        wfmt3(1:npc)=wfmt(1:npc,ias,1,jst)
+        wfmt3(npc+1:npc2)=wfmt(1:npc,ias,2,jst)
+        call zfcmtwr(nrc,nrci,wrcmt(:,is),wfmt3)
+        call zfcmtwr(nrc,nrci,wrcmt(:,is),wfmt3(npc+1))
+        call zgemm('N','N',lmmaxi,nrci,lmmaxi,zone,vmatmti(:,:,1,1,ias),lmmaxi,&
+         wfmt3,lmmaxi,zone,wfmt2,lmmaxi)
+        call zgemm('N','N',lmmaxo,nrco,lmmaxo,zone,vmatmto(:,:,1,1,ias),lmmaxo,&
+         wfmt3(ipco),lmmaxo,zone,wfmt2(ipco),lmmaxo)
+        call zgemm('N','N',lmmaxi,nrci,lmmaxi,zone,vmatmti(:,:,2,2,ias),lmmaxi,&
+         wfmt3(npc+1),lmmaxi,zone,wfmt2(npc+1),lmmaxi)
+        call zgemm('N','N',lmmaxo,nrco,lmmaxo,zone,vmatmto(:,:,2,2,ias),lmmaxo,&
+         wfmt3(npc+ipco),lmmaxo,zone,wfmt2(npc+ipco),lmmaxo)
+        if (ncmag) then
+          call zgemm('N','N',lmmaxi,nrci,lmmaxi,zone,vmatmti(:,:,1,2,ias), &
+           lmmaxi,wfmt3(npc+1),lmmaxi,zone,wfmt2,lmmaxi)
+          call zgemm('N','N',lmmaxo,nrco,lmmaxo,zone,vmatmto(:,:,1,2,ias), &
+           lmmaxo,wfmt3(npc+ipco),lmmaxo,zone,wfmt2(ipco),lmmaxo)
+          call zgemm('N','N',lmmaxi,nrci,lmmaxi,zone,vmatmti(:,:,2,1,ias), &
+           lmmaxi,wfmt3,lmmaxi,zone,wfmt2(npc+1),lmmaxi)
+          call zgemm('N','N',lmmaxo,nrco,lmmaxo,zone,vmatmto(:,:,2,1,ias), &
+           lmmaxo,wfmt3(ipco),lmmaxo,zone,wfmt2(npc+ipco),lmmaxo)
+        end if
+      end if
+    end if
+! copy to single-precision array
+    wfmt4(1:npc2)=wfmt2(1:npc2)
 ! compute the inner products
-    do ist=1,jst
-      vbmat(ist,jst)=vbmat(ist,jst) &
-       +zdotc(npc,wfmt(:,ias,1,ist),1,wfmt2,1) &
-       +zdotc(npc,wfmt(:,ias,2,ist),1,wfmt2(:,2),1)
+    do ist=1,jst-1
+      vbmat(ist,jst)=vbmat(ist,jst)+cdotc(npc2,wfmt1(:,ist),1,wfmt4,1)
     end do
+    vbmat(jst,jst)=vbmat(jst,jst)+sdot(npc4,wfmt1(:,jst),1,wfmt4,1)
   end do
-end do
 !$OMP END PARALLEL DO
+end do
 call freethd(nthd)
+deallocate(wfmt1)
 !---------------------------!
 !     interstitial part     !
 !---------------------------!
@@ -95,9 +143,10 @@ do jst=1,nstsv
     do igp=1,ngp(jspn)
       z(igp)=wfir2(igfft(igpig(igp,jspn)),ispn)
     end do
-    do ist=1,jst
+    do ist=1,jst-1
       vbmat(ist,jst)=vbmat(ist,jst)+zdotc(ngp(jspn),wfgp(:,ispn,ist),1,z,1)
     end do
+    vbmat(jst,jst)=vbmat(jst,jst)+ddot(2*ngp(jspn),wfgp(:,ispn,jst),1,z,1)
   end do
 end do
 !$OMP END DO
