@@ -28,8 +28,6 @@ integer ik,ist1,ist2,ist3
 integer iv(3),iq,ig
 real(8) vc(3)
 complex(8) z1
-! automatic arrays
-integer idx(nstsv)
 ! allocatable arrays
 real(8), allocatable :: vgqc(:,:),gqc(:),gclgq(:),jlgqrmt(:,:,:)
 complex(8), allocatable :: apwalm(:,:,:,:),evecfv(:,:),evecsv(:,:)
@@ -55,12 +53,8 @@ call getevecfv(filext,0,vkl(:,ikp),vgkl(:,:,1,ikp),evecfv)
 call getevecsv(filext,0,vkl(:,ikp),evecsv)
 ! find the matching coefficients
 call match(ngk(1,ikp),vgkc(:,:,1,ikp),gkc(:,1,ikp),sfacgk(:,:,1,ikp),apwalm)
-! index to all states
-do ist1=1,nstsv
-  idx(ist1)=ist1
-end do
 ! calculate the wavefunctions for all states of passed non-reduced k-point ikp
-call genwfsv(.false.,.false.,nstsv,idx,ngdgc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
+call genwfsv(.false.,.false.,nstsv,0,ngdgc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
  apwalm,evecfv,evecsv,wfmt2,ngtc,wfir2)
 ! start loop over reduced k-point set
 do ik=1,nkpt
@@ -69,7 +63,7 @@ do ik=1,nkpt
   iv(:)=modulo(iv(:),ngridk(:))
 ! check if the q-point is in user-defined set
   iv(:)=iv(:)*ngridq(:)
-  if (any(modulo(iv(:),ngridk(:)).ne.0)) cycle
+  if (any(mod(iv(:),ngridk(:)).ne.0)) cycle
   iv(:)=iv(:)/ngridk(:)
   iq=ivqiq(iv(1),iv(2),iv(3))
   vc(:)=vkc(:,ik)-vkc(:,ikp)
@@ -93,7 +87,7 @@ do ik=1,nkpt
   call getevecfv(filext,ik,vkl(:,ik),vgkl(:,:,:,ik),evecfv)
   call getevecsv(filext,ik,vkl(:,ik),evecsv)
 ! calculate the wavefunctions for all states of the reduced k-point
-  call genwfsv(.false.,.false.,nstsv,idx,ngdgc,igfc,ngk(1,ik),igkig(:,1,ik), &
+  call genwfsv(.false.,.false.,nstsv,0,ngdgc,igfc,ngk(1,ik),igkig(:,1,ik), &
    apwalm,evecfv,evecsv,wfmt1,ngtc,wfir1)
 !----------------------------------------------!
 !     valence-valence-valence contribution     !
@@ -108,9 +102,8 @@ do ik=1,nkpt
 ! compute the Coulomb potential
       call genzvclmt(nrcmt,nrcmti,nrcmtmax,rlcmt,wprcmt,npcmtmax, &
        zrhomt(:,:,ist1),zvclmt)
-      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rlcmt,ngdgc,igfc,ngvc, &
-       gqc,gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir(:,ist1),npcmtmax,zvclmt, &
-       zvclir)
+      call zpotcoul(nrcmt,nrcmti,npcmt,nrcmtmax,rlcmt,ngdgc,igfc,ngvc,gqc, &
+       gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir(:,ist1),npcmtmax,zvclmt,zvclir)
       zvclir(:)=zvclir(:)*cfrc(:)
       do ist3=ist1,nstsv
         z1=zfinp(zrhomt(:,:,ist3),zrhoir(:,ist3),zvclmt,zvclir)
