@@ -6,12 +6,12 @@
 !BOP
 ! !ROUTINE: genveedu
 ! !INTERFACE:
-subroutine genveedu(i,u,j,vee)
+subroutine genveedu(idu,u,j,vee)
 ! !USES:
 use modmain
 use moddftu
 ! !INPUT/OUTPUT PARAMETERS:
-!   i   : DFT+U entry (in,integer)
+!   idu : DFT+U entry (in,integer)
 !   u   : parameter U (out,real)
 !   j   : parameter J (out,real)
 !   vee : Coulomb matrix elements (out,real(-lmaxdm:lmaxdm,-lmaxdm:lmaxdm,
@@ -27,7 +27,7 @@ use moddftu
 !BOC
 implicit none
 ! arguments
-integer, intent(in) :: i
+integer, intent(in) :: idu
 real(8), intent(out) :: u,j
 real(8), intent(out) :: vee(-lmaxdm:lmaxdm,-lmaxdm:lmaxdm,-lmaxdm:lmaxdm, &
  -lmaxdm:lmaxdm)
@@ -38,9 +38,9 @@ real(8) sm1,sm2,t1
 real(8) :: f(0:2*lmaxdm)
 ! external functions
 real(8), external :: gaunt
-l=idftu(2,i)
+l=isldu(2,idu)
 ! calculate Slater integrals
-call genfdu(i,u,j,f)
+call genfdu(idu,u,j,f)
 do m1=-l,l
   do m2=-l,l
     do m3=-l,l
