@@ -13,11 +13,10 @@ implicit none
 real(8), intent(in) :: vmt(npmtmax,natmtot),vir(ngtot)
 complex(8), intent(out) :: vmat(nstsv,nstsv,nkpt)
 ! local variables
-integer ik,ist,ispn
+integer ik,ispn
 integer is,ias,nrc,nrci
 integer n,lp,nthd
 ! automatic arrays
-integer idx(nstsv)
 real(8) rfmt(npcmtmax)
 ! allocatable arrays
 real(8), allocatable :: vmt1(:,:),vir1(:)
@@ -44,10 +43,6 @@ end do
 call freethd(nthd)
 ! multiply interstitial potential by characteristic function
 vir1(:)=vir(:)*cfunir(:)
-! index to all states
-do ist=1,nstsv
-  idx(ist)=ist
-end do
 ! loop over k-points
 call holdthd(nkpt/np_mpi,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
@@ -70,7 +65,7 @@ do ik=1,nkpt
   call getevecfv(filext,ik,vkl(:,ik),vgkl(:,:,:,ik),evecfv)
   call getevecsv(filext,ik,vkl(:,ik),evecsv)
 ! calculate the wavefunctions for all states of the input k-point
-  call genwfsv(.false.,.true.,nstsv,idx,ngridg,igfft,ngk(:,ik),igkig(:,:,ik), &
+  call genwfsv(.false.,.true.,nstsv,0,ngridg,igfft,ngk(:,ik),igkig(:,:,ik), &
    apwalm,evecfv,evecsv,wfmt,ngkmax,wfgk)
   call genvmatk(vmt1,vir1,ngk(:,ik),igkig(:,:,ik),wfmt,ngkmax,wfgk,vmat(:,:,ik))
 end do
