@@ -26,7 +26,6 @@ integer npci,i,igp,ihp
 real(8) t0,t1
 complex(8) zsm,z1,z2,z3,z4
 ! automatic arrays
-integer idx(nstsv)
 complex(8) ylm(lmmaxo)
 ! allocatable arrays
 real(8), allocatable :: jl(:,:)
@@ -44,13 +43,9 @@ do ispn=1,nspnfv
   call match(ngp(ispn),vgpc(:,:,ispn),gpc(:,ispn),sfacgp(:,:,ispn), &
    apwalm(:,:,:,:,ispn))
 end do
-! index to all states
-do ist=1,nstsv
-  idx(ist)=ist
-end do
 ! calculate the second-variational wavefunctions for all states
-call genwfsv(.true.,.true.,nstsv,idx,ngridg,igfft,ngp,igpig,apwalm,evecfv, &
- evecsv,wfmt,ngkmax,wfgp)
+call genwfsv(.true.,.true.,nstsv,0,ngridg,igfft,ngp,igpig,apwalm,evecfv,evecsv,&
+ wfmt,ngkmax,wfgp)
 deallocate(apwalm,evecfv,evecsv)
 ! zero the plane wave coefficients
 wfpw(:,:,:)=0.d0
@@ -119,7 +114,7 @@ do jspn=1,nspnfv
             z2=z1*wfgp(igp,ispn,ist)
             lm=0
             do l=0,lmaxi
-              z3=z2*zil(l)
+              z3=z2*zil(mod(l,4))
               do m=-l,l
                 lm=lm+1
                 z4=z3*ylm(lm)
@@ -132,7 +127,7 @@ do jspn=1,nspnfv
             end do
             lm=0
             do l=0,lmaxo
-              z3=z2*zil(l)
+              z3=z2*zil(mod(l,4))
               do m=-l,l
                 lm=lm+1
                 z4=z3*ylm(lm)
@@ -193,7 +188,7 @@ do jspn=1,nspnfv
                   i=i+1
                   z2=z2+wfmt(i,ias,ispn,ist)*ylm(lm)
                 end do
-                z1=z1+jl(l,irc)*zilc(l)*z2
+                z1=z1+jl(l,irc)*zilc(mod(l,4))*z2
               end do
               zsm=zsm+wrcmt(irc,is)*z1
               if (irc.eq.nrci) lmax=lmaxo
