@@ -8,7 +8,7 @@ use modmain
 implicit none
 ! arguments
 logical, intent(in) :: tsh,tgp
-integer, intent(in) :: nst,idx(nst),ngdg(3),igf(*)
+integer, intent(in) :: nst,idx(*),ngdg(3),igf(*)
 real(8), intent(in) :: vpl(3)
 integer, intent(out) :: ngp(nspnfv),igpig(ngkmax,nspnfv)
 complex(8), intent(out) :: wfmt(npcmtmax,natmtot,nspinor,nst)
