@@ -6,7 +6,7 @@
 !BOP
 ! !ROUTINE: genylmv
 ! !INTERFACE:
-subroutine genylmv(lmax,v,ylm)
+pure subroutine genylmv(lmax,v,ylm)
 ! !INPUT/OUTPUT PARAMETERS:
 !   lmax : maximum angular momentum (in,integer)
 !   v    : input vector (in,real(3))
@@ -35,12 +35,6 @@ real(8), parameter :: eps=1.d-14
 real(8) r,st,ct,sp,cp
 real(8) t1,t2,t3,t4
 complex(8) z1
-if ((lmax.lt.0).or.(lmax.gt.50)) then
-  write(*,*)
-  write(*,'("Error(genylmv): lmax out of range : ",I8)') lmax
-  write(*,*)
-  stop
-end if
 ylm(1)=0.28209479177387814347d0
 if (lmax.eq.0) return
 r=sqrt(v(1)**2+v(2)**2+v(3)**2)
@@ -111,7 +105,6 @@ do l=2,lmax
   t4=t2*dble(l-1)
   ylm(lm1)=t3*(t1*ylm(lm2)-t4*ylm(lm3))
 end do
-return
 end subroutine
 !EOC
 
