@@ -18,10 +18,8 @@ complex(8) z11,z12,z21,z22,z1,z2
 if (ncmag) then
 ! non-collinear case
   do i=1,n
-    z11=wf11(i)
-    z12=wf12(i)
-    z21=wf21(i)
-    z22=wf22(i)
+    z11=wf11(i); z12=wf12(i)
+    z21=wf21(i); z22=wf22(i)
 ! up-dn spin density
     z1=conjg(z11)*z22
 ! dn-up spin density
@@ -47,6 +45,5 @@ else
     zrho(i)=z1+z2
   end do
 end if
-return
 end subroutine
 
