@@ -13,7 +13,8 @@ implicit none
 complex(8), intent(in) :: zvmt(npcmtmax,natmtot),zvir(ngtot)
 complex(8), intent(in) :: zbmt(npcmtmax,natmtot,ndmag),zbir(ngtot,ndmag)
 integer, intent(in) :: ngp,igpig(ngp)
-complex(8), intent(in) :: wfmt(npcmtmax,natmtot,nspinor,nstsv)
+! note that the muffin-tin wavefunction is single-precision
+complex(4), intent(in) :: wfmt(npcmtmax,natmtot,nspinor,nstsv)
 ! note that wfir does not have a 1/sqrt(omega) prefactor
 complex(8), intent(in) :: wfir(ngtot,nspinor,nstsv)
 complex(8), intent(in) :: wfgp(ngp,nspinor,nstsv)
@@ -22,10 +23,12 @@ complex(8), intent(out) :: vbmat(nstsv,nstsv)
 integer ist,jst,ispn
 integer is,ias,npc,nthd
 ! automatic arrays
-complex(8) wfmt2(npcmtmax,nspinor),z(ngp)
+complex(4) wfmt2(npcmtmax,nspinor)
+complex(8) z(ngp)
 ! allocatable arrays
 complex(8), allocatable :: wfir2(:,:)
 ! external functions
+complex(4), external :: cdotc
 complex(8), external :: zdotc
 ! zero the matrix elements
 vbmat(:,:)=0.d0
@@ -43,18 +46,18 @@ do jst=1,nstsv
 ! apply local potential and magnetic field to spinor wavefunction
     if (ncmag) then
 ! non-collinear case
-      call zvbmk1(npc,zvmt(:,ias),zbmt(:,ias,1),zbmt(:,ias,2),zbmt(:,ias,3), &
+      call zvbmk1_sp(npc,zvmt(:,ias),zbmt(:,ias,1),zbmt(:,ias,2),zbmt(:,ias,3),&
        wfmt(:,ias,1,jst),wfmt(:,ias,2,jst),wfmt2,wfmt2(:,2))
     else
 ! collinear case
-      call zvbmk2(npc,zvmt(:,ias),zbmt(:,ias,1),wfmt(:,ias,1,jst), &
+      call zvbmk2_sp(npc,zvmt(:,ias),zbmt(:,ias,1),wfmt(:,ias,1,jst), &
        wfmt(:,ias,2,jst),wfmt2,wfmt2(:,2))
     end if
 ! compute the inner products
     do ist=1,nstsv
       vbmat(ist,jst)=vbmat(ist,jst) &
-       +zdotc(npc,wfmt(:,ias,1,ist),1,wfmt2,1) &
-       +zdotc(npc,wfmt(:,ias,2,ist),1,wfmt2(:,2),1)
+       +cdotc(npc,wfmt(:,ias,1,ist),1,wfmt2,1) &
+       +cdotc(npc,wfmt(:,ias,2,ist),1,wfmt2(:,2),1)
     end do
   end do
 end do
@@ -113,6 +116,23 @@ do i=1,n
 end do
 end subroutine
 
+pure subroutine zvbmk1_sp(n,zv,zb1,zb2,zb3,wf11,wf12,wf21,wf22)
+implicit none
+! arguments
+integer, intent(in) :: n
+complex(8), intent(in) :: zv(n),zb1(n),zb2(n),zb3(n)
+complex(4), intent(in) :: wf11(n),wf12(n)
+complex(4), intent(out) :: wf21(n),wf22(n)
+! local variables
+integer i
+complex(8) z1
+do i=1,n
+  z1=cmplx(-aimag(zb2(i)),dble(zb2(i)),8)
+  wf21(i)=(zv(i)+zb3(i))*wf11(i)+(zb1(i)-z1)*wf12(i)
+  wf22(i)=(zv(i)-zb3(i))*wf12(i)+(zb1(i)+z1)*wf11(i)
+end do
+end subroutine
+
 pure subroutine zvbmk2(n,zv,zb,wf11,wf12,wf21,wf22)
 implicit none
 ! arguments
@@ -128,5 +148,20 @@ do i=1,n
 end do
 end subroutine
 
+pure subroutine zvbmk2_sp(n,zv,zb,wf11,wf12,wf21,wf22)
+implicit none
+! arguments
+integer, intent(in) :: n
+complex(8), intent(in) :: zv(n),zb(n)
+complex(4), intent(in) :: wf11(n),wf12(n)
+complex(4), intent(out) :: wf21(n),wf22(n)
+! local variables
+integer i
+do i=1,n
+  wf21(i)=(zv(i)+zb(i))*wf11(i)
+  wf22(i)=(zv(i)-zb(i))*wf12(i)
+end do
+end subroutine
+
 end subroutine
 
