@@ -12,7 +12,8 @@ implicit none
 ! muffin-tin and by the characteristic function in the interstitial region
 complex(8), intent(in) :: zvmt(npcmtmax,natmtot),zvir(ngtot)
 integer, intent(in) :: ngp,igpig(ngp)
-complex(8), intent(in) :: wfmt(npcmtmax,natmtot,nspinor,nstsv)
+! note that the muffin-tin wavefunction is single-precision
+complex(4), intent(in) :: wfmt(npcmtmax,natmtot,nspinor,nstsv)
 ! note that wfir does not have a 1/sqrt(omega) prefactor
 complex(8), intent(in) :: wfir(ngtot,nspinor,nstsv)
 complex(8), intent(in) :: wfgp(ngp,nspinor,nstsv)
@@ -21,10 +22,12 @@ complex(8), intent(out) :: vmat(nstsv,nstsv)
 integer ist,jst,ispn
 integer is,ias,npc,nthd
 ! automatic arrays
-complex(8) wfmt1(npcmtmax),z(ngp)
+complex(4) wfmt1(npcmtmax)
+complex(8) z(ngp)
 ! allocatable arrays
 complex(8), allocatable :: wfir1(:)
 ! external functions
+complex(4), external :: cdotc
 complex(8), external :: zdotc
 ! zero the matrix elements
 vmat(:,:)=0.d0
@@ -45,7 +48,7 @@ do jst=1,nstsv
       wfmt1(1:npc)=zvmt(1:npc,ias)*wfmt(1:npc,ias,ispn,jst)
 ! compute the inner products
       do ist=1,nstsv
-        vmat(ist,jst)=vmat(ist,jst)+zdotc(npc,wfmt(:,ias,ispn,ist),1,wfmt1,1)
+        vmat(ist,jst)=vmat(ist,jst)+cdotc(npc,wfmt(:,ias,ispn,ist),1,wfmt1,1)
       end do
     end do
   end do
