@@ -6,7 +6,6 @@
 subroutine geomopt
 use modmain
 use modmpi
-use modstore
 use moddelf
 implicit none
 ! local variables
@@ -16,10 +15,10 @@ real(8) ds
 call init0
 call init1
 ! smooth the exchange-correlation potentials and fields
-msmooth_=msmooth
+msmooth0=msmooth
 msmooth=4
 ! store orginal volume
-omega_=omega
+omega0=omega
 ! atomic forces are required
 tforce=.true.
 if (task.eq.3) then
@@ -172,7 +171,7 @@ do istp=1,maxlatvstp
 ! tensor instead
     ds=sum(abs(stress(:)-stressp(:)))
   end if
-! broadcase ds from master process to all other processes
+! broadcast ds from master process to all other processes
   call mpi_bcast(ds,1,mpi_double_precision,0,mpicom,ierror)
   if ((istp.ge.3).and.(ds.le.epsstress*tau0latv)) then
     if (mp_mpi) then
@@ -202,6 +201,6 @@ end if
 ! ground-state should be run again after lattice optimisation
 if (latvopt.ne.0) call gndstate
 ! restore original parameters
-msmooth=msmooth_
+msmooth=msmooth0
 end subroutine
 
