@@ -67,6 +67,7 @@ if (ramdisk) then
 end if
 open(202,file=fname,form='UNFORMATTED',access='DIRECT',recl=recl)
 read(202,rec=ik) vkl_,nmatmax_,nstfv_,nspnfv_,evecfv
+close(202)
 10 continue
 !$OMP END CRITICAL(u202)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
@@ -185,7 +186,7 @@ if (nlotot.gt.0) then
 ! rotate local-orbitals (active transformation)
         do ilo=1,nlorb(is)
           l=lorbl(ilo,is)
-          lm=l*(l+1)-l+1
+          lm=l**2+1
           i=ngk(jspn,ik)+idxlo(lm,ilo,ias)
           j=ngk(jspn,ik)+idxlo(lm,ilo,jas)
           call rotzflm(symlatc(:,:,lspl),l,l,lolmmax,nstfv,nmatmax, &
