@@ -13,6 +13,8 @@ use moddftu
 use modulr
 use modmpi
 use modomp
+use modvars
+use modramdisk
 ! !DESCRIPTION:
 !   Computes the self-consistent Kohn-Sham ground-state. General information is
 !   written to the file {\tt INFO.OUT}. First- and second-variational
@@ -38,6 +40,7 @@ call init0
 call init1
 ! initialise q-vector-dependent variables if required
 if (xctype(1).lt.0) call init2
+wrtdsk0=wrtdsk
 ! apply strain to the G, k, G+k and q-vectors if required
 call straingkq
 if (task.eq.0) trdstate=.false.
@@ -75,8 +78,6 @@ if (mp_mpi) then
   open(65,file='RMSDVS'//trim(filext),form='FORMATTED')
 ! open DTOTENERGY.OUT
   open(66,file='DTOTENERGY'//trim(filext),form='FORMATTED')
-! open TMDFTU.OUT
-  if (tmwrite) open(67,file='TMDFTU'//trim(filext),form='FORMATTED')
 ! open MOMENTM.OUT
   if (spinpol) open(68,file='MOMENTM'//trim(filext),form='FORMATTED')
 ! open RESIDUAL.OUT
@@ -143,8 +144,8 @@ do iscl=1,maxscl
     tlast=.true.
   end if
   if (mp_mpi) flush(60)
-! reset the OpenMP thread variables
-  call omp_reset
+! always write the eigenvectors to disk on the last loop
+  if (tlast) wrtdsk=.true.
 ! generate the core wavefunctions and densities
   call gencore
 ! find the new linearisation energies
@@ -191,13 +192,7 @@ do iscl=1,maxscl
 ! write the DFT+U matrices to file
       call writedftu
 ! calculate and write tensor moments to file
-      if (tmwrite) then
-        if (spinorb) then
-          call writetm3du(67)
-        else
-          call writetm2du(67)
-        end if
-      end if
+      if (tmwrite) call writetm3
     end if
   end if
 ! compute the Kohn-Sham potentials and magnetic fields
@@ -211,7 +206,7 @@ do iscl=1,maxscl
 ! mix the old effective potential and field with the new
   call mixerifc(mixtype,nmix,vsbs,dv,nwork,work)
 ! calculate and add the fixed spin moment effective field (after mixing)
-  call fsmbfield
+  call bfieldfsm
   call addbfsm
 ! Fourier transform Kohn-Sham potential to G-space
   call genvsig
@@ -255,10 +250,14 @@ do iscl=1,maxscl
     flush(64)
 ! output effective fields for fixed spin moment calculations
     if (fsmtype.ne.0) call writefsm(60)
-! check for WRITE file
+! check for existence of the WRITE file
     call checkwrite(twrite)
+! check self-consistent loop number modulo nwrite
+    if (nwrite.ge.1) then
+      if (mod(iscl,nwrite).eq.0) twrite=.true.
+    end if
 ! write STATE.OUT file if required
-    if (twrite.or.((nwrite.ge.1).and.(mod(iscl,nwrite).eq.0))) then
+    if (twrite) then
       call writestate
       write(60,*)
       write(60,'("Wrote STATE.OUT")')
@@ -382,12 +381,25 @@ if (mp_mpi) then
   close(65)
 ! close the DTOTENERGY.OUT file
   close(66)
-! close TMDFTU.OUT file
-  if (tmwrite) close(67)
 ! close the RESIDUAL.OUT file
   if (xctype(1).lt.0) close(69)
+! write to VARIABLES.OUT if required
+  if (wrtvars) then
+    call writevars('engytot',rv=engytot)
+    call writevars('fermidos',rv=fermidos)
+    call writevars('bandgap',nv=2,rva=bandgap)
+    if (spinpol) then
+      call writevars('momtot',nv=ndmag,rva=momtot)
+      call writevars('momtotm',rv=momtotm)
+      call writevars('mommt',nv=3*natmtot,rva=mommt)
+    end if
+    if (tforce) then
+      call writevars('forcetot',nv=3*natmtot,rva=forcetot)
+    end if
+  end if
 end if
 deallocate(work)
+wrtdsk=wrtdsk0
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
 end subroutine
