@@ -9,7 +9,6 @@ use modphonon
 use modbog
 use modmpi
 use modomp
-use modstore
 implicit none
 ! local variables
 integer nmix,nwork
@@ -29,10 +28,10 @@ call genapwlofr
 call gensocfr
 call genevfsv
 ! precise determination of the Fermi energy
-swidth_=swidth
+swidth0=swidth
 swidth=1.d-5
 call occupy
-swidth=swidth_
+swidth=swidth0
 ! initialise electron-phonon variables
 call initeph
 ! size of mixing vector for electron and phonon density matrices (complex array)
@@ -90,6 +89,8 @@ do iscl=1,maxscl
   if (mp_mpi) then
 ! write the electronic eigenvalues to file
     call writeevaluv
+! write the phononic eigenvalues to file
+    call writeevalwx
 ! write the Fermi energy to file
     call writefermi
     write(60,*)
@@ -101,6 +102,8 @@ do iscl=1,maxscl
     write(60,*)
     write(60,'("Estimated indirect band gap : ",G18.10)') bandgap(1)
     write(60,'(" from k-point ",I6," to k-point ",I6)') ikgap(1),ikgap(2)
+    write(60,'("Estimated direct band gap   : ",G18.10)') bandgap(2)
+    write(60,'(" at k-point ",I6)') ikgap(3)
     write(60,*)
     write(60,'("Fermionic anomalous correlation entropy : ",G18.10)') face
     write(60,*)
