@@ -9,7 +9,6 @@ use modulr
 use moddftu
 use modmpi
 use modomp
-use modstore
 implicit none
 ! local variables
 logical twrite
@@ -34,7 +33,7 @@ if (spincore) then
   stop
 end if
 ! no k-point reduction
-reducek_=reducek
+reducek0=reducek
 reducek=0
 ! initialise global variables
 call init0
@@ -183,7 +182,7 @@ do iscl=1,maxscl
 ! multiply the RMS change in potential by the number of Q-points
   dv=dv*dble(nfqrz)
 ! calculate and add the fixed spin moment effective field (after mixing)
-  call fsmbfield
+  call bfieldfsm
   call addbfsmu
   if (mp_mpi) then
 ! write eigenvalues to file
@@ -202,10 +201,14 @@ do iscl=1,maxscl
     end if
 ! output effective fields for fixed spin moment calculations
     if (fsmtype.ne.0) call writefsm(60)
-! check for WRITE file
+! check for existence of the WRITE file
     call checkwrite(twrite)
+! check self-consistent loop number modulo nwrite
+    if (nwrite.ge.1) then
+      if (mod(iscl,nwrite).eq.0) twrite=.true.
+    end if
 ! write STATE_ULR.OUT file if required
-    if (twrite.or.((nwrite.ge.1).and.(mod(iscl,nwrite).eq.0))) then
+    if (twrite) then
       call writestulr
       write(60,*)
       write(60,'("Wrote STATE_ULR.OUT")')
@@ -241,6 +244,13 @@ do iscl=1,maxscl
 end do
 10 continue
 if (mp_mpi) then
+! output timing information
+  write(60,*)
+  write(60,'("Timings (CPU seconds) :")')
+  write(60,'(" Hamiltonian matrix set up",T40,": ",F12.2)') timemat
+  write(60,'(" eigenvalue equation",T40,": ",F12.2)') timesv
+  write(60,'(" charge density calculation",T40,": ",F12.2)') timerho
+  write(60,'(" potential calculation",T40,": ",F12.2)') timepot
   write(60,*)
   write(60,'("+------------------------------+")')
   write(60,'("| Self-consistent loop stopped |")')
@@ -261,7 +271,7 @@ do ir=1,nqpt
 end do
 deallocate(lock,work)
 ! restore original parameters
-reducek=reducek_
+reducek=reducek0
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
 end subroutine
