@@ -24,7 +24,7 @@ call holdthd(natmtot,nthd)
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
-  call gradrfmt(nrmt(is),nrmti(is),rlmt(:,1,is),rlmt(:,-1,is),rfmt(:,ias),ld, &
+  call gradrfmt(nrmt(is),nrmti(is),rlmt(:,-1,is),wcrmt(:,:,is),rfmt(:,ias),ld, &
    grfmt(1,ias,1))
 end do
 !$OMP END PARALLEL DO
@@ -44,6 +44,5 @@ do i=1,3
   grfir(:,i)=dble(zfft2(:))
 end do
 deallocate(zfft1,zfft2)
-return
 end subroutine
 
