@@ -19,8 +19,8 @@ use modmain
 !   grfmt : gradient of rfmt (out,real(ld,3))
 ! !DESCRIPTION:
 !   Calculates the gradient of a real muffin-tin function. In other words, given
-!   the real spherical harmonic expansion coefficients, $f_{lm}(r)$, of a
-!   function $f({\bf r})$, the routine returns ${\bf F}_{lm}$ where
+!   the real spherical harmonic expansion coefficients $f_{lm}(r)$ of a function
+!   $f({\bf r})$, the routine returns ${\bf F}_{lm}$ where
 !   $$ \sum_{lm}{\bf F}_{lm}(r)R_{lm}(\hat{\bf r})=\nabla f({\bf r}), $$
 !   and $R_{lm}$ is a real spherical harmonic function. This is done by first
 !   converting the function to a complex spherical harmonic expansion and then
@@ -33,8 +33,7 @@ use modmain
 implicit none
 ! arguments
 integer, intent(in) :: nr,nri
-real(8), intent(in) :: ri(nr),wcr(12,nr)
-real(8), intent(in) :: rfmt(*)
+real(8), intent(in) :: ri(nr),wcr(12,nr),rfmt(*)
 integer, intent(in) :: ld
 real(8), intent(out) :: grfmt(ld,3)
 ! local variables
