@@ -6,7 +6,6 @@
 subroutine gwbandstr
 use modmain
 use modgw
-use modstore
 use modmpi
 use modomp
 implicit none
@@ -19,7 +18,7 @@ real(8), allocatable :: bmt(:,:,:),bir(:,:)
 real(8), allocatable :: wr(:),sf(:)
 complex(8), allocatable :: se(:,:,:)
 ! store original parameters
-vkloff_(:)=vkloff(:)
+vkloff0(:)=vkloff(:)
 ! initialise universal variables
 call init0
 call init1
@@ -100,7 +99,7 @@ if (mp_mpi) then
   write(*,'(" GW spectral function band structure written to GWBAND.OUT")')
 end if
 ! restore original input parameters
-vkloff(:)=vkloff_(:)
+vkloff(:)=vkloff0(:)
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
 end subroutine
