@@ -10,7 +10,7 @@ use modmpi
 use modomp
 implicit none
 ! local variables
-integer ik,nthd
+integer ik,lp,nthd
 ! initialise universal variables
 call init0
 call init1
@@ -35,7 +35,18 @@ do ik=1,nkpt
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
+! broadcast occupation number array to every MPI process
+if (np_mpi.gt.1) then
+  do ik=1,nkpt
+    lp=mod(ik-1,np_mpi)
+    call mpi_bcast(occsv(:,ik),nstsv,mpi_double_precision,lp,mpicom,ierror)
+  end do
+end if
 if (mp_mpi) then
+! write the occupation numbers to file
+  do ik=1,nkpt
+    call putoccsv(filext,ik,occsv(:,ik))
+  end do
   write(*,*)
   write(*,'("Info(gwdmat):")')
   write(*,'(" GW density matrices determined for each k-point")')
