@@ -10,7 +10,7 @@ use modmpi
 use modomp
 implicit none
 ! local variables
-integer ik,nthd
+integer ik,lp,nthd
 ! compute the GW density matrices and write the natural orbitals and occupation
 ! numbers to EVECSV.OUT and OCCSV.OUT, respectively
 call holdthd(nkpt/np_mpi,nthd)
@@ -23,6 +23,19 @@ do ik=1,nkpt
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
+! broadcast occupation number array to every MPI process
+if (np_mpi.gt.1) then
+  do ik=1,nkpt
+    lp=mod(ik-1,np_mpi)
+    call mpi_bcast(occsv(:,ik),nstsv,mpi_double_precision,lp,mpicom,ierror)
+  end do
+end if
+! write the occupation numbers to file
+if (mp_mpi) then
+  do ik=1,nkpt
+    call putoccsv(filext,ik,occsv(:,ik))
+  end do
+end if
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
 ! determine the density and magnetisation in the usual way
