@@ -10,18 +10,14 @@ use modmpi
 use modomp
 implicit none
 ! local variables
-logical exist
 integer ik,nthd
-integer nwork,n
+integer nmix,nwork
 real(8) dv
 ! allocatable arrays
 real(8), allocatable :: vmt(:,:),vir(:)
 real(8), allocatable :: bmt(:,:,:),bir(:,:)
-real(8), allocatable :: v(:),work(:)
+real(8), allocatable :: work(:)
 complex(8), allocatable :: se(:,:,:)
-! external functions
-real(8) rfint
-external rfint
 ! initialise universal variables
 call init0
 call init1
@@ -32,8 +28,13 @@ call readstate
 call genvsig
 ! read the Fermi energy
 call readfermi
-! determine the constant part of the LDA/GGA exchange-correlation potential
-vxc0=rfint(vxcmt,vxcir)/omega
+! zero the exchange-correlation potential and magnetic field
+vxcmt(:,:)=0.d0
+vxcir(:)=0.d0
+if (spinpol) then
+  bxcmt(:,:,:)=0.d0
+  bxcir(:,:)=0.d0
+end if
 ! re-calculate the ground-state
 call gencore
 call linengy
@@ -45,15 +46,6 @@ allocate(vmt(npcmtmax,natmtot),vir(ngtot))
 if (spinpol) then
   allocate(bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag))
 end if
-n=npmtmax*natmtot+ngtot
-if (spinpol) n=n+ndmag*(npcmtmax*natmtot+ngtot)
-allocate(v(n))
-nwork=-1
-call mixerifc(mixtype,n,v,dv,nwork,v)
-allocate(work(nwork))
-iscl=0
-call mixpack(.true.,n,v)
-call mixerifc(mixtype,n,v,dv,nwork,work)
 if (mp_mpi) then
 ! open GW_INFO.OUT file
   open(60,file='GW_INFO.OUT',form='FORMATTED')
@@ -76,6 +68,17 @@ if (mp_mpi) then
   write(60,'("| Self-consistent loop started |")')
   write(60,'("+------------------------------+")')
 end if
+! size of mixing vector
+nmix=size(vsbs)
+! determine the size of the mixer work array
+nwork=-1
+call mixerifc(mixtype,nmix,vsbs,dv,nwork,vsbs)
+allocate(work(nwork))
+! initialise the mixer
+iscl=0
+call mixerifc(mixtype,nmix,vsbs,dv,nwork,work)
+! set the stop signal to .false.
+tstop=.false.
 ! set last self-consistent loop flag
 tlast=.false.
 do iscl=1,maxscl
@@ -130,16 +133,9 @@ do iscl=1,maxscl
   call gwrhomag
 ! invert the Kohn-Sham equations to find V_s and B_s
   call ksinvert
-! pack interstitial and muffin-tin potential and field into one array
-  call mixpack(.true.,n,v)
-! mix in the old potential and field with the new
-  call mixerifc(mixtype,n,v,dv,nwork,work)
-! make sure every MPI process has a numerically identical potential
-  if (np_mpi.gt.1) then
-    call mpi_bcast(v,n,mpi_double_precision,0,mpicom,ierror)
-  end if
-! unpack potential and field
-  call mixpack(.false.,n,v)
+! mix the old effective potential and field with the new
+  call mixerifc(mixtype,nmix,vsbs,dv,nwork,work)
+! Fourier transform Kohn-Sham potential to G-space
   call genvsig
   if (mp_mpi) then
 ! write the Kohn-Sham occupation numbers to file
@@ -202,17 +198,9 @@ do iscl=1,maxscl
       tlast=.true.
     end if
   end if
-! check for STOP file (only master process)
-  if (mp_mpi) then
-    inquire(file='STOP',exist=exist)
-    if (exist) then
-      write(60,*)
-      write(60,'("STOP file exists - stopping self-consistent loop")')
-      open(50,file='STOP')
-      close(50,status='DELETE')
-      tlast=.true.
-    end if
-  end if
+! check for STOP file
+  call checkstop
+  if (tstop) tlast=.true.
 ! broadcast tlast from master process to all other processes
   call mpi_bcast(tlast,1,mpi_logical,0,mpicom,ierror)
 ! reset the OpenMP thread variables
@@ -244,6 +232,5 @@ if (mp_mpi) then
 end if
 deallocate(vmt,vir)
 if (spinpol) deallocate(bmt,bir)
-return
 end subroutine
 
