@@ -20,7 +20,7 @@ integer iw,jw,it,nthd
 real(8) vl(3),vc(3),t1,t2
 complex(8) z1,z2
 ! automatic arrays
-integer idx(nstsv)
+complex(8) zfgq(ngrf)
 ! allocatable arrays
 integer(8), allocatable :: lock(:)
 real(8), allocatable :: vgqc(:,:),gqc(:),gclgq(:)
@@ -31,7 +31,7 @@ complex(8), allocatable :: wfmt1(:,:,:,:),wfir1(:,:,:)
 complex(8), allocatable :: wfmt2(:,:,:,:),wfir2(:,:,:)
 complex(8), allocatable :: zrhomt(:,:,:),zrhoir(:,:)
 complex(8), allocatable :: zvclmt(:,:),zvclir(:)
-complex(8), allocatable :: zfgq(:),zrho(:,:,:),epsi(:,:,:)
+complex(8), allocatable :: zrho(:,:,:),epsi(:,:,:)
 complex(8), allocatable :: v(:,:),stau(:,:,:)
 complex(8), allocatable :: gs(:,:),wc(:,:),zv(:)
 ! external functions
@@ -57,12 +57,8 @@ call getevecfv(filext,ikp,vkl(:,ikp),vgkl(:,:,:,ikp),evecfv)
 call getevecsv(filext,ikp,vkl(:,ikp),evecsv)
 ! find the matching coefficients
 call match(ngk(1,ikp),vgkc(:,:,1,ikp),gkc(:,1,ikp),sfacgk(:,:,1,ikp),apwalm)
-! index to all states
-do ist1=1,nstsv
-  idx(ist1)=ist1
-end do
 ! calculate the wavefunctions for all states of the input k-point
-call genwfsv(.false.,.true.,nstsv,idx,ngdgc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
+call genwfsv(.false.,.true.,nstsv,0,ngdgc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
  apwalm,evecfv,evecsv,wfmt1,ngtc,wfir1)
 ! local -V_xc and -B_xc matrix elements
 if (spinpol) then
@@ -85,7 +81,7 @@ do ik=1,nkptnr
   iv(:)=modulo(iv(:),ngridk(:))
 ! check if the q-point is in user-defined set
   iv(:)=iv(:)*ngridq(:)
-  if (any(modulo(iv(:),ngridk(:)).ne.0)) cycle
+  if (any(mod(iv(:),ngridk(:)).ne.0)) cycle
   iv(:)=iv(:)/ngridk(:)
   iq=ivqiq(iv(1),iv(2),iv(3))
   vl(:)=vkl(:,ikp)-vkl(:,ik)
@@ -111,16 +107,14 @@ do ik=1,nkptnr
   call getevecfv(filext,0,vkl(:,ik),vgkl(:,:,1,ik),evecfv)
   call getevecsv(filext,0,vkl(:,ik),evecsv)
 ! calculate the wavefunctions for all states
-  call genwfsv(.false.,.false.,nstsv,idx,ngdgc,igfc,ngk(1,ik),igkig(:,1,ik), &
+  call genwfsv(.false.,.false.,nstsv,0,ngdgc,igfc,ngk(1,ik),igkig(:,1,ik), &
    apwalm,evecfv,evecsv,wfmt2,ngtc,wfir2)
 ! determine the complex densities and Fourier transform to G+q-space
   do ist3=1,nstsv
     call holdthd(nstsv,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(zfgq) &
 !$OMP NUM_THREADS(nthd)
-    allocate(zfgq(ngrf))
-!$OMP DO
     do ist1=1,nstsv
       call genzrho(.true.,.true.,ngtc,wfmt2(:,:,:,ist3),wfir2(:,:,ist3), &
        wfmt1(:,:,:,ist1),wfir1(:,:,ist1),zrhomt(:,:,ist1),zrhoir(:,ist1))
@@ -128,9 +122,7 @@ do ik=1,nkptnr
        zfgq)
       zrho(ist1,:,ist3)=conjg(zfgq(:))
     end do
-!$OMP END DO
-    deallocate(zfgq)
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
     call freethd(nthd)
 !--------------------------------------!
 !     valence Fock matrix elements     !
@@ -148,9 +140,8 @@ do ik=1,nkptnr
 ! calculate the Coulomb potential
       call genzvclmt(nrcmt,nrcmti,nrcmtmax,rlcmt,wprcmt,npcmtmax, &
        zrhomt(:,:,ist2),zvclmt)
-      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rlcmt,ngdgc,igfc,ngvc, &
-       gqc,gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir(:,ist2),npcmtmax,zvclmt, &
-       zvclir)
+      call zpotcoul(nrcmt,nrcmti,npcmt,nrcmtmax,rlcmt,ngdgc,igfc,ngvc,gqc, &
+       gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir(:,ist2),npcmtmax,zvclmt,zvclir)
       zvclir(:)=zvclir(:)*cfrc(:)
       do ist1=1,ist2
         z1=zfinp(zrhomt(:,:,ist1),zrhoir(:,ist1),zvclmt,zvclir)
@@ -297,7 +288,6 @@ call freethd(nthd)
 deallocate(vgqc,gqc,gclgq,jlgqr,jlgqrmt)
 deallocate(ylmgq,sfacgq,apwalm,evecfv,evecsv)
 deallocate(wfmt1,wfir1,wfmt2,wfir2)
-deallocate(zrhomt,zrhoir,zrho)
-deallocate(epsi,v,gs)
+deallocate(zrhomt,zrhoir,zrho,epsi,v,gs)
 end subroutine
 
