@@ -3,11 +3,10 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine hflocal(hyb,vmt,vir,bmt,bir)
+subroutine hflocal(vmt,vir,bmt,bir)
 use modmain
 implicit none
 ! arguments
-logical, intent(in) :: hyb
 real(8), intent(out) :: vmt(npcmtmax,natmtot),vir(ngtot)
 real(8), intent(out) :: bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag)
 ! local variables
@@ -18,7 +17,7 @@ real(8) rfmt1(npmtmax),rfmt2(npcmtmax)
 ! compute the Coulomb potential
 call potcoul
 ! convert to spherical coordinates and store in output arrays
-if (hyb) then
+if (hybrid) then
 ! hybrid functional case
   call potxc(.true.,xctype,rhomt,rhoir,magmt,magir,taumt,tauir,exmt,exir,ecmt, &
    ecir,vxcmt,vxcir,bxcmt,bxcir,wxcmt,wxcir)
@@ -30,6 +29,7 @@ if (hyb) then
     rfmt1(1:np)=vclmt(1:np,ias)+vxcmt(1:np,ias)
     call rfmtftoc(nrc,nrci,rfmt1,rfmt2)
     call rbsht(nrc,nrci,rfmt2,vmt(:,ias))
+    call rfcmtwr(nrc,nrci,wrcmt(:,is),vmt(:,ias))
   end do
   vir(:)=(vclir(:)+vxcir(:))*cfunir(:)
   if (spinpol) then
@@ -40,6 +40,7 @@ if (hyb) then
         nrci=nrcmti(is)
         call rfmtftoc(nrc,nrci,bxcmt(:,ias,idm),rfmt1)
         call rbsht(nrc,nrci,rfmt1,bmt(:,ias,idm))
+        call rfcmtwr(nrc,nrci,wrcmt(:,is),bmt(:,ias,idm))
       end do
       bir(:,idm)=bxcir(:,idm)*cfunir(:)
     end do
@@ -52,9 +53,9 @@ else
     nrci=nrcmti(is)
     call rfmtftoc(nrc,nrci,vclmt(:,ias),rfmt1)
     call rbsht(nrc,nrci,rfmt1,vmt(:,ias))
+    call rfcmtwr(nrc,nrci,wrcmt(:,is),vmt(:,ias))
   end do
   vir(:)=vclir(:)*cfunir(:)
 end if
-return
 end subroutine
 
