@@ -11,9 +11,8 @@ implicit none
 ! local variables
 integer ik2,nthd
 call holdthd(nkptnr/np_mpi,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
 do ik2=1,nkptnr
 ! distribute among MPI processes
   if (mod(ik2-1,np_mpi).ne.lp_mpi) cycle
@@ -22,9 +21,7 @@ do ik2=1,nkptnr
 !$OMP END CRITICAL(hmldbse_)
   call hmldbsek(ik2)
 end do
-!$OMP END DO
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
 call freethd(nthd)
-return
 end subroutine
 
