@@ -16,7 +16,7 @@ integer iv(3),iq,ig,jg,nthd
 real(8) vl(3),vc(3),t0,t1,t2
 complex(8) z1
 ! automatic arrays
-integer idx(nstsv),ngp(nspnfv)
+integer ngp(nspnfv)
 ! allocatable arrays
 integer, allocatable :: igpig(:,:)
 real(8), allocatable :: vgqc(:,:),gqc(:),gclgq(:),jlgqr(:,:,:)
@@ -39,17 +39,13 @@ if (bsefull) then
   allocate(zvc(ngrf,nvbse,ncbse))
   allocate(zcv(ngrf,ncbse,nvbse))
 end if
-! index to all states
-do ist1=1,nstsv
-  idx(ist1)=ist1
-end do
 ! generate the wavefunctions for all states of k-point ik2
-call genwfsvp(.false.,.false.,nstsv,idx,ngdgc,igfc,vkl(:,ik2),ngp,igpig,wfmt2, &
+call genwfsvp(.false.,.false.,nstsv,0,ngdgc,igfc,vkl(:,ik2),ngp,igpig,wfmt2, &
  ngtc,wfir2)
 ! begin loop over ik1
 do ik1=1,nkptnr
 ! generate the wavefunctions for all states of k-point ik1
-  call genwfsvp(.false.,.false.,nstsv,idx,ngdgc,igfc,vkl(:,ik1),ngp,igpig, &
+  call genwfsvp(.false.,.false.,nstsv,0,ngdgc,igfc,vkl(:,ik1),ngp,igpig, &
    wfmt1,ngtc,wfir1)
 ! determine equivalent q-vector in first Brillouin zone
   iv(:)=ivk(:,ik1)-ivk(:,ik2)
