@@ -6,7 +6,7 @@
 !BOP
 ! !ROUTINE: hmlistl
 ! !INTERFACE:
-subroutine hmlistl(ngp,igpig,vgpc,ld,h)
+pure subroutine hmlistl(ngp,igpig,vgpc,ld,h)
 ! !USES:
 use modmain
 ! !INPUT/OUTPUT PARAMETERS:
@@ -32,26 +32,21 @@ implicit none
 integer, intent(in) :: ngp,igpig(ngkmax)
 real(8), intent(in) :: vgpc(3,ngkmax)
 integer, intent(in) :: ld
-complex(8), intent(inout) :: h(*)
+complex(8), intent(inout) :: h(ld,*)
 ! local variables
-integer i1,i2,i3,j1,j2,j3
-integer ig,i,j,k
+integer ig,j1,j2,j3,i,j
 real(8) v1,v2,v3,t1
 do j=1,ngp
-  k=(j-1)*ld
   ig=igpig(j)
   j1=ivg(1,ig); j2=ivg(2,ig); j3=ivg(3,ig)
   v1=0.5d0*vgpc(1,j); v2=0.5d0*vgpc(2,j); v3=0.5d0*vgpc(3,j)
   do i=1,j
-    k=k+1
     ig=igpig(i)
-    i1=ivg(1,ig)-j1; i2=ivg(2,ig)-j2; i3=ivg(3,ig)-j3
-    ig=ivgig(i1,i2,i3)
+    ig=ivgig(ivg(1,ig)-j1,ivg(2,ig)-j2,ivg(3,ig)-j3)
     t1=vgpc(1,i)*v1+vgpc(2,i)*v2+vgpc(3,i)*v3
-    h(k)=h(k)+vsig(ig)+t1*cfunig(ig)
+    h(i,j)=h(i,j)+vsig(ig)+t1*cfunig(ig)
   end do
 end do
-return
 end subroutine
 !EOC
 
