@@ -32,24 +32,22 @@ use modomp
 implicit none
 ! local variables
 integer is,ias,nthd
-integer nr,nri,iro
-integer ir,npi,i
-integer l1,l2,l3,m2,lm2
+integer nr,nri,iro,i0,i1
+integer l1,l2,l3,lm2
 integer io,jo,ilo,jlo
-real(8) sm,t1
+real(8) sm
 ! begin loops over atoms and species
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
-!$OMP PRIVATE(is,nr,nri,iro,npi) &
+!$OMP PRIVATE(is,nr,nri,iro) &
 !$OMP PRIVATE(l1,l2,l3,io,jo,sm) &
-!$OMP PRIVATE(lm2,m2,i,ir,t1,ilo,jlo) &
+!$OMP PRIVATE(lm2,i0,i1,ilo,jlo) &
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
   nri=nrmti(is)
   iro=nri+1
-  npi=npmti(is)
 !---------------------------!
 !     APW-APW integrals     !
 !---------------------------!
@@ -65,36 +63,25 @@ do ias=1,natmtot
             haa(1,jo,l3,io,l1,ias)=0.d0
           end if
           if (l1.ge.l3) then
-            lm2=1
             do l2=1,lmaxi
-              do m2=-l2,l2
-                lm2=lm2+1
-                sm=0.d0
-                i=lm2
-                do ir=1,nri
-                  t1=apwfr(ir,1,io,l1,ias)*apwfr(ir,1,jo,l3,ias)*wrmt(ir,is)
-                  sm=sm+t1*vsmt(i,ias)
-                  i=i+lmmaxi
-                end do
-                do ir=iro,nr
-                  t1=apwfr(ir,1,io,l1,ias)*apwfr(ir,1,jo,l3,ias)*wrmt(ir,is)
-                  sm=sm+t1*vsmt(i,ias)
-                  i=i+lmmaxo
-                end do
+              do lm2=l2**2+1,(l2+1)**2
+                i1=lmmaxi*(nri-1)+lm2
+                sm=sum(apwfr(1:nri,1,io,l1,ias)*apwfr(1:nri,1,jo,l3,ias) &
+                 *wrmt(1:nri,is)*vsmt(lm2:i1:lmmaxi,ias))
+                i0=i1+lmmaxi
+                i1=lmmaxo*(nr-iro)+i0
+                sm=sm+sum(apwfr(iro:nr,1,io,l1,ias)*apwfr(iro:nr,1,jo,l3,ias) &
+                 *wrmt(iro:nr,is)*vsmt(i0:i1:lmmaxo,ias))
                 haa(lm2,jo,l3,io,l1,ias)=sm
                 haa(lm2,io,l1,jo,l3,ias)=sm
               end do
             end do
             do l2=lmaxi+1,lmaxo
-              do m2=-l2,l2
-                lm2=lm2+1
-                sm=0.d0
-                i=npi+lm2
-                do ir=iro,nr
-                  t1=apwfr(ir,1,io,l1,ias)*apwfr(ir,1,jo,l3,ias)*wrmt(ir,is)
-                  sm=sm+t1*vsmt(i,ias)
-                  i=i+lmmaxo
-                end do
+              do lm2=l2**2+1,(l2+1)**2
+                i0=lmmaxi*nri+lm2
+                i1=lmmaxo*(nr-iro)+i0
+                sm=sum(apwfr(iro:nr,1,io,l1,ias)*apwfr(iro:nr,1,jo,l3,ias) &
+                 *wrmt(iro:nr,is)*vsmt(i0:i1:lmmaxo,ias))
                 haa(lm2,jo,l3,io,l1,ias)=sm
                 haa(lm2,io,l1,jo,l3,ias)=sm
               end do
@@ -117,35 +104,24 @@ do ias=1,natmtot
         else
           hloa(1,io,l3,ilo,ias)=0.d0
         end if
-        lm2=1
         do l2=1,lmaxi
-          do m2=-l2,l2
-            lm2=lm2+1
-            sm=0.d0
-            i=lm2
-            do ir=1,nri
-              t1=lofr(ir,1,ilo,ias)*apwfr(ir,1,io,l3,ias)*wrmt(ir,is)
-              sm=sm+t1*vsmt(i,ias)
-              i=i+lmmaxi
-            end do
-            do ir=nri+1,nr
-              t1=lofr(ir,1,ilo,ias)*apwfr(ir,1,io,l3,ias)*wrmt(ir,is)
-              sm=sm+t1*vsmt(i,ias)
-              i=i+lmmaxo
-            end do
+          do lm2=l2**2+1,(l2+1)**2
+            i1=lmmaxi*(nri-1)+lm2
+            sm=sum(lofr(1:nri,1,ilo,ias)*apwfr(1:nri,1,io,l3,ias) &
+             *wrmt(1:nri,is)*vsmt(lm2:i1:lmmaxi,ias))
+            i0=i1+lmmaxi
+            i1=lmmaxo*(nr-iro)+i0
+            sm=sm+sum(lofr(iro:nr,1,ilo,ias)*apwfr(iro:nr,1,io,l3,ias) &
+             *wrmt(iro:nr,is)*vsmt(i0:i1:lmmaxo,ias))
             hloa(lm2,io,l3,ilo,ias)=sm
           end do
         end do
         do l2=lmaxi+1,lmaxo
-          do m2=-l2,l2
-            lm2=lm2+1
-            sm=0.d0
-            i=npi+lm2
-            do ir=iro,nr
-              t1=lofr(ir,1,ilo,ias)*apwfr(ir,1,io,l3,ias)*wrmt(ir,is)
-              sm=sm+t1*vsmt(i,ias)
-              i=i+lmmaxo
-            end do
+          do lm2=l2**2+1,(l2+1)**2
+            i0=lmmaxi*nri+lm2
+            i1=lmmaxo*(nr-iro)+i0
+            sm=sum(lofr(iro:nr,1,ilo,ias)*apwfr(iro:nr,1,io,l3,ias) &
+             *wrmt(iro:nr,is)*vsmt(i0:i1:lmmaxo,ias))
             hloa(lm2,io,l3,ilo,ias)=sm
           end do
         end do
@@ -165,35 +141,24 @@ do ias=1,natmtot
       else
         hlolo(1,jlo,ilo,ias)=0.d0
       end if
-      lm2=1
       do l2=1,lmaxi
-        do m2=-l2,l2
-          lm2=lm2+1
-          sm=0.d0
-          i=lm2
-          do ir=1,nri
-            t1=lofr(ir,1,ilo,ias)*lofr(ir,1,jlo,ias)*wrmt(ir,is)
-            sm=sm+t1*vsmt(i,ias)
-            i=i+lmmaxi
-          end do
-          do ir=iro,nr
-            t1=lofr(ir,1,ilo,ias)*lofr(ir,1,jlo,ias)*wrmt(ir,is)
-            sm=sm+t1*vsmt(i,ias)
-            i=i+lmmaxo
-          end do
+        do lm2=l2**2+1,(l2+1)**2
+          i1=lmmaxi*(nri-1)+lm2
+          sm=sum(lofr(1:nri,1,ilo,ias)*lofr(1:nri,1,jlo,ias)*wrmt(1:nri,is) &
+           *vsmt(lm2:i1:lmmaxi,ias))
+          i0=i1+lmmaxi
+          i1=lmmaxo*(nr-iro)+i0
+          sm=sm+sum(lofr(iro:nr,1,ilo,ias)*lofr(iro:nr,1,jlo,ias) &
+           *wrmt(iro:nr,is)*vsmt(i0:i1:lmmaxo,ias))
           hlolo(lm2,jlo,ilo,ias)=sm
         end do
       end do
       do l2=lmaxi+1,lmaxo
-        do m2=-l2,l2
-          lm2=lm2+1
-          sm=0.d0
-          i=npi+lm2
-          do ir=iro,nr
-            t1=lofr(ir,1,ilo,ias)*lofr(ir,1,jlo,ias)*wrmt(ir,is)
-            sm=sm+t1*vsmt(i,ias)
-            i=i+lmmaxo
-          end do
+        do lm2=l2**2+1,(l2+1)**2
+          i0=lmmaxi*nri+lm2
+          i1=lmmaxo*(nr-iro)+i0
+          sm=sum(lofr(iro:nr,1,ilo,ias)*lofr(iro:nr,1,jlo,ias)*wrmt(iro:nr,is) &
+           *vsmt(i0:i1:lmmaxo,ias))
           hlolo(lm2,jlo,ilo,ias)=sm
         end do
       end do
