@@ -15,7 +15,7 @@ integer is,ias,l
 real(8) t0
 complex(8) z1
 ! automatic arrays
-integer idx(nstsv),ngp(nspnfv)
+integer ngp(nspnfv)
 ! allocatable arrays
 integer, allocatable :: igpig(:,:)
 complex(8), allocatable :: wfmt1(:,:,:,:),wfir1(:,:,:)
@@ -32,12 +32,8 @@ allocate(wfmt2(npcmtmax,natmtot,nspinor,nstsv),wfir2(ngtc,nspinor,nstsv))
 allocate(zrhomt(npcmtmax,natmtot),zrhoir(ngtc))
 allocate(zvclmt(npcmtmax,natmtot,nvcbse),zvclir(ngtc,nvcbse))
 allocate(zfmt(npcmtmax))
-! index to all states
-do ist1=1,nstsv
-  idx(ist1)=ist1
-end do
 ! calculate the wavefunctions for all states of k-point ik2
-call genwfsvp(.false.,.false.,nstsv,idx,ngdgc,igfc,vkl(:,ik2),ngp,igpig,wfmt2, &
+call genwfsvp(.false.,.false.,nstsv,0,ngdgc,igfc,vkl(:,ik2),ngp,igpig,wfmt2, &
  ngtc,wfir2)
 l=0
 do i2=1,nvbse
@@ -52,8 +48,8 @@ do i2=1,nvbse
 ! compute the Coulomb potential
     call genzvclmt(nrcmt,nrcmti,nrcmtmax,rlcmt,wprcmt,npcmtmax,zrhomt, &
      zvclmt(:,:,l))
-    call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rlcmt,ngdgc,igfc,ngvc,gc, &
-     gclg,ngvec,jlgrmt,ylmg,sfacg,zrhoir,npcmtmax,zvclmt(:,:,l),zvclir(:,l))
+    call zpotcoul(nrcmt,nrcmti,npcmt,nrcmtmax,rlcmt,ngdgc,igfc,ngvc,gc,gclg, &
+     ngvec,jlgrmt,ylmg,sfacg,zrhoir,npcmtmax,zvclmt(:,:,l),zvclir(:,l))
     zvclir(:,l)=zvclir(:,l)*cfrc(:)
   end do
 end do
@@ -64,7 +60,7 @@ do ik1=1,nkptnr
     wfmt1(:,:,:,:)=wfmt2(:,:,:,:)
     wfir1(:,:,:)=wfir2(:,:,:)
   else
-    call genwfsvp(.false.,.false.,nstsv,idx,ngdgc,igfc,vkl(:,ik1),ngp,igpig, &
+    call genwfsvp(.false.,.false.,nstsv,0,ngdgc,igfc,vkl(:,ik1),ngp,igpig, &
      wfmt1,ngtc,wfir1)
   end if
   do i1=1,nvbse
