@@ -28,8 +28,8 @@ use modomp
 !BOC
 implicit none
 ! local variables
-integer is,ia,ias,n
-integer ist,nr,l,i
+integer is,ia,ias,idu
+integer ist,nr,l,n,i
 real(8) t1
 real(8) ts0,ts1
 
@@ -61,9 +61,11 @@ lmmaxo=(lmaxo+1)**2
 ! check DOS lmax is within range
 lmaxdos=min(lmaxdos,lmaxo)
 ! write to VARIABLES.OUT
-call writevars('lmaxapw',iv=lmaxapw)
-call writevars('lmaxi',iv=lmaxi)
-call writevars('lmaxo',iv=lmaxo)
+if (wrtvars) then
+  call writevars('lmaxapw',iv=lmaxapw)
+  call writevars('lmaxi',iv=lmaxi)
+  call writevars('lmaxo',iv=lmaxo)
+end if
 
 !------------------------------------!
 !     index to atoms and species     !
@@ -85,11 +87,13 @@ natmtot=ias
 ! number of phonon branches
 nbph=3*natmtot
 ! write to VARIABLES.OUT
-call writevars('nspecies',iv=nspecies)
-call writevars('natoms',nv=nspecies,iva=natoms)
-call writevars('spsymb',nv=nspecies,sva=spsymb)
-call writevars('spname',nv=nspecies,sva=spname)
-call writevars('spzn',nv=nspecies,rva=spzn)
+if (wrtvars) then
+  call writevars('nspecies',iv=nspecies)
+  call writevars('natoms',nv=nspecies,iva=natoms)
+  call writevars('spsymb',nv=nspecies,sva=spsymb)
+  call writevars('spname',nv=nspecies,sva=spname)
+  call writevars('spzn',nv=nspecies,rva=spzn)
+end if
 
 !------------------------!
 !     spin variables     !
@@ -97,7 +101,7 @@ call writevars('spzn',nv=nspecies,rva=spzn)
 if (spinsprl) then
   spinpol=.true.
   spinorb=.false.
-  if (any(task.eq.[5,51,52,53,61,62,63,700,701,800,801])) then
+  if (any(task.eq.[5,51,52,53,61,62,63,700,701])) then
     write(*,*)
     write(*,'("Error(init0): spin-spirals do not work with task ",I4)') task
     write(*,*)
@@ -145,8 +149,8 @@ end if
 tevecsv=.false.
 ! spin-polarised calculations require second-variational eigenvectors
 if (spinpol) tevecsv=.true.
-! Hartree-Fock/RDMFT/TDDFT/GW requires second-variational eigenvectors
-if (any(task.eq.[5,10,170,300,460,461,462,463,600,620,630,800,801])) then
+! Hartree-Fock/RDMFT/TDDFT/GW/ULR requires second-variational eigenvectors
+if (any(task.eq.[5,10,170,300,460,461,462,463,600,620,630,700,701])) then
   tevecsv=.true.
 end if
 ! get exchange-correlation functional data
@@ -244,18 +248,23 @@ if (reducebf.lt.1.d0-1.d-4) then
     bfcmt(:,:,:)=0.d0
   end if
 end if
-! set the fixed tensor moment spatial and spin rotation matrices equal for the
-! case of spin-orbit coupling; parity for spin is ignored by rotdmat
-if (spinorb) then
-  do i=1,ntmfix
-    rtmfix(:,:,2,i)=rtmfix(:,:,1,i)
-  end do
+if (tmwrite.or.(ftmtype.ne.0).or.(task.eq.400)) then
+  if (.not.spinorb) then
+    write(*,*)
+    write(*,'("Error(init0): tensor moments require spin-orbit coupling &
+     &enabled")')
+    write(*,'(" set spinorb=.true.")')
+    write(*,*)
+    stop
+  end if
 end if
 ! generate the fixed tensor moment density matrices if required
-call gendmftm
+if (ftmtype.ne.0) call gendmftm
 ! write to VARIABLES.OUT
-call writevars('nspinor',iv=nspinor)
-call writevars('ndmag',iv=ndmag)
+if (wrtvars) then
+  call writevars('nspinor',iv=nspinor)
+  call writevars('ndmag',iv=ndmag)
+end if
 
 !----------------------------------!
 !     crystal structure set up     !
@@ -286,18 +295,20 @@ end do
 ! input q-vector in Cartesian coordinates
 call r3mv(bvec,vecql,vecqc)
 ! write to VARIABLES.OUT
-call writevars('avec',nv=9,rva=avec)
-call writevars('bvec',nv=9,rva=bvec)
-call writevars('omega',rv=omega)
-do is=1,nspecies
-  call writevars('atposl',l=is,nv=3*natoms(is),rva=atposl(:,:,is))
-end do
+if (wrtvars) then
+  call writevars('avec',nv=9,rva=avec)
+  call writevars('bvec',nv=9,rva=bvec)
+  call writevars('omega',rv=omega)
+  do is=1,nspecies
+    call writevars('atposl',n1=is,nv=3*natoms(is),rva=atposl(:,:,is))
+  end do
+end if
 
 !-------------------------------!
 !     vector fields E and A     !
 !-------------------------------!
 tefield=.false.
-if (sum(abs(efieldc(:))).gt.epslat) then
+if (any(abs(efieldc(:)).gt.epslat)) then
 ! no shift of the atomic positions
   tshift=.false.
 ! electric field vector in lattice coordinates
@@ -305,7 +316,7 @@ if (sum(abs(efieldc(:))).gt.epslat) then
   tefield=.true.
 end if
 tafield=.false.
-if (sum(abs(afieldc(:))).gt.epslat) then
+if (any(abs(afieldc(:)).gt.epslat)) then
   tafield=.true.
 ! A-field in lattice coordinates
   call r3mv(ainv,afieldc,afieldl)
@@ -394,10 +405,12 @@ end if
 ! effective Wigner radius
 rwigner=(3.d0/(fourpi*(chgtot/omega)))**(1.d0/3.d0)
 ! write to VARIABLES.OUT
-call writevars('spze',nv=nspecies,rva=spze)
-call writevars('chgcr',nv=nspecies,rva=chgcr)
-call writevars('chgexs',rv=chgexs)
-call writevars('chgval',rv=chgtot)
+if (wrtvars) then
+  call writevars('spze',nv=nspecies,rva=spze)
+  call writevars('chgcr',nv=nspecies,rva=chgcr)
+  call writevars('chgexs',rv=chgexs)
+  call writevars('chgval',rv=chgtot)
+end if
 
 !-------------------------!
 !     G-vector arrays     !
@@ -467,12 +480,14 @@ call gengvc
 ! generate the characteristic function on the coarse grid
 call gencfrc
 ! write to VARIABLES.OUT
-call writevars('gmaxvr',rv=gmaxvr)
-call writevars('ngridg',nv=3,iva=ngridg)
-call writevars('intgv',nv=6,iva=intgv)
-call writevars('ngvec',iv=ngvec)
-call writevars('ivg',nv=3*ngtot,iva=ivg)
-call writevars('igfft',nv=ngtot,iva=igfft)
+if (wrtvars) then
+  call writevars('gmaxvr',rv=gmaxvr)
+  call writevars('ngridg',nv=3,iva=ngridg)
+  call writevars('intgv',nv=6,iva=intgv)
+  call writevars('ngvec',iv=ngvec)
+  call writevars('ivg',nv=3*ngtot,iva=ivg)
+  call writevars('igfft',nv=ngtot,iva=igfft)
+end if
 
 !-------------------------!
 !     atoms and cores     !
@@ -595,15 +610,11 @@ if ((xcgrad.eq.3).or.(xcgrad.eq.4)) then
   allocate(taumt(npmtmax,natmtot,nspinor),tauir(ngtot,nspinor))
   allocate(taucr(npmtmax,natmtot,nspinor))
 end if
-! meta-GGA exchange-correlation and Kohn-Sham potentials
+! meta-GGA exchange-correlation potential
 if (allocated(wxcmt)) deallocate(wxcmt)
 if (allocated(wxcir)) deallocate(wxcir)
-if (allocated(wsmt)) deallocate(wsmt)
-if (allocated(wsir)) deallocate(wsir)
 if (xcgrad.eq.4) then
   allocate(wxcmt(npmtmax,natmtot),wxcir(ngtot))
-  allocate(wsmt(npcmtmax,natmtot),wsir(ngtot))
-  tevecsv=.true.
 end if
 ! spin-orbit coupling radial function
 if (allocated(socfr)) deallocate(socfr)
@@ -659,6 +670,13 @@ if ((dftu.ne.0).or.(ftmtype.ne.0)) then
   allocate(vmatmt(lmmaxdm,nspinor,lmmaxdm,nspinor,natmtot))
 ! zero the potential matrix
   vmatmt(:,:,:,:,:)=0.d0
+! matrix elements in spherical coordinates for TDDFT+U
+  if (any(task.eq.[460,461,462,463,478])) then
+    if (allocated(vmatmti)) deallocate(vmatmti)
+    allocate(vmatmti(lmmaxi,lmmaxi,nspinor,nspinor,natmtot))
+    if (allocated(vmatmto)) deallocate(vmatmto)
+    allocate(vmatmto(lmmaxo,lmmaxo,nspinor,nspinor,natmtot))
+  end if
 ! require the potential matrix elements be calculated
   tvmatmt=.true.
 ! flags for non-zero muffin-tin potential matrices
@@ -669,27 +687,36 @@ if ((dftu.ne.0).or.(ftmtype.ne.0)) then
   tevecsv=.true.
 end if
 if (dftu.ne.0) then
+  if (any(task.eq.[5,300,600,610,620,630,640])) then
+    write(*,*)
+    write(*,'("Error(init0): DFT+U does not work with task ",I8)') task
+    write(*,*)
+    stop
+  end if
 ! DFT+U energy for each atom
   if (allocated(engyadu)) deallocate(engyadu)
   allocate(engyadu(natmmax,ndftu))
-! interpolation constants (alpha)
-  if (allocated(alphadu)) deallocate(alphadu)
-  allocate(alphadu(natmmax,ndftu))
 ! flag the muffin-tin potential matrices which are non-zero
-  do i=1,ndftu
-    is=idftu(1,i)
+  do idu=1,ndftu
+    is=isldu(1,idu)
     if (is.gt.nspecies) then
       write(*,*)
       write(*,'("Error(init0): invalid species number : ",I8)') is
       write(*,*)
       stop
     end if
-    l=idftu(2,i)
+    l=isldu(2,idu)
     do ia=1,natoms(is)
       ias=idxas(ia,is)
       tvmmt(l,ias)=.true.
     end do
   end do
+! zero the initial values of screening length
+  lamdu0(:)=0.d0
+! write to VARIABLES.OUT
+  if (wrtvars) then
+    call writevars('udufix',nv=ndftu,rva=udufix)
+  end if
 end if
 if (ftmtype.ne.0) then
 ! allocate and zero the fixed tensor moment potential array
