@@ -43,7 +43,7 @@ end if
 if (any(task.eq.[105,180,185,320,330,331])) then
 ! equal k- and q-point grids for nesting function, BSE and linear-reposnse TDDFT
   ngridq(:)=ngridk(:)
-else if ((xctype(1).lt.0).or.(any(task.eq.[5,300,600,620,630,800,801]))) then
+else if ((xctype(1).lt.0).or.(any(task.eq.[5,300,600,620,630]))) then
 ! allow the q-point grid to be smaller than the k-point grid for OEP,
 ! Hartree-Fock, RDMFT and GW
   if (any(ngridq(:).le.0)) ngridq(:)=ngridk(:)
@@ -51,8 +51,7 @@ else
   ngridq(:)=abs(ngridq(:))
 end if
 ! check that the q-point and k-point grids are commensurate for some tasks
-if ((xctype(1).lt.0).or.(any(task.eq.[5,205,240,241,300,600,620,630, &
- 800,801]))) then
+if ((xctype(1).lt.0).or.(any(task.eq.[5,205,240,241,300,600,620,630]))) then
   iv(:)=mod(ngridk(:),ngridq(:))
   if ((iv(1).ne.0).or.(iv(2).ne.0).or.(iv(3).ne.0)) then
     write(*,*)
@@ -87,20 +86,22 @@ call genppts(.true.,nsymqpt,symqpt,ngridq,nqptnr,epslat,bvec,boxl,nqpt,ivqiq, &
 ! write the q-points to QPOINTS.OUT
 if (mp_mpi) call writeqpts
 ! write to VARIABLES.OUT
-call writevars('nsymqpt',iv=nsymqpt)
-call writevars('symqpt',nv=9*nsymqpt,iva=symqpt)
-call writevars('ngridq',nv=3,iva=ngridq)
-call writevars('nqpt',iv=nqpt)
-call writevars('ivqiq',nv=nqptnr,iva=ivqiq)
-call writevars('ivq',nv=3*nqptnr,iva=ivq)
-call writevars('vql',nv=3*nqptnr,rva=vql)
-call writevars('wqpt',nv=nqpt,rva=wqpt)
+if (wrtvars) then
+  call writevars('nsymqpt',iv=nsymqpt)
+  call writevars('symqpt',nv=9*nsymqpt,iva=symqpt)
+  call writevars('ngridq',nv=3,iva=ngridq)
+  call writevars('nqpt',iv=nqpt)
+  call writevars('ivqiq',nv=nqptnr,iva=ivqiq)
+  call writevars('ivq',nv=3*nqptnr,iva=ivq)
+  call writevars('vql',nv=3*nqptnr,rva=vql)
+  call writevars('wqpt',nv=nqpt,rva=wqpt)
+end if
 
 !--------------------------------------------------------!
 !     OEP, Hartree-Fock, RDMFT, BSE and GW variables     !
 !--------------------------------------------------------!
 if ((xctype(1).lt.0).or.(any(task.eq.[5,180,185,188,205,300,320,330,331,600, &
- 620,630,800,801]))) then
+ 620,630]))) then
 ! determine the regularised Coulomb Green's function for small q
   call gengclq
 ! output the Coulomb Green's function to GCLQ.OUT
