@@ -39,8 +39,8 @@ if (task.eq.270) then
   dvv(:,:,:)=0.d0
   duv(:,:,:)=0.d0
   do ik=1,nkpt
-    call rndevsv(1.d-8,dvv(:,:,ik))
-    call rndevsv(1.d-8,duv(:,:,ik))
+    call rndevsv(1.d0,dvv(:,:,ik))
+    call rndevsv(1.d0,duv(:,:,ik))
   end do
 else
   do ik=1,nkpt
@@ -49,7 +49,8 @@ else
 ! get the eigenvectors from file
     call getevecuv(ik,vkl(:,ik),u,v)
 ! calculate the density matrices
-    call dmatuv(nstsv,efermi,evalsv(:,ik),u,v,dvv(:,:,ik),duv(:,:,ik))
+    call dmatuv(nstsv,efermi,evalsv(:,ik),u,v,dvv(:,:,ik),duv(:,:,ik), &
+     vnorm(:,ik))
   end do
 end if
 
@@ -68,6 +69,8 @@ end do
 deallocate(dynq,ev)
 if (allocated(evalwx)) deallocate(evalwx)
 allocate(evalwx(nbph,nqpt))
+if (allocated(xnorm)) deallocate(xnorm)
+allocate(xnorm(nbph,nqpt))
 ! associate the phononic density matrices with target
 dxx(1:nbph,1:nbph,1:nqpt)=>duvwx(i:)
 i=i+nbph*nbph*nqpt
@@ -83,7 +86,7 @@ else
 ! get the eigenvectors from file
     call getevecwxy(iq,w,x,y)
 ! calculate the density matrices
-    call dmatwx(nbph,w,x,dxx(:,:,iq),dwx(:,:,iq))
+    call dmatwx(nbph,w,x,dxx(:,:,iq),dwx(:,:,iq),xnorm(:,iq))
   end do
 end if
 
