@@ -7,14 +7,7 @@ subroutine initoep
 use modmain
 implicit none
 ! local variables
-integer ist,ic,m
-integer is,ias,nrc,nrci
-integer xctype_(3)
-! allocatable arrays
-real(8), allocatable :: rfmt(:)
-! external functions
-real(8) rfint
-external rfint
+integer is,ic,ist,m
 ! find maximum core states over all species
 ncrmax=0
 do is=1,nspecies
@@ -39,23 +32,12 @@ if (spinpol) then
   if (allocated(bxir)) deallocate(bxir)
   allocate(bxir(ngtot,ndmag))
 end if
-! initialise the exchange potential to LDA
-xctype_(1)=3
-xctype_(2:)=0
-call potxc(.true.,xctype_,rhomt,rhoir,magmt,magir,taumt,tauir,exmt,exir,ecmt, &
- ecir,vxcmt,vxcir,bxcmt,bxcir,wxcmt,wxcir)
-allocate(rfmt(npcmtmax))
-do ias=1,natmtot
-  is=idxis(ias)
-  nrc=nrcmt(is)
-  nrci=nrcmti(is)
-  call rfmtftoc(nrc,nrci,vxcmt(:,ias),rfmt)
-  call rbsht(nrc,nrci,rfmt,vxmt(:,ias))
-end do
-deallocate(rfmt)
-vxir(:)=vxcir(:)
-! determine the constant part of V_xc
-vxc0=rfint(vxcmt,vxcir)/omega
-return
+! zero the exchange potential and magnetic field
+vxmt(:,:)=0.d0
+vxir(:)=0.d0
+if (spinpol) then
+  bxmt(:,:,:)=0.d0
+  bxir(:,:)=0.d0
+end if
 end subroutine
 
