@@ -152,5 +152,10 @@ do ik0=1,nkpt0
   end do
 end do
 deallocate(idx)
+! zero the timing variables
+timemat=0.d0
+timesv=0.d0
+timerho=0.d0
+timepot=0.d0
 end subroutine
 
