@@ -6,7 +6,6 @@
 subroutine latvstep
 use modmain
 use modmpi
-use modstore
 implicit none
 ! local variables
 integer i
@@ -27,9 +26,9 @@ end do
 call reciplat(avec,bvec,omega,omegabz)
 ! preserve the volume if required (added by Ronald Cohen)
 if (latvopt.eq.2) then
-  t1=(omega_/omega)**(1.d0/3.d0)
+  t1=(omega0/omega)**(1.d0/3.d0)
   avec(:,:)=t1*avec(:,:)
-  omega=omega_
+  omega=omega0
 end if
 ! each MPI process should have numerically identical lattice vectors
 call mpi_bcast(avec,9,mpi_double_precision,0,mpicom,ierror)
