@@ -102,7 +102,6 @@ real(8), optional, intent(out) :: wc(n),wcup(n),wcdn(n)
 integer nspin,fmly,id,k
 integer(c_size_t) np
 type(xc_f90_func_t) p
-real(8) ta
 ! allocatable arrays
 real(8), allocatable :: r(:,:),sigma(:,:),vrho(:,:),vsigma(:,:)
 real(8), allocatable :: lapl(:,:),t(:,:),vlapl(:,:),vtau(:,:)
@@ -391,7 +390,7 @@ integer, intent(out) :: xcgrad
 logical, intent(inout) :: hybrid
 real(8), intent(inout) :: hybridc
 ! local variables
-integer j,k,id
+integer k,id
 integer fmly,flg
 character(128) name
 type(xc_f90_func_t) p
