@@ -22,8 +22,8 @@ implicit none
 ! local variables
 logical fnd
 integer is,ia,ja,ias,jas
-integer nr,nri,iro,ir,l,i
-integer ilo,io,jo,nnf
+integer nr,nri,iro,i0,i1
+integer l,ilo,io,jo,nnf
 ! automatic arrays
 logical done(natmmax)
 real(8) vr(nrmtmax)
@@ -37,15 +37,11 @@ do is=1,nspecies
   do ia=1,natoms(is)
     if (done(ia)) cycle
     ias=idxas(ia,is)
-    i=1
-    do ir=1,nri
-      vr(ir)=vsmt(i,ias)*y00
-      i=i+lmmaxi
-    end do
-    do ir=iro,nr
-      vr(ir)=vsmt(i,ias)*y00
-      i=i+lmmaxo
-    end do
+    i1=lmmaxi*(nri-1)+1
+    vr(1:nri)=vsmt(1:i1:lmmaxi,ias)*y00
+    i0=i1+lmmaxi
+    i1=lmmaxo*(nr-iro)+i0
+    vr(iro:nr)=vsmt(i0:i1:lmmaxo,ias)*y00
 !-----------------------!
 !     APW functions     !
 !-----------------------!
