@@ -6,7 +6,6 @@
 subroutine mae
 use modmain
 use modmpi
-use modstore
 use moddelf
 implicit none
 ! local variables
@@ -17,14 +16,14 @@ real(8) a(3,3),b(3,3)
 ! initialise global variables
 call init0
 ! store original parameters
-avec_(:,:)=avec(:,:)
-spinpol_=spinpol
-spinorb_=spinorb
-cmagz_=cmagz
-bfieldc0_(:)=bfieldc0(:)
-reducebf_=reducebf
-fsmtype_=fsmtype
-vkloff_(:)=vkloff(:)
+avec0(:,:)=avec(:,:)
+spinpol0=spinpol
+spinorb0=spinorb
+cmagz0=cmagz
+bfieldc00(:)=bfieldc0(:)
+reducebf0=reducebf
+fsmtype0=fsmtype
+vkloff0(:)=vkloff(:)
 ! enable spin-orbit coupling
 spinorb=.true.
 ! enforce collinear magnetism in the z-direction
@@ -73,7 +72,7 @@ do i=1,npmae
   th=-tpmae(1,i)
   call axangrot(v1,th,b)
   call r3mm(b,a,rotsht)
-  call r3mm(rotsht,avec_,avec)
+  call r3mm(rotsht,avec0,avec)
 ! find the corresponding moment direction vector
   call r3minv(rotsht,a)
   v1(:)=0.d0
@@ -140,14 +139,14 @@ if (mp_mpi) then
   write(*,'(" Additional information written to MAE_INFO.OUT")')
 end if
 ! restore original input parameters
-avec(:,:)=avec_(:,:)
-spinpol=spinpol_
-spinorb=spinorb_
-cmagz=cmagz_
-fsmtype=fsmtype_
-bfieldc0(:)=bfieldc0_(:)
-reducebf=reducebf_
-vkloff(:)=vkloff_(:)
+avec(:,:)=avec0(:,:)
+spinpol=spinpol0
+spinorb=spinorb0
+cmagz=cmagz0
+fsmtype=fsmtype0
+bfieldc0(:)=bfieldc00(:)
+reducebf=reducebf0
+vkloff(:)=vkloff0(:)
 trotsht=.false.
 end subroutine
 
