@@ -6,7 +6,7 @@
 !BOP
 ! !ROUTINE: massnucl
 ! !INTERFACE:
-real(8) function massnucl(z)
+elemental real(8) function massnucl(z)
 ! !INPUT/OUTPUT PARAMETERS:
 !   z : atomic number (in,real)
 ! !DESCRIPTION:
@@ -53,7 +53,6 @@ end if
 n=a-za
 b=av*a-as*a**(2.d0/3.d0)-ac*(za**2)/a**(1.d0/3.d0)-asym*(za-n)**2/a
 massnucl=(za*mp+n*mn-b)/mu
-return
 end function
 !EOC
 
