@@ -38,7 +38,7 @@ use modmain
 !    (|{\bf G+p}|R_{\alpha})\exp(i({\bf G+p})\cdot{\bf r}_{\alpha})Y^*_{lm}
 !    (\widehat{{\bf G+p}}), $$
 !   with ${\bf r}_{\alpha}$ the atomic position and $R_{\alpha}$ the muffin-tin
-!   radius. See routine {\tt wavefmt}.
+!   radius. See routine {\tt wfmtfv}.
 !
 ! !REVISION HISTORY:
 !   Created April 2003 (JKD)
@@ -84,7 +84,7 @@ do is=1,nspecies
     do ia=1,natoms(is)
       ias=idxas(ia,is)
       do l=0,lmaxapw
-        z1=(t0/apwfr(nr,1,1,l,ias))*zil(l)
+        z1=(t0/apwfr(nr,1,1,l,ias))*zil(mod(l,4))
         lma=l**2+1; lmb=lma+2*l
         do igp=1,ngp
           z2=djl(l,1,igp)*z1*sfacgp(igp,ias)
@@ -116,7 +116,7 @@ do is=1,nspecies
 ! begin loop over l
     do l=0,lmaxapw
       ord=apword(l,is)
-      z1=t0*zil(l)
+      z1=t0*zil(mod(l,4))
 ! set up matrix of derivatives
       do jo=1,ord
         do io=1,ord
