@@ -22,8 +22,6 @@ real(8) t1
 ! automatic arrays
 integer ipiv(msd)
 real(8) c(msd),beta(msd,msd),gamma(msd),work(msd)
-! external functions
-real(8), external :: dnrm2
 if (n.lt.1) then
   write(*,*)
   write(*,'("Error(mixbroyden): n < 1 : ",I8)') n
@@ -38,8 +36,8 @@ if (msd.lt.2) then
 end if
 ! initialise mixer
 if (iscl.le.0) then
-  call dcopy(n,nu,1,mu,1)
-  call dcopy(n,nu,1,mu(:,2),1)
+  mu(:,1)=nu(:)
+  mu(:,2)=nu(:)
   f(:,1)=0.d0
   df(:,1)=0.d0
   u(:,1)=0.d0
@@ -59,9 +57,9 @@ f(:,kc)=nu(:)-mu(:,kp)
 d=sum(f(:,kc)**2)
 d=sqrt(d/dble(n))
 df(:,jc)=f(:,kc)-f(:,kp)
-t1=dnrm2(n,df(:,jc),1)
+t1=norm2(df(:,jc))
 if (t1.gt.1.d-8) t1=1.d0/t1
-call dscal(n,t1,df(:,jc),1)
+df(:,jc)=t1*df(:,jc)
 u(:,jc)=alpha*df(:,jc)+t1*(mu(:,kp)-mu(:,kc))
 call holdthd(m,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
@@ -102,6 +100,6 @@ nu(:)=mu(:,kp)+alpha*f(:,kc)
 do l=1,m
   call daxpy(n,-gamma(l),u(:,l),1,nu,1)
 end do
-call dcopy(n,nu,1,mu(:,kc),1)
+mu(:,kc)=nu(:)
 end subroutine
 
