@@ -27,14 +27,22 @@ complex(8), pointer :: dvv(:,:,:),duv(:,:,:)
 real(8) face
 ! bdiag is .true. if the matrix B is taken to be diagonal
 logical bdiag
+! cut-off energy for matrix B (elements outside this window are set to zero)
+real(8) ecutb
 
 !--------------------------------------!
 !     bosonic Bogoliubov variables     !
 !--------------------------------------!
 ! Bogoliubov equation eigenvalues
 real(8), allocatable :: evalwx(:,:)
+! power used in formula for (W,X) pseudo-normalisation (see article)
+integer pwxpsn
+! X-norm for each branch and q-point
+real(8), allocatable :: xnorm(:,:)
 ! density matrices XX† and WX†
 complex(8), pointer :: dxx(:,:,:),dwx(:,:,:)
+! ediag is .true. if the matrix E is taken to be diagonal
+logical ediag
 
 end module
 
