@@ -9,17 +9,17 @@ module modmain
 !     lattice parameters     !
 !----------------------------!
 ! lattice vectors stored column-wise
-real(8) avec(3,3)
+real(8) avec(3,3),avec0(3,3),davec(3,3)
 ! magnitude of random displacements added to lattice vectors
 real(8) rndavec
 ! inverse of lattice vector matrix
 real(8) ainv(3,3)
 ! reciprocal lattice vectors
-real(8) bvec(3,3)
+real(8) bvec(3,3),bvec0(3,3)
 ! inverse of reciprocal lattice vector matrix
-real(8) binv(3,3)
+real(8) binv(3,3),binv0(3,3)
 ! unit cell volume
-real(8) omega
+real(8) omega,omega0
 ! Brillouin zone volume
 real(8) omegabz
 ! any vector with length less than epslat is considered zero
@@ -35,24 +35,25 @@ integer, parameter :: maxatoms=200
 ! number of species
 integer nspecies
 ! number of atoms for each species
-integer natoms(maxspecies)
+integer natoms(maxspecies),natoms0(maxspecies)
 ! maximum number of atoms over all the species
 integer natmmax
 ! total number of atoms
-integer natmtot
+integer natmtot,natmtot0
 ! index to atoms and species
 integer idxas(maxatoms,maxspecies)
 ! inverse atoms and species indices
-integer idxis(maxatoms*maxspecies)
+integer idxis(maxatoms*maxspecies),idxis0(maxatoms*maxspecies)
 integer idxia(maxatoms*maxspecies)
 ! molecule is .true. is the system is an isolated molecule
 logical molecule
 ! primcell is .true. if primitive unit cell is to be found automatically
-logical primcell
+logical primcell,primcell0
 ! atomic positions in lattice coordinates
-real(8) atposl(3,maxatoms,maxspecies)
+real(8) atposl(3,maxatoms,maxspecies),atposl0(3,maxatoms,maxspecies)
+real(8) datposl(3,maxatoms,maxspecies)
 ! atomic positions in Cartesian coordinates
-real(8) atposc(3,maxatoms,maxspecies)
+real(8) atposc(3,maxatoms,maxspecies),atposc0(3,maxatoms,maxspecies)
 ! magnitude of random displacements added to the atomic positions
 real(8) rndatposc
 ! tdatpos is .true. if small amplitude displacements are to be included when
@@ -72,9 +73,9 @@ character(256) sppath
 ! species filenames
 character(256) spfname(maxspecies)
 ! species name
-character(256) spname(maxspecies)
+character(64) spname(maxspecies)
 ! species symbol
-character(256) spsymb(maxspecies)
+character(64) spsymb(maxspecies)
 ! species nuclear charge
 real(8) spzn(maxspecies)
 ! ptnucl is .true. if the nuclei are to be treated as point charges, if .false.
@@ -138,7 +139,7 @@ integer xctsp(3)
 !     muffin-tin radial mesh and angular momentum variables     !
 !---------------------------------------------------------------!
 ! scale factor for number of muffin-tin points
-real(8) nrmtscf
+real(8) nrmtscf,dnrmtscf
 ! number of muffin-tin radial points for each species
 integer nrmt(maxspecies)
 ! maximum nrmt over all the species
@@ -178,15 +179,15 @@ real(8), allocatable :: wcrcmt(:,:,:)
 ! maximum allowable angular momentum for augmented plane waves
 integer, parameter :: maxlapw=30
 ! maximum angular momentum for augmented plane waves
-integer lmaxapw
+integer lmaxapw,dlmaxapw
 ! (lmaxapw+1)^2
 integer lmmaxapw
 ! maximum angular momentum on the outer part of the muffin-tin
-integer lmaxo
+integer lmaxo,dlmaxo
 ! (lmaxo+1)^2
 integer lmmaxo
 ! maximum angular momentum on the inner part of the muffin-tin
-integer lmaxi
+integer lmaxi,lmaxi0
 ! (lmaxi+1)^2
 integer lmmaxi
 ! fraction of muffin-tin radius which constitutes the inner part
@@ -203,9 +204,9 @@ integer npmtmax,npcmtmax
 !     spin related variables     !
 !--------------------------------!
 ! spinpol is .true. for spin-polarised calculations
-logical spinpol
+logical spinpol,spinpol0
 ! spinorb is .true. for spin-orbit coupling
-logical spinorb
+logical spinorb,spinorb0
 ! scale factor of spin-orbit coupling term in Hamiltonian
 real(8) socscf
 ! dimension of magnetisation and magnetic vector fields (1 or 3)
@@ -213,7 +214,7 @@ integer ndmag
 ! ncmag is .true. if the magnetisation is non-collinear, i.e. when ndmag = 3
 logical ncmag
 ! if cmagz is .true. then collinear magnetism along the z-axis is enforced
-logical cmagz
+logical cmagz,cmagz0
 ! spcpl is .true. if the up and down spins are coupled
 logical spcpl
 ! fixed spin moment type
@@ -221,13 +222,13 @@ logical spcpl
 !  1 (-1) : total moment (direction)
 !  2 (-2) : individual muffin-tin moments (direction)
 !  3 (-3) : total and muffin-tin moments (direction)
-integer fsmtype
+integer fsmtype,fsmtype0
 ! fixed total spin magnetic moment
-real(8) momfix(3)
+real(8) momfix(3),momfix0(3)
 ! fixed spin moment global effective field in Cartesian coordinates
 real(8) bfsmc(3)
 ! muffin-tin fixed spin moments
-real(8) mommtfix(3,maxatoms,maxspecies)
+real(8) mommtfix(3,maxatoms,maxspecies),mommtfix0(3,maxatoms,maxspecies)
 ! muffin-tin fixed spin moment effective fields in Cartesian coordinates
 real(8), allocatable :: bfsmcmt(:,:)
 ! fixed spin moment field step size
@@ -237,17 +238,17 @@ integer nspinor
 ! global external magnetic field in Cartesian coordinates
 real(8) bfieldc(3)
 ! initial field
-real(8) bfieldc0(3)
+real(8) bfieldc0(3),bfieldc00(3)
 ! external magnetic field in each muffin-tin in Cartesian coordinates
 real(8) bfcmt(3,maxatoms,maxspecies)
 ! initial field as read in from input file
-real(8) bfcmt0(3,maxatoms,maxspecies)
+real(8) bfcmt0(3,maxatoms,maxspecies),bfcmt00(3,maxatoms,maxspecies)
 ! magnitude of random vectors added to muffin-tin fields
 real(8) rndbfcmt
 ! external magnetic fields are multiplied by reducebf after each s.c. loop
-real(8) reducebf
+real(8) reducebf,reducebf0
 ! spinsprl is .true. if a spin-spiral is to be calculated
-logical spinsprl
+logical spinsprl,spinsprl0
 ! ssdph is .true. if the muffin-tin spin-spiral magnetisation is de-phased
 logical ssdph
 ! spin-spiral phase factor for each atom
@@ -257,7 +258,7 @@ integer nspnfv
 ! map from second- to first-variational spin index
 integer jspnfv(2)
 ! spin-spiral q-vector in lattice coordinates
-real(8) vqlss(3)
+real(8) vqlss(3),vqlss0(3)
 ! spin-spiral q-vector in Cartesian coordinates
 real(8) vqcss(3)
 ! current q-point in spin-spiral supercell calculation
@@ -282,7 +283,7 @@ real(8) efieldl(3)
 ! tafield is .true. if a constant vector potential is applied
 logical tafield
 ! vector potential A-field which couples to paramagnetic current
-real(8) afieldc(3)
+real(8) afieldc(3),afieldc0(3)
 ! A-field in lattice coordinates
 real(8) afieldl(3)
 
@@ -305,7 +306,7 @@ integer isymlat(48)
 ! lattice point group symmetries in Cartesian coordinates
 real(8) symlatc(3,3,48)
 ! tshift is .true. if atomic basis is allowed to be shifted
-logical tshift
+logical tshift,tshift0
 ! tsyminv is .true. if the crystal has inversion symmetry
 logical tsyminv
 ! maximum of symmetries allowed
@@ -336,13 +337,13 @@ integer, allocatable :: lspnsyms(:,:)
 !     G-vector variables     !
 !----------------------------!
 ! G-vector cut-off for interstitial potential and density
-real(8) gmaxvr
+real(8) gmaxvr,dgmaxvr
 ! G-vector grid sizes
-integer ngridg(3)
+integer ngridg(3),ngridg0(3)
 ! G-vector grid sizes for coarse grid (G < 2*gkmax)
 integer ngdgc(3)
 ! total number of G-vectors
-integer ngtot
+integer ngtot,ngtot0
 ! total number of G-vectors for coarse grid (G < 2*gkmax)
 integer ngtc
 ! integer grid intervals for each direction
@@ -352,18 +353,18 @@ integer ngvec
 ! number of G-vectors for coarse grid (G < 2*gkmax)
 integer ngvc
 ! G-vector integer coordinates (i1,i2,i3)
-integer, allocatable :: ivg(:,:)
+integer, allocatable :: ivg(:,:),ivg0(:,:)
 ! map from (i1,i2,i3) to G-vector index
 integer, allocatable :: ivgig(:,:,:)
 ! map from G-vector index to FFT array
-integer, allocatable :: igfft(:)
+integer, allocatable :: igfft(:),igfft0(:)
 ! map from G-vector index to FFT array for coarse grid (G < 2*gkmax)
 integer, allocatable :: igfc(:)
 ! G-vectors in Cartesian coordinates
 real(8), allocatable :: vgc(:,:)
 ! length of G-vectors
 real(8), allocatable :: gc(:)
-! Coulomb Green's function in G-space = 4 pi / G^2
+! Coulomb Green's function in G-space = 4π/G²
 real(8), allocatable :: gclg(:)
 ! spherical Bessel functions j_l(|G|R_mt)
 real(8), allocatable :: jlgrmt(:,:,:)
@@ -384,18 +385,18 @@ real(8), allocatable :: cfrc(:)
 !     k-point variables     !
 !---------------------------!
 ! autokpt is .true. if the k-point set is determined automatically
-logical autokpt
+logical autokpt,autokpt0
 ! radius of sphere used to determine k-point density when autokpt is .true.
 real(8) radkpt
 ! k-point grid sizes
-integer ngridk(3)
+integer ngridk(3),ngridk0(3),dngridk(3)
 ! k-point offset
-real(8) vkloff(3)
+real(8) vkloff(3),vkloff0(3)
 ! type of reduction to perform on k-point set
 !  0 : no reduction
 !  1 : reduce with full crystal symmetry group
 !  2 : reduce with symmorphic symmetries only
-integer reducek
+integer reducek,reducek0
 ! number of point group symmetries used for k-point reduction
 integer nsymkpt
 ! point group symmetry matrices used for k-point reduction
@@ -433,7 +434,7 @@ integer nkspolar
 ! species for which the muffin-tin radius will be used for calculating gkmax
 integer isgkmax
 ! smallest muffin-tin radius times gkmax
-real(8) rgkmax
+real(8) rgkmax,drgkmax
 ! maximum |G+k| cut-off for APW functions
 real(8) gkmax
 ! number of G+k-vectors for augmented plane waves
@@ -518,6 +519,9 @@ complex(8), allocatable :: zfshti(:,:)
 complex(8), allocatable :: zbshto(:,:)
 ! complex forward SHT matrix for lmaxo
 complex(8), allocatable :: zfshto(:,:)
+! single-precision copies of the complex SHT matrices
+complex(4), allocatable :: cbshti(:,:),cfshti(:,:)
+complex(4), allocatable :: cbshto(:,:),cfshto(:,:)
 
 !---------------------------------------------------------------!
 !     density, potential and exchange-correlation variables     !
@@ -539,12 +543,12 @@ logical trhonorm
 ! muffin-tin and interstitial magnetisation vector field
 real(8), allocatable :: magmt(:,:,:),magir(:,:)
 ! tjr is .true. if the current density j(r) is to be calculated
-logical tjr
+logical tjr,tjr0
 ! muffin-tin and interstitial gauge-invariant current density vector field
 real(8), allocatable :: jrmt(:,:,:),jrir(:,:)
 ! amount of smoothing to be applied to the exchange-correlation potentials and
 ! magnetic field
-integer msmooth
+integer msmooth,msmooth0
 ! muffin-tin and interstitial Coulomb potential
 real(8), allocatable :: vclmt(:,:),vclir(:)
 ! Poisson solver pseudocharge density constant
@@ -587,12 +591,8 @@ real(8), allocatable :: socfr(:,:)
 real(8), allocatable :: taumt(:,:,:),tauir(:,:)
 ! core kinetic energy density
 real(8), allocatable :: taucr(:,:,:)
-! taudft is .true. if meta-GGA is to be treated as a meta-GGA functional
-logical taudft
 ! meta-GGA exchange-correlation potential
 real(8), allocatable :: wxcmt(:,:),wxcir(:)
-! meta-GGA Kohn-Sham potential
-real(8), allocatable :: wsmt(:,:),wsir(:)
 ! Tran-Blaha '09 constant c [Phys. Rev. Lett. 102, 226401 (2009)]
 real(8) c_tb09
 ! tc_tb09 is .true. if the Tran-Blaha constant has been read in
@@ -608,7 +608,7 @@ real(8) tempk
 ! type of mixing to use for the potential
 integer mixtype
 ! mixing type description
-character(256) mixdescr
+character(64) mixdescr
 ! adaptive mixing parameters (formerly beta0 and betamax)
 real(8) amixpm(2)
 ! subspace dimension for Broyden mixing
@@ -737,6 +737,8 @@ integer lorbordc
 integer nxoapwlo
 ! excess local orbitals
 integer nxlo
+! number of (l,m) components used for generating the muffin-tin wavefunctions
+integer nlmwf(maxspecies)
 
 !-------------------------------------------!
 !     overlap and Hamiltonian variables     !
@@ -776,7 +778,7 @@ real(8) epsefvit
 !     eigenvalue and occupancy variables     !
 !--------------------------------------------!
 ! number of empty states per atom and spin
-real(8) nempty0
+real(8) nempty0,dnempty0
 ! number of empty states
 integer nempty
 ! number of first-variational states
@@ -786,9 +788,9 @@ integer nstsv
 ! smearing type
 integer stype
 ! smearing function description
-character(256) sdescr
+character(64) sdescr
 ! smearing width
-real(8) swidth
+real(8) swidth,swidth0
 ! autoswidth is .true. if the smearing width is to be determined automatically
 logical autoswidth
 ! effective mass used in smearing width formula
@@ -880,7 +882,7 @@ real(8) engytot
 !     force, stress and strain variables     !
 !--------------------------------------------!
 ! tforce is .true. if force should be calculated
-logical tforce
+logical tforce,tforce0
 ! Hellmann-Feynman force on each atom
 real(8), allocatable :: forcehf(:,:)
 ! incomplete basis set (IBS) force on each atom
@@ -893,9 +895,7 @@ real(8), allocatable :: forcetotp(:,:)
 real(8) forcemax
 ! tfav0 is .true. if the average force should be zero in order to prevent
 ! translation of the atomic basis
-logical tfav0
-! average force
-real(8) forceav(3)
+logical tfav0,tfav00
 ! atomic position optimisation type
 !  0 : no optimisation
 !  1 : unconstrained optimisation
@@ -933,13 +933,19 @@ real(8) tau0latv
 ! step size for each stress tensor component acting on the lattice vectors
 real(8) taulatv(9)
 
-!-------------------------------!
-!     convergence variables     !
-!-------------------------------!
+!--------------------------------------------------------!
+!     self-consistent loop and convergence variables     !
+!--------------------------------------------------------!
 ! maximum number of self-consistent loops
-integer maxscl
+integer maxscl,maxscl0
 ! current self-consistent loop number
 integer iscl
+! tlast is .true. if the calculation is on the last self-consistent loop
+logical tlast
+! tstop is .true. if the STOP file exists
+logical tstop
+! number of self-consistent loops after which STATE.OUT is written
+integer nwrite
 ! Kohn-Sham potential convergence tolerance
 real(8) epspot
 ! energy convergence tolerance
@@ -1115,9 +1121,8 @@ complex(8), parameter :: zzero=(0.d0,0.d0)
 complex(8), parameter :: zone=(1.d0,0.d0)
 complex(8), parameter :: zi=(0.d0,1.d0)
 ! array of i^l and (-i)^l values
-integer, private :: l
-complex(8), parameter :: zil(0:maxlapw)=[((0.d0,1.d0)**l,l=0,maxlapw)]
-complex(8), parameter :: zilc(0:maxlapw)=[((0.d0,-1.d0)**l,l=0,maxlapw)]
+complex(8), parameter :: zil(0:3)=[zone,zi,-zone,-zi]
+complex(8), parameter :: zilc(0:3)=[zone,-zi,-zone,zi]
 ! Pauli spin matrices:
 ! sigma_x = ( 0  1 )   sigma_y = ( 0 -i )   sigma_z = ( 1  0 )
 !           ( 1  0 )             ( i  0 )             ( 0 -1 )
@@ -1166,21 +1171,17 @@ real(8), parameter :: amu=amu_si/em_si
 !     miscellaneous variables     !
 !---------------------------------!
 ! code version
-integer, parameter :: version(3)=[7,2,42]
+integer, parameter :: version(3)=[8,4,30]
 ! maximum number of tasks
 integer, parameter :: maxtasks=40
 ! number of tasks
 integer ntasks
+! task index
+integer itask
 ! task array
 integer tasks(maxtasks)
 ! current task
 integer task
-! tlast is .true. if the calculation is on the last self-consistent loop
-logical tlast
-! tstop is .true. if the STOP file exists
-logical tstop
-! number of self-consistent loops after which STATE.OUT is written
-integer nwrite
 ! filename extension for files generated by gndstate
 character(256) :: filext='.OUT'
 ! scratch space path
