@@ -6,9 +6,8 @@
 module modrandom
 
 ! random number generator state
-integer(8) rndstate(0:5)
-data rndstate / 799047353, 1322018920, 1014372120, 1198189977, 832907020, &
-                5678910 /
+integer(8) :: rndstate(0:5)=[799047353, 1322018920, 1014372120, 1198189977, &
+ 832907020, 5678910]
 
 contains
 
@@ -33,8 +32,8 @@ implicit none
 ! local variables
 ! parameters taken from the GNU Scientific Library (GSL)
 integer(8), parameter :: a1=107374182, a5=104480, m=2147483647
-integer(8) i,i1,i5
-data i / 0 /
+integer(8) :: i=0
+integer(8) i1,i5
 !$OMP CRITICAL(randomu_)
 i=modulo(i+1,6_8)
 i1=modulo(i-1,6_8)
@@ -42,7 +41,6 @@ i5=modulo(i-5,6_8)
 rndstate(i)=int(mod(a1*rndstate(i1)+a5*rndstate(i5),m))
 randomu=dble(rndstate(i))/dble(m)
 !$OMP END CRITICAL(randomu_)
-
 end function
 !EOC
 
