@@ -36,10 +36,14 @@ real(8) tstime
 real(8) dtimes
 ! number of time steps
 integer ntimes
+! starting time step
+integer itimes0
 ! current time step
 integer itimes
 ! time steps
 real(8), allocatable :: times(:)
+! tdt0 is .true. if the time-evolution starts at t=0
+logical tdt0
 ! phase defining complex direction of time evolution
 real(8) tdphi
 ! number of time steps after which the time-dependent eigenvectors are backed up
@@ -77,9 +81,6 @@ logical tdjr1d,tdjr2d,tdjr3d
 logical tddos,tdlsj
 ! magnitude of complex numbers added to initial eigenvectors
 real(8) rndevt0
-! starting time for the Fourier transform when calculating the linear response
-! dielectric function from the real-time evolved current
-real(8) t0tdlr
 ! number of time steps between force calculations
 integer ntsforce
 ! total atomic forces at each time step
