@@ -5,39 +5,34 @@
 
 module modvars
 
-use modmpi
+use modmain
+use moddftu
 
 ! if wrtvars is .true. then variables are written to VARIABLES.OUT
 logical wrtvars
+! if batch is .true. then Elk will run in batch mode
+logical batch
 
 contains
 
 subroutine delvars
 implicit none
-if (.not.mp_mpi) return
 ! delete existing variables file
 open(95,file='VARIABLES.OUT')
 close(95,status='DELETE')
 end subroutine
 
-subroutine writevars(vname,l,m,nv,iv,iva,rv,rva,zv,zva,sv,sva)
+subroutine writevars(vname,n1,n2,n3,n4,n5,n6,nv,iv,iva,rv,rva,zv,zva,sv,sva)
 implicit none
 ! arguments
 character(*), intent(in) :: vname
-integer, optional, intent(in) :: l,m
-integer, optional, intent(in) :: nv
-integer, optional, intent(in) :: iv
-integer, optional, intent(in) :: iva(*)
-real(8), optional, intent(in) :: rv
-real(8), optional, intent(in) :: rva(*)
-complex(8), optional, intent(in) :: zv
-complex(8), optional, intent(in) :: zva(*)
-character(*), optional, intent(in) :: sv
-character(*), optional, intent(in) :: sva(*)
+integer, optional, intent(in) :: n1,n2,n3,n4,n5,n6
+integer, optional, intent(in) :: nv,iv,iva(*)
+real(8), optional, intent(in) :: rv,rva(*)
+complex(8), optional, intent(in) :: zv,zva(*)
+character(*), optional, intent(in) :: sv,sva(*)
 ! local variables
 integer i
-if (.not.wrtvars) return
-if (.not.mp_mpi) return
 if ((present(iva)).or.(present(rva)).or.(present(zva)).or.(present(sva))) then
   if (.not.present(nv)) then
     write(*,*)
@@ -55,9 +50,13 @@ if ((present(iva)).or.(present(rva)).or.(present(zva)).or.(present(sva))) then
 end if
 open(95,file='VARIABLES.OUT',position='APPEND',form='FORMATTED',action='WRITE')
 write(95,*)
-write(95,'(A)',advance='NO') trim(vname)
-if (present(l)) write(95,'(I8)',advance='NO') l
-if (present(m)) write(95,'(I8)',advance='NO') m
+write(95,'(A," ")',advance='NO') trim(vname)
+if (present(n1)) write(95,'(I8)',advance='NO') n1
+if (present(n2)) write(95,'(I8)',advance='NO') n2
+if (present(n3)) write(95,'(I8)',advance='NO') n3
+if (present(n4)) write(95,'(I8)',advance='NO') n4
+if (present(n5)) write(95,'(I8)',advance='NO') n5
+if (present(n6)) write(95,'(I8)',advance='NO') n6
 write(95,*)
 if (present(iv)) then
   write(95,'(2I8)') 1,1
