@@ -6,6 +6,7 @@
 subroutine momentu
 use modmain
 use modulr
+use modtest
 implicit none
 ! local variables
 integer ifq,idm,is,ias
@@ -46,5 +47,8 @@ if (ncmag) then
 else
   momtotm=abs(momtot(1))
 end if
+! write the muffin-tin moments to test file
+call writetest(770,'ULR muffin-tin moments',nv=ndmag*natmtot*nqpt,tol=1.d-2, &
+ rva=mommtru)
 end subroutine
 
