@@ -26,8 +26,7 @@ use modtest
 !BOC
 implicit none
 ! local variables
-integer ik,idm
-integer is,ia,ias
+integer idm,is,ia,ias
 integer nr,nri,nrn
 real(8) mc(3),bc(3),bd(3)
 real(8) rho0,rhon,rhoa
@@ -49,11 +48,9 @@ call readfermi
 call linengy
 ! generate the APW and local-orbital radial functions and integrals
 call genapwlofr
-! get the eigenvalues and occupancies from file
-do ik=1,nkpt
-  call getevalsv(filext,ik,vkl(:,ik),evalsv(:,ik))
-  call getoccsv(filext,ik,vkl(:,ik),occsv(:,ik))
-end do
+! read the eigenvalues and occupancies from file
+call readevalsv
+call readoccsv
 ! calculate the density
 call rhomag
 ! calculate the dipole magnetic field if required
