@@ -6,9 +6,10 @@
 !BOP
 ! !ROUTINE: nfftifc
 ! !INTERFACE:
-subroutine nfftifc(n)
+subroutine nfftifc(np,n)
 ! !INPUT/OUTPUT PARAMETERS:
-!   n : required/avalable grid size (inout,integer)
+!   np : number of allowed primes (in,integer)
+!   n  : required/avalable grid size (inout,integer)
 ! !DESCRIPTION:
 !   Interface to the grid requirements of the fast Fourier transform routine.
 !   Most routines restrict $n$ to specific prime factorisations. This routine
@@ -20,13 +21,17 @@ subroutine nfftifc(n)
 !BOC
 implicit none
 ! arguments
+integer, intent(in) :: np
 integer, intent(inout) :: n
 ! local variables
 integer i,j
-! currently we use primes 2, 3 and 5
-integer, parameter :: np=3
-integer p(np)
-data p / 2,3,5 /
+integer, parameter :: p(10)=[2,3,5,7,11,13,17,19,23,29]
+if ((np.lt.1).or.(np.gt.10)) then
+  write(*,*)
+  write(*,'("Error(nfftifc): np out of range : ",I8)') np
+  write(*,*)
+  stop
+end if
 if (n.le.0) then
   write(*,*)
   write(*,'("Error(nfftifc): n <= 0 : ",I8)') n
