@@ -24,8 +24,8 @@ implicit none
 ! local variables
 integer, parameter :: maxit=1000
 integer ik,ist,it
-real(8) e0,e1,e
-real(8) chg,w,x,t1
+real(8) e0,e1,e,de
+real(8) chg,w,x,t0
 ! external functions
 real(8), external :: sdelta,stheta
 ! determine the smearing width automatically if required
@@ -46,7 +46,7 @@ if (e0.lt.e0min) then
    &linearisation energy : ",2G18.10)') e0,e0min
   write(*,'(" for s.c. loop ",I5)') iscl
 end if
-t1=1.d0/swidth
+t0=1.d0/swidth
 ! determine the Fermi energy using the bisection method
 do it=1,maxit
   efermi=0.5d0*(e0+e1)
@@ -58,7 +58,7 @@ do it=1,maxit
       if (e.lt.e0min) then
         occsv(ist,ik)=0.d0
       else
-        x=(efermi-e)*t1
+        x=(efermi-e)*t0
         occsv(ist,ik)=occmax*stheta(stype,x)
         chg=chg+w*occsv(ist,ik)
       end if
@@ -80,8 +80,8 @@ fermidos=0.d0
 do ik=1,nkpt
   w=wkpt(ik)
   do ist=1,nstsv
-    x=(evalsv(ist,ik)-efermi)*t1
-    fermidos=fermidos+w*sdelta(stype,x)*t1
+    x=(evalsv(ist,ik)-efermi)*t0
+    fermidos=fermidos+w*sdelta(stype,x)
   end do
   if (abs(occsv(nstsv,ik)).gt.epsocc) then
     write(*,*)
@@ -89,7 +89,7 @@ do ik=1,nkpt
     write(*,'(" and s.c. loop ",I5)') iscl
   end if
 end do
-fermidos=fermidos*occmax
+fermidos=fermidos*occmax*t0
 ! write Fermi density of states to test file
 call writetest(500,'DOS at Fermi energy',tol=5.d-3,rv=fermidos)
 ! estimate the indirect band gap (FC)
@@ -102,7 +102,7 @@ ikgap(2)=1
 do ist=1,nstsv
   do ik=1,nkpt
     e=evalsv(ist,ik)
-    if (e.lt.efermi) then
+    if (e.le.efermi) then
       if (e.gt.e0) then
         e0=e
         ikgap(1)=ik
@@ -119,26 +119,26 @@ bandgap(1)=e1-e0
 ! write band gap to test file
 call writetest(510,'estimated indirect band gap',tol=2.d-2,rv=bandgap(1))
 ! estimate the direct band gap
-e=1.d8
+de=1.d8
 ikgap(3)=1
 do ik=1,nkpt
   e0=-1.d8
   e1=1.d8
   do ist=1,nstsv
-    t1=evalsv(ist,ik)
-    if (t1.le.efermi) then
-      if (t1.gt.e0) e0=t1
+    e=evalsv(ist,ik)
+    if (e.le.efermi) then
+      if (e.gt.e0) e0=e
     else
-      if (t1.lt.e1) e1=t1
+      if (e.lt.e1) e1=e
     end if
   end do
-  t1=e1-e0
-  if (t1.lt.e) then
-    e=t1
+  e=e1-e0
+  if (e.lt.de) then
+    de=e
     ikgap(3)=ik
   end if
 end do
-bandgap(2)=e
+bandgap(2)=de
 end subroutine
 !EOC
 
