@@ -13,8 +13,7 @@ integer ik0,ik,ist,it
 real(8) e0,e1,e
 real(8) chg,x,t1
 ! external functions
-real(8) stheta
-external stheta
+real(8), external :: stheta
 ! find minimum and maximum eigenvalues
 e0=evalu(1,1)
 e1=e0
@@ -55,11 +54,9 @@ do it=1,maxit
   else
     e1=efermi
   end if
-  if ((e1-e0).lt.1.d-12) goto 10
+  if ((e1-e0).lt.1.d-12) return
 end do
 write(*,*)
 write(*,'("Warning(occupyulr): could not find Fermi energy")')
-10 continue
-return
 end subroutine
 
