@@ -10,7 +10,7 @@ use modmpi
 implicit none
 integer ik,ist
 real(8) chg,w,vn
-real(8) e0,e1,e
+real(8) e0,e1,e,t1
 ! determine the total charge and fermionic anomalous correlation entropy
 chg=0.d0
 face=0.d0
@@ -42,7 +42,8 @@ ikgap(2)=1
 do ist=1,nstsv
   do ik=1,nkpt
     e=evaluv(ist,ik)
-    if (e.lt.0.d0) then
+    if (vnorm(ist,ik).gt.0.5d0) e=-e
+    if (e.le.0.d0) then
       if (e.gt.e0) then
         e0=e
         ikgap(1)=ik
@@ -56,5 +57,27 @@ do ist=1,nstsv
   end do
 end do
 bandgap(1)=e1-e0
+! estimate the direct band gap
+e=1.d8
+ikgap(3)=1
+do ik=1,nkpt
+  e0=-1.d8
+  e1=1.d8
+  do ist=1,nstsv
+    t1=evaluv(ist,ik)
+    if (vnorm(ist,ik).gt.0.5d0) t1=-t1
+    if (t1.le.0.d0) then
+      if (t1.gt.e0) e0=t1
+    else
+      if (t1.lt.e1) e1=t1
+    end if
+  end do
+  t1=e1-e0
+  if (t1.lt.e) then
+    e=t1
+    ikgap(3)=ik
+  end if
+end do
+bandgap(2)=e
 end subroutine
 
