@@ -12,7 +12,7 @@ implicit none
 integer ik,idm,is,ias
 integer nrc,nrci,np,npc
 integer n,nthd,it
-real(8) t1
+real(8) tau,t1
 ! allocatable arrays
 real(8), allocatable :: dvxmt(:,:),dvxir(:)
 real(8), allocatable :: dbxmt(:,:,:),dbxir(:,:)
@@ -20,13 +20,8 @@ real(8), allocatable :: rfmt1(:,:),rfmt2(:),rfir(:)
 real(8), allocatable :: rvfmt(:,:,:),rvfir(:,:)
 complex(8), allocatable :: vclcv(:,:,:,:),vclvv(:,:,:)
 ! external functions
-real(8) rfinpc
-external rfinpc
-! initialise the OEP exchange potential
-if (iscl.le.0) then
-  call initoep
-  return
-end if
+real(8), external :: rfint,rfinpc
+if (iscl.le.0) return
 ! calculate Coulomb matrix elements
 allocate(vclcv(ncrmax,natmtot,nstsv,nkpt),vclvv(nstsv,nstsv,nkpt))
 call oepvcl(vclcv,vclvv)
@@ -37,6 +32,16 @@ if (spinpol) then
   allocate(dbxmt(npcmtmax,natmtot,ndmag),dbxir(ngtot,ndmag))
   allocate(rvfmt(npmtmax,natmtot,ndmag),rvfir(ngtot,ndmag))
 end if
+! initialise the exchange potential and magnetic field
+tau=tauoep(2)
+vxmt(:,:)=tau*vxmt(:,:)
+vxir(:)=tau*vxir(:)
+if (spinpol) then
+  bxmt(:,:,:)=tau*bxmt(:,:,:)
+  bxir(:,:)=tau*bxir(:,:)
+end if
+! iterative method step size
+tau=tauoep(1)
 !------------------------------!
 !     start iteration loop     !
 !------------------------------!
@@ -53,16 +58,14 @@ do it=1,maxitoep
   end if
 ! calculate the k-dependent residuals
   call holdthd(nkpt/np_mpi,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
   do ik=1,nkpt
 ! distribute among MPI processes
     if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
     call oepresk(ik,vclcv,vclvv,dvxmt,dvxir,dbxmt,dbxir)
   end do
-!$OMP END DO
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
   call freethd(nthd)
 ! add residuals from each process and redistribute
   if (np_mpi.gt.1) then
@@ -82,10 +85,9 @@ do it=1,maxitoep
   end if
 ! convert muffin-tin residuals to spherical harmonics
   call holdthd(natmtot,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(is,nrc,nrci,idm) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
   do ias=1,natmtot
     is=idxis(ias)
     nrc=nrcmt(is)
@@ -95,19 +97,19 @@ do it=1,maxitoep
       call rfsht(nrc,nrci,dbxmt(:,ias,idm),rvfmt(:,ias,idm))
     end do
   end do
-!$OMP END DO
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
   call freethd(nthd)
 ! symmetrise the residuals
-  call symrf(nrcmt,nrcmti,npcmt,npmtmax,rfmt1,dvxir)
-  if (spinpol) call symrvf(.true.,ncmag,nrcmt,nrcmti,npcmt,npmtmax,rvfmt,dbxir)
+  call symrf(nrcmt,nrcmti,npcmt,ngridg,ngtot,ngvec,igfft,npmtmax,rfmt1,dvxir)
+  if (spinpol) call symrvf(.true.,ncmag,nrcmt,nrcmti,npcmt,ngridg,ngtot,ngvec, &
+   igfft,npmtmax,rvfmt,ngtot,dbxir)
 ! magnitude of residuals
-  resoep=sqrt(abs(rfinpc(npmtmax,rfmt1,dvxir,rfmt1,dvxir)))
+  resoep=rfinpc(npmtmax,rfmt1,dvxir,rfmt1,dvxir)
   do idm=1,ndmag
     t1=rfinpc(npmtmax,rvfmt(:,:,idm),dbxir(:,idm),rvfmt(:,:,idm),dbxir(:,idm))
-    resoep=resoep+sqrt(abs(t1))
+    resoep=resoep+t1
   end do
-  resoep=resoep/omega
+  resoep=sqrt(resoep)/omega
 ! update exchange potential and magnetic field
   call holdthd(natmtot,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
@@ -123,29 +125,28 @@ do it=1,maxitoep
 ! convert residual to spherical coordinates
     call rbsht(nrc,nrci,rfmt1(:,ias),rfmt2)
 ! subtract from exchange potential
-    vxmt(1:npc,ias)=vxmt(1:npc,ias)-tauoep*rfmt2(1:npc)
+    vxmt(1:npc,ias)=vxmt(1:npc,ias)-tau*rfmt2(1:npc)
 ! repeat for exchange magnetic field
     do idm=1,ndmag
       call rbsht(nrc,nrci,rvfmt(:,ias,idm),rfmt2)
-      bxmt(1:npc,ias,idm)=bxmt(1:npc,ias,idm)-tauoep*rfmt2(1:npc)
+      bxmt(1:npc,ias,idm)=bxmt(1:npc,ias,idm)-tau*rfmt2(1:npc)
     end do
   end do
 !$OMP END DO
   deallocate(rfmt2)
 !$OMP END PARALLEL
   call freethd(nthd)
-  vxir(:)=vxir(:)-tauoep*dvxir(:)
+  vxir(:)=vxir(:)-tau*dvxir(:)
   do idm=1,ndmag
-    bxir(:,idm)=bxir(:,idm)-tauoep*dbxir(:,idm)
+    bxir(:,idm)=bxir(:,idm)-tau*dbxir(:,idm)
   end do
 ! end iteration loop
 end do
 ! convert the exchange potential and field to spherical harmonics
 call holdthd(natmtot,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(is,nrc,nrci,idm) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
 do ias=1,natmtot
   is=idxis(ias)
   nrc=nrcmt(is)
@@ -155,8 +156,7 @@ do ias=1,natmtot
     call rfsht(nrc,nrci,bxmt(:,ias,idm),rvfmt(:,ias,idm))
   end do
 end do
-!$OMP END DO
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
 call freethd(nthd)
 ! convert potential and field from a coarse to a fine radial mesh
 call rfmtctof(rfmt1)
@@ -177,16 +177,16 @@ do idm=1,ndmag
   bxcir(:,idm)=bxcir(:,idm)+bxir(:,idm)
 end do
 ! symmetrise the exchange potential and field
-call symrf(nrmt,nrmti,npmt,npmtmax,vxcmt,vxcir)
-if (spinpol) call symrvf(.true.,ncmag,nrmt,nrmti,npmt,npmtmax,bxcmt,bxcir)
+call symrf(nrmt,nrmti,npmt,ngridg,ngtot,ngvec,igfft,npmtmax,vxcmt,vxcir)
+if (spinpol) call symrvf(.true.,ncmag,nrmt,nrmti,npmt,ngridg,ngtot,ngvec,igfft,&
+ npmtmax,bxcmt,ngtot,bxcir)
 deallocate(rfmt1,rfir,vclcv,vclvv)
 deallocate(dvxmt,dvxir)
 if (spinpol) then
   deallocate(rvfmt,rvfir)
   deallocate(dbxmt,dbxir)
 end if
-! set the constant part of the exchange potential equal to that of LDA/GGA
-call rfint0(vxc0,vxcmt,vxcir)
-return
+! set the constant part of the exchange potential equal to zero
+call rfint0(0.d0,vxcmt,vxcir)
 end subroutine
 
