@@ -18,8 +18,6 @@ integer is,ia,ias,ic,m
 integer nrc,nrci,npc
 real(8) de
 complex(8) z1,z2
-! automatic arrays
-integer idx(nstsv)
 ! allocatable arrays
 complex(8), allocatable :: apwalm(:,:,:,:),evecfv(:,:),evecsv(:,:)
 complex(8), allocatable :: wfmt(:,:,:,:),wfir(:,:,:),wfcr(:,:)
@@ -36,13 +34,9 @@ call getevecsv(filext,ik,vkl(:,ik),evecsv)
 ! find the matching coefficients
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot))
 call match(ngk(1,ik),vgkc(:,:,1,ik),gkc(:,1,ik),sfacgk(:,:,1,ik),apwalm)
-! index to all states
-do ist=1,nstsv
-  idx(ist)=ist
-end do
 ! calculate the wavefunctions for all states
 allocate(wfmt(npcmtmax,natmtot,nspinor,nstsv),wfir(ngtot,nspinor,nstsv))
-call genwfsv(.false.,.false.,nstsv,idx,ngridg,igfft,ngk(1,ik),igkig(:,1,ik), &
+call genwfsv(.false.,.false.,nstsv,0,ngridg,igfft,ngk(1,ik),igkig(:,1,ik), &
  apwalm,evecfv,evecsv,wfmt,ngtot,wfir)
 deallocate(apwalm,evecfv,evecsv)
 !-----------------------------------------------------------!
