@@ -15,9 +15,8 @@ complex(8), intent(out) :: vclvv(nstsv,nstsv,nkpt)
 integer ik,ncv,nvv
 integer lp,nthd
 call holdthd(nkpt/np_mpi,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
 do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
@@ -26,8 +25,7 @@ do ik=1,nkpt
 !$OMP END CRITICAL(oepvcl_)
   call oepvclk(ik,vclcv(:,:,:,ik),vclvv(:,:,ik))
 end do
-!$OMP END DO
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
 call freethd(nthd)
 ! broadcast matrix elements to all other processes
 ncv=ncrmax*natmtot*nstsv
@@ -37,6 +35,5 @@ do ik=1,nkpt
   call mpi_bcast(vclcv(:,:,:,ik),ncv,mpi_double_complex,lp,mpicom,ierror)
   call mpi_bcast(vclvv(:,:,ik),nvv,mpi_double_complex,lp,mpicom,ierror)
 end do
-return
 end subroutine
 
