@@ -51,12 +51,8 @@ call getevecfv(filext,ikp,vkl(:,ikp),vgkl(:,:,:,ikp),evecfv)
 call getevecsv(filext,ikp,vkl(:,ikp),evecsv)
 ! find the matching coefficients
 call match(ngk(1,ikp),vgkc(:,:,1,ikp),gkc(:,1,ikp),sfacgk(:,:,1,ikp),apwalm)
-! index to all states
-do ist1=1,nstsv
-  idx(ist1)=ist1
-end do
 ! calculate the wavefunctions for all states of the input k-point
-call genwfsv(.false.,.false.,nstsv,idx,ngdgc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
+call genwfsv(.false.,.false.,nstsv,0,ngdgc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
  apwalm,evecfv,evecsv,wfmt1,ngtc,wfir1)
 ! loop over non-reduced k-point set
 do ik=1,nkptnr
@@ -67,7 +63,7 @@ do ik=1,nkptnr
   iv(:)=modulo(iv(:),ngridk(:))
 ! check if the q-point is in user-defined set
   iv(:)=iv(:)*ngridq(:)
-  if (any(modulo(iv(:),ngridk(:)).ne.0)) cycle
+  if (any(mod(iv(:),ngridk(:)).ne.0)) cycle
   iv(:)=iv(:)/ngridk(:)
   iq=ivqiq(iv(1),iv(2),iv(3))
   vc(:)=vkc(:,ikp)-vkc(:,ik)
@@ -139,9 +135,8 @@ do ik=1,nkptnr
 ! calculate the Coulomb potential
         call genzvclmt(nrcmt,nrcmti,nrcmtmax,rlcmt,wprcmt,npcmtmax, &
          zrhomt1(:,:,ist2),zvclmt)
-        call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rlcmt,ngdgc,igfc,ngvc,&
-         gqc,gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir1(:,ist2),npcmtmax,zvclmt, &
-         zvclir)
+        call zpotcoul(nrcmt,nrcmti,npcmt,nrcmtmax,rlcmt,ngdgc,igfc,ngvc,gqc, &
+         gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir1(:,ist2),npcmtmax,zvclmt,zvclir)
         zvclir(:)=zvclir(:)*cfrc(:)
 !----------------------------------------------!
 !     valence-valence-valence contribution     !
