@@ -15,7 +15,7 @@ real(8) wmin,wmax,wd,dw
 real(8) tmax,temp(ntemp),s(ntemp)
 real(8) v(3),t1,t2
 ! allocatable arrays
-real(8), allocatable :: wp(:),w(:),gw(:),f(:)
+real(8), allocatable :: wq(:),w(:),gw(:),f(:)
 complex(8), allocatable :: dynq(:,:,:),dynr(:,:,:)
 complex(8), allocatable :: dynp(:,:),ev(:,:)
 ! external functions
@@ -23,7 +23,7 @@ real(8), external :: splint
 ! initialise universal variables
 call init0
 call init2
-allocate(wp(nbph),w(nwplot),gw(nwplot),f(nwplot))
+allocate(wq(nbph),w(nwplot),gw(nwplot),f(nwplot))
 allocate(dynq(nbph,nbph,nqpt),dynr(nbph,nbph,nqptnr))
 allocate(dynp(nbph,nbph),ev(nbph,nbph))
 ! read in the dynamical matrices
@@ -36,12 +36,13 @@ call dynqtor(dynq,dynr)
 wmin=0.d0
 wmax=0.d0
 do iq=1,nqpt
-  call dynev(dynq(:,:,iq),wp,ev)
-  wmin=min(wmin,wp(1))
-  wmax=max(wmax,wp(nbph))
+  call dynev(dynq(:,:,iq),wq,ev)
+  wmin=min(wmin,wq(1))
+  wmax=max(wmax,wq(nbph))
 end do
-wmax=wmax+(wmax-wmin)*0.1d0
-wmin=wmin-(wmax-wmin)*0.1d0
+t1=(wmax-wmin)*0.1d0
+wmin=wmin-t1
+wmax=wmax+t1
 wd=wmax-wmin
 if (wd.lt.1.d-8) wd=1.d0
 dw=wd/dble(nwplot)
@@ -59,9 +60,9 @@ do i1=0,ngrkf-1
 ! compute the dynamical matrix at this particular q-point
       call dynrtoq(v,dynr,dynp)
 ! find the phonon frequencies
-      call dynev(dynp,wp,ev)
+      call dynev(dynp,wq,ev)
       do i=1,nbph
-        t1=(wp(i)-wmin)/dw+1.d0
+        t1=(wq(i)-wmin)/dw+1.d0
         iw=nint(t1)
         if ((iw.ge.1).and.(iw.le.nwplot)) then
           gw(iw)=gw(iw)+1.d0
@@ -165,6 +166,6 @@ close(50)
 write(*,'(" thermodynamic properties written to THERMO.OUT")')
 ! write phonon DOS to test file
 call writetest(210,'phonon DOS',nv=nwplot,tol=1.d-2,rva=gw)
-deallocate(wp,w,gw,f,dynq,dynr,dynp,ev)
+deallocate(wq,w,gw,f,dynq,dynr,dynp,ev)
 end subroutine
 
