@@ -54,9 +54,11 @@ end do
 fmin=minval(fp(:,:))
 fmax=maxval(fp(:,:))
 t1=0.5d0*(fmax-fmin)
+fmin=fmin-t1
+fmax=fmax+t1
 do iv=1,nvp1d
-  write(fnum2,'(2G18.10)') dvp1d(iv),fmax+t1
-  write(fnum2,'(2G18.10)') dvp1d(iv),fmin-t1
+  write(fnum2,'(2G18.10)') dvp1d(iv),fmin
+  write(fnum2,'(2G18.10)') dvp1d(iv),fmax
   write(fnum2,*)
 end do
 deallocate(fp)
