@@ -18,7 +18,7 @@ real(8), intent(out) :: fp(np,nf)
 ! local variables
 integer iq,ifq0,ifq
 integer jf,ip
-real(8) sum,t1
+real(8) sm,t1
 complex(8) z1
 ! allocatable arrays
 complex(8), allocatable :: fpq(:,:)
@@ -37,7 +37,7 @@ do jf=1,nf
     call zfplot(np,vpl,zfmt(:,:,jf,ifq),zfir(:,jf,ifq),fpq(:,ifq))
   end do
   do ip=1,np
-    sum=0.d0
+    sm=0.d0
     do ifq=ifq0,nfqrz
       iq=iqrzf(ifq)
 ! multiply complex function by phase factor exp(iQ.r)
@@ -45,12 +45,11 @@ do jf=1,nf
       z1=cmplx(cos(t1),sin(t1),8)
       t1=dble(fpq(ip,ifq)*z1)
       if (ifq.gt.1) t1=t1*2.d0
-      sum=sum+t1
+      sm=sm+t1
     end do
-    fp(ip,jf)=sum
+    fp(ip,jf)=sm
   end do
 end do
 deallocate(fpq)
-return
 end subroutine
 
