@@ -7,21 +7,16 @@ real(8) function polefit(zfm,c)
 use modgw
 implicit none
 ! arguments
-complex(8), intent(in) :: zfm(0:nwfm)
-complex(8), intent(in) :: c(2*npole+1)
+complex(8), intent(in) :: zfm(0:nwfm),c(2*npole+1)
 ! local variables
 integer iw
-real(8) sum
 complex(8) z1
 ! external functions
-complex(8) zfpole
-external zfpole
-sum=0.d0
+complex(8), external :: zfpole
+polefit=0.d0
 do iw=0,nwfm
   z1=zfm(iw)-zfpole(c,wfm(iw))
-  sum=sum+dble(z1)**2+aimag(z1)**2
+  polefit=polefit+dble(z1)**2+aimag(z1)**2
 end do
-polefit=sum
-return
 end function
 
