@@ -6,7 +6,7 @@
 !BOP
 ! !ROUTINE: polynm
 ! !INTERFACE:
-real(8) function polynm(m,np,xa,ya,x)
+pure real(8) function polynm(m,np,xa,ya,x)
 ! !INPUT/OUTPUT PARAMETERS:
 !   m  : order of derivative (in,integer)
 !   np : number of points to fit (in,integer)
@@ -32,7 +32,7 @@ real(8), intent(in) :: x
 integer i,j,k
 real(8) x0,x1,x2,x3,y0,y1,y2,y3
 real(8) t0,t1,t2,t3,t4,t5,t6
-real(8) c1,c2,c3,sum
+real(8) c1,c2,c3,sm
 ! automatic arrays
 real(8) c(np)
 ! fast evaluations for small np
@@ -115,13 +115,7 @@ case(4)
   end select
   return
 end select
-if (np.le.0) then
-  write(*,*)
-  write(*,'("Error(polynm): np <= 0 : ",I8)') np
-  write(*,*)
-  stop
-end if
-if (m.ge.np) then
+if ((np.le.0).or.(m.ge.np)) then
   polynm=0.d0
   return
 end if
@@ -134,13 +128,13 @@ do i=2,np
 end do
 ! special case m=0
 if (m.eq.0) then
-  sum=c(1)
+  sm=c(1)
   t1=1.d0
   do i=2,np
     t1=t1*(x-xa(i-1))
-    sum=sum+c(i)*t1
+    sm=sm+c(i)*t1
   end do
-  polynm=sum
+  polynm=sm
   return
 end if
 x0=xa(1)
@@ -173,7 +167,6 @@ else
   end do
   polynm=t1*t2
 end if
-return
 end function
 !EOC
 
