@@ -23,7 +23,7 @@ use modomp
 implicit none
 ! local variables
 integer is,ias,nthd
-integer nr,nri,ir,i
+integer nr,nri,iro,i0,i1
 ! allocatable arrays
 complex(8), allocatable :: zrhomt(:,:),zrhoir(:)
 complex(8), allocatable :: zvclmt(:,:),zvclir(:)
@@ -48,15 +48,12 @@ do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
   nri=nrmti(is)
-  i=1
-  do ir=1,nri
-    zvclmt(i,ias)=zvclmt(i,ias)+vcln(ir,is)
-    i=i+lmmaxi
-  end do
-  do ir=nri+1,nr
-    zvclmt(i,ias)=zvclmt(i,ias)+vcln(ir,is)
-    i=i+lmmaxo
-  end do
+  iro=nri+1
+  i1=lmmaxi*(nri-1)+1
+  zvclmt(1:i1:lmmaxi,ias)=zvclmt(1:i1:lmmaxi,ias)+vcln(1:nri,is)
+  i0=i1+lmmaxi
+  i1=lmmaxo*(nr-iro)+i0
+  zvclmt(i0:i1:lmmaxo,ias)=zvclmt(i0:i1:lmmaxo,ias)+vcln(iro:nr,is)
 end do
 ! apply atomic displacement potential if required
 if (tdatpos) call zvcldisp(zvclmt)
@@ -64,8 +61,8 @@ allocate(zrhoir(ngtot),zvclir(ngtot))
 ! store real interstitial charge density in complex array
 zrhoir(:)=rhoir(:)
 ! solve Poisson's equation in the entire unit cell
-call zpotcoul(nrmt,nrmti,npmt,npmti,nrmtmax,rlmt,ngridg,igfft,ngvec,gc,gclg, &
- ngvec,jlgrmt,ylmg,sfacg,zrhoir,npmtmax,zvclmt,zvclir)
+call zpotcoul(nrmt,nrmti,npmt,nrmtmax,rlmt,ngridg,igfft,ngvec,gc,gclg,ngvec, &
+ jlgrmt,ylmg,sfacg,zrhoir,npmtmax,zvclmt,zvclir)
 ! convert complex muffin-tin potential to real spherical harmonic expansion
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
