@@ -32,7 +32,7 @@ do ifq=1,nfqrz
 ! convert the complex muffin-tin density from coarse to fine radial mesh
   do ias=1,natmtot
     is=idxis(ias)
-    call zcopy(npcmt(is),rhoqmt(:,ias,ifq),1,zrhomt(:,ias),1)
+    zrhomt(1:npcmt(is),ias)=rhoqmt(1:npcmt(is),ias,ifq)
   end do
   call zfmtctof(zrhomt)
 ! solve the complex Poisson's equation in the muffin-tins
@@ -57,9 +57,9 @@ do ifq=1,nfqrz
 ! convert the interstitial density from coarse to fine grid
   call zfirctof(rhoqir(:,ifq),zrhoir)
 ! solve Poisson's equation in the entire unit cell
-  call zpotcoul(nrmt,nrmti,npmt,npmti,nrmtmax,rlmt,ngridg,igfft,ngvec, &
-   gqc(:,ifq),gclgq(:,ifq),ngvec,jlgqrmt(:,:,:,ifq),ylmgq(:,:,ifq), &
-   sfacgq(:,:,ifq),zrhoir,npmtmax,zvclmt,vsqir(:,ifq))
+  call zpotcoul(nrmt,nrmti,npmt,nrmtmax,rlmt,ngridg,igfft,ngvec,gqc(:,ifq), &
+   gclgq(:,ifq),ngvec,jlgqrmt(:,:,:,ifq),ylmgq(:,:,ifq),sfacgq(:,:,ifq),zrhoir,&
+   npmtmax,zvclmt,vsqir(:,ifq))
   do ias=1,natmtot
     is=idxis(ias)
     nrc=nrcmt(is)
