@@ -55,8 +55,6 @@ vsir(1:ngtot)=vclir(1:ngtot)+vxcir(1:ngtot)
 call rfirsm(msmooth,vsir)
 ! generate the effective magnetic fields
 call genbs
-! generate the meta-GGA effective potential
-call genws
 call timesec(ts1)
 timepot=timepot+ts1-ts0
 end subroutine
