@@ -7,6 +7,9 @@ subroutine potksu
 use modmain
 use modulr
 implicit none
+! local variables
+real(8) ts0,ts1
+call timesec(ts0)
 ! compute the ultra long-range Coulomb potential
 call potcoulu
 ! compute the ultra long-range exchange-correlation potential and fields
@@ -16,5 +19,7 @@ if (reducebf.lt.1.d0) then
   bfcq(:,:)=bfcq(:,:)*reducebf
   bfcmtq(:,:,:)=bfcmtq(:,:,:)*reducebf
 end if
+call timesec(ts1)
+timepot=timepot+ts1-ts0
 end subroutine
 
