@@ -36,8 +36,7 @@ real(8), intent(out) :: vn(nr)
 integer ir
 real(8) rn,t1,t2
 ! external functions
-real(8) radnucl
-external radnucl
+real(8), external :: radnucl
 if (zn.eq.0.d0) then
   vn(:)=0.d0
   return
@@ -58,7 +57,6 @@ else
     end if
   end do
 end if
-return
 end subroutine
 !EOC
 
