@@ -38,9 +38,10 @@ real(8), intent(out) :: wxcmt_(npmtmax,natmtot),wxcir_(ngtot)
 ! local variables
 integer ias,nthd1,nthd2
 call holdthd(2,nthd1)
-!$OMP PARALLEL SECTIONS DEFAULT(SHARED) &
-!$OMP PRIVATE(ias) &
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(nthd2,ias) &
 !$OMP NUM_THREADS(nthd1)
+!$OMP SECTIONS
 !$OMP SECTION
 ! muffin-tin exchange-correlation potential, field and energy density
 call holdthd(natmtot,nthd2)
@@ -55,21 +56,19 @@ call freethd(nthd2)
 !$OMP SECTION
 ! interstitial exchange-correlation potential, field and energy density
 call potxcir(xctype_,rhoir_,magir_,tauir_,exir_,ecir_,vxcir_,bxcir_,wxcir_)
-!$OMP END PARALLEL SECTIONS
-call freethd(nthd1)
+!$OMP END SECTIONS
 ! symmetrise the exchange-correlation potential and magnetic field
 if (tsh) then
-  call holdthd(2,nthd1)
-!$OMP PARALLEL SECTIONS DEFAULT(SHARED) &
-!$OMP NUM_THREADS(nthd1)
+!$OMP SECTIONS
 !$OMP SECTION
-  call symrf(nrmt,nrmti,npmt,npmtmax,vxcmt_,vxcir_)
+  call symrf(nrmt,nrmti,npmt,ngridg,ngtot,ngvec,igfft,npmtmax,vxcmt_,vxcir_)
 !$OMP SECTION
-  if (spinpol) call symrvf(.true.,ncmag,nrmt,nrmti,npmt,npmtmax,bxcmt_,bxcir_)
-!$OMP END PARALLEL SECTIONS
-  call freethd(nthd1)
+  if (spinpol) call symrvf(.true.,ncmag,nrmt,nrmti,npmt,ngridg,ngtot,ngvec, &
+   igfft,npmtmax,bxcmt_,ngtot,bxcir_)
+!$OMP END SECTIONS
 end if
-return
+!$OMP END PARALLEL
+call freethd(nthd1)
 end subroutine
 !EOC
 
