@@ -44,13 +44,13 @@ do ir=1,nqpt
 ! convert muffin-tin density and magnetisation from coarse to fine radial mesh
   do ias=1,natmtot
     is=idxis(ias)
-    call dcopy(npcmt(is),rhormt(:,ias,ir),1,rhomt_(:,ias),1)
+    rhomt_(1:npcmt(is),ias)=rhormt(1:npcmt(is),ias,ir)
   end do
   call rfmtctof(rhomt_)
   do idm=1,ndmag
     do ias=1,natmtot
       is=idxis(ias)
-      call dcopy(npcmt(is),magrmt(:,ias,idm,ir),1,magmt_(:,ias,idm),1)
+      magmt_(1:npcmt(is),ias,idm)=magrmt(1:npcmt(is),ias,idm,ir)
     end do
     call rfmtctof(magmt_(:,:,idm))
   end do
