@@ -18,16 +18,19 @@ character(256) fext,fname
 call dynfext(iqph,isph,iaph,ipph,fext)
 ! construct filename
 fname=trim(scrpath)//'DEVECSV'//trim(fext)
-! find the record length
-inquire(iolength=recl) vkl(:,ik),nstsv,devecsv
 !$OMP CRITICAL(u226)
-open(226,file=fname,form='UNFORMATTED',access='DIRECT',recl=recl)
-write(226,rec=ik) vkl(:,ik),nstsv,devecsv
-close(226)
 ! write to RAM disk if required
 if (ramdisk) then
   call putrd(fname,ik,v1=vkl(:,ik),n1=nstsv,nzv=nstsv*nstsv,zva=devecsv)
 end if
+! write to disk if required
+if (wrtdsk) then
+! find the record length
+  inquire(iolength=recl) vkl(:,ik),nstsv,devecsv
+  open(226,file=fname,form='UNFORMATTED',access='DIRECT',recl=recl)
+  write(226,rec=ik) vkl(:,ik),nstsv,devecsv
+  close(226)
+end if
 !$OMP END CRITICAL(u226)
 end subroutine
 
