@@ -16,17 +16,20 @@ integer recl
 character(256) fname
 ! construct the filename
 fname='EVALFV'//trim(fext)
-! find the record length
-inquire(iolength=recl) vkl(:,ik),nstfv,nspnfv,evalfv
 !$OMP CRITICAL(u200)
-open(200,file=fname,form='UNFORMATTED',access='DIRECT',recl=recl)
-write(200,rec=ik) vkl(:,ik),nstfv,nspnfv,evalfv
-close(200)
 ! write to RAM disk if required
 if (ramdisk) then
   call putrd(fname,ik,v1=vkl(:,ik),n1=nstfv,n2=nspnfv,nrv=nstfv*nspnfv, &
    rva=evalfv)
 end if
+! write to disk if required
+if (wrtdsk) then
+! find the record length
+  inquire(iolength=recl) vkl(:,ik),nstfv,nspnfv,evalfv
+  open(200,file=fname,form='UNFORMATTED',access='DIRECT',recl=recl)
+  write(200,rec=ik) vkl(:,ik),nstfv,nspnfv,evalfv
+  close(200)
+end if
 !$OMP END CRITICAL(u200)
 end subroutine
 
