@@ -14,12 +14,10 @@ real(8), intent(in) :: evalsvp(nstsv)
 integer recl
 ! find the record length
 inquire(iolength=recl) vkl(:,ik),nstsv,evalsvp
-!$OMP CRITICAL(u124)
-open(124,file='EVALSV'//trim(fext),form='UNFORMATTED',access='DIRECT', &
- action='WRITE',recl=recl)
-write(124,rec=ik) vkl(:,ik),nstsv,evalsvp
-close(124)
-!$OMP END CRITICAL(u124)
-return
+!$OMP CRITICAL(u204)
+open(204,file='EVALSV'//trim(fext),form='UNFORMATTED',access='DIRECT',recl=recl)
+write(204,rec=ik) vkl(:,ik),nstsv,evalsvp
+close(204)
+!$OMP END CRITICAL(u204)
 end subroutine
 
