@@ -16,16 +16,19 @@ integer recl
 character(256) fname
 ! construct the filename
 fname=trim(scrpath)//'EVECSV'//trim(fext)
-! find the record length
-inquire(iolength=recl) vkl(:,ik),nstsv,evecsv
 !$OMP CRITICAL(u206)
-open(206,file=fname,form='UNFORMATTED',access='DIRECT',recl=recl)
-write(206,rec=ik) vkl(:,ik),nstsv,evecsv
-close(206)
 ! write to RAM disk if required
 if (ramdisk) then
   call putrd(fname,ik,v1=vkl(:,ik),n1=nstsv,nzv=nstsv*nstsv,zva=evecsv)
 end if
+! write to disk if required
+if (wrtdsk) then
+! find the record length
+  inquire(iolength=recl) vkl(:,ik),nstsv,evecsv
+  open(206,file=fname,form='UNFORMATTED',access='DIRECT',recl=recl)
+  write(206,rec=ik) vkl(:,ik),nstsv,evecsv
+  close(206)
+end if
 !$OMP END CRITICAL(u206)
 end subroutine
 
