@@ -16,8 +16,6 @@ real(8), intent(in) :: bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag)
 ! local variables
 integer ist,ispn,recl
 ! automatic arrays
-integer idx(nstsv)
-! automatic arrays
 complex(8) kmat(nstsv,nstsv),a(nstsv,nstsv)
 ! allocatable arrays
 complex(8), allocatable :: apwalm(:,:,:,:,:),evecfv(:,:,:),evecsv(:,:)
@@ -33,13 +31,9 @@ do ispn=1,nspnfv
   call match(ngk(ispn,ik),vgkc(:,:,ispn,ik),gkc(:,ispn,ik), &
    sfacgk(:,:,ispn,ik),apwalm(:,:,:,:,ispn))
 end do
-! index to all states
-do ist=1,nstsv
-  idx(ist)=ist
-end do
 ! calculate the wavefunctions for all states of the input k-point
 allocate(wfmt(npcmtmax,natmtot,nspinor,nstsv),wfgk(ngkmax,nspinor,nstsv))
-call genwfsv(.false.,.true.,nstsv,idx,ngridg,igfft,ngk(:,ik),igkig(:,:,ik), &
+call genwfsv(.false.,.true.,nstsv,0,ngridg,igfft,ngk(:,ik),igkig(:,:,ik), &
  apwalm,evecfv,evecsv,wfmt,ngkmax,wfgk)
 deallocate(apwalm,evecfv)
 ! compute Kohn-Sham potential matrix elements
@@ -49,8 +43,6 @@ else
   call genvmatk(vmt,vir,ngk(:,ik),igkig(:,:,ik),wfmt,ngkmax,wfgk,kmat)
 end if
 deallocate(wfgk)
-! add the DFT+U matrix elements if required
-call genvmmtsv(wfmt,kmat)
 ! negate the potential matrix elements because we have to subtract them
 kmat(:,:)=-kmat(:,:)
 ! add second-variational eigenvalues along the diagonal
@@ -75,16 +67,19 @@ if (tfv) then
    nstsv)
 end if
 deallocate(evecsv,wfmt)
-! determine the record length
-inquire(iolength=recl) vkl(:,1),nstsv,kmat
 !$OMP CRITICAL(u220)
-open(220,file='KMAT.OUT',form='UNFORMATTED',access='DIRECT',recl=recl)
-write(220,rec=ik) vkl(:,ik),nstsv,kmat
-close(220)
 ! write to RAM disk if required
 if (ramdisk) then
   call putrd('KMAT.OUT',ik,v1=vkl(:,ik),n1=nstsv,nzv=nstsv*nstsv,zva=kmat)
 end if
+! write to disk if required
+if (wrtdsk) then
+! determine the record length
+  inquire(iolength=recl) vkl(:,1),nstsv,kmat
+  open(220,file='KMAT.OUT',form='UNFORMATTED',access='DIRECT',recl=recl)
+  write(220,rec=ik) vkl(:,ik),nstsv,kmat
+  close(220)
+end if
 !$OMP END CRITICAL(u220)
 end subroutine
 
