@@ -11,19 +11,14 @@ implicit none
 ! arguments
 integer, intent(in) :: ik
 ! local variables
-integer ist,ispn,recl
+integer ispn,recl
 ! automatic arrays
-integer idx(nstsv)
 complex(8) pmat(nstsv,nstsv,3)
 ! allocatable arrays
 complex(8), allocatable :: apwalm(:,:,:,:,:),evecfv(:,:,:),evecsv(:,:)
 complex(8), allocatable :: wfmt(:,:,:,:),wfgk(:,:,:)
-! index to all states
-do ist=1,nstsv
-  idx(ist)=ist
-end do
-allocate(evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv))
 ! get the eigenvectors from file
+allocate(evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv))
 call getevecfv(filext,ik,vkl(:,ik),vgkl(:,:,:,ik),evecfv)
 call getevecsv(filext,ik,vkl(:,ik),evecsv)
 ! find the matching coefficients
@@ -34,23 +29,26 @@ do ispn=1,nspnfv
 end do
 ! calculate the wavefunctions for all states
 allocate(wfmt(npcmtmax,natmtot,nspinor,nstsv),wfgk(ngkmax,nspinor,nstsv))
-call genwfsv(.true.,.true.,nstsv,idx,ngridg,igfft,ngk(:,ik),igkig(:,:,ik), &
- apwalm,evecfv,evecsv,wfmt,ngkmax,wfgk)
+call genwfsv(.true.,.true.,nstsv,0,ngridg,igfft,ngk(:,ik),igkig(:,:,ik),apwalm,&
+ evecfv,evecsv,wfmt,ngkmax,wfgk)
 deallocate(evecfv,evecsv,apwalm)
 ! calculate the momentum matrix elements
 call genpmatk(ngk(:,ik),igkig(:,:,ik),vgkc(:,:,:,ik),wfmt,wfgk,pmat)
 deallocate(wfmt,wfgk)
-! determine the record length
-inquire(iolength=recl) vkl(:,1),nstsv,pmat
 ! write the matrix elements in the second-variational basis
 !$OMP CRITICAL(u230)
-open(230,file='PMAT.OUT',form='UNFORMATTED',access='DIRECT',recl=recl)
-write(230,rec=ik) vkl(:,ik),nstsv,pmat
-close(230)
 ! write to RAM disk if required
 if (ramdisk) then
   call putrd('PMAT.OUT',ik,v1=vkl(:,ik),n1=nstsv,nzv=nstsv*nstsv*3,zva=pmat)
 end if
+! write to disk if required
+if (wrtdsk) then
+! determine the record length
+  inquire(iolength=recl) vkl(:,1),nstsv,pmat
+  open(230,file='PMAT.OUT',form='UNFORMATTED',access='DIRECT',recl=recl)
+  write(230,rec=ik) vkl(:,ik),nstsv,pmat
+  close(230)
+end if
 !$OMP END CRITICAL(u230)
 end subroutine
 
