@@ -137,8 +137,8 @@ if (t1.le.0.d0) then
   stop
 end if
 t1=1.d0/t1
-call dscal(nr,t1,g0,1)
-call dscal(nr,t1,f0,1)
+g0(:)=t1*g0(:)
+f0(:)=t1*f0(:)
 end subroutine
 !EOC
 
