@@ -25,13 +25,13 @@ integer ik,ist,is,ias
 integer nr,nri,ir,i
 real(8) wo
 complex(8) z1
+! automatic arrays
+real(8) rfmt(npmtmax)
 ! allocatable arrays
-real(8), allocatable :: rfmt(:)
 complex(8), allocatable :: evecsv(:,:)
 ! external functions
 real(8), external :: rfmtinp
 complex(8), external :: zdotc
-allocate(rfmt(npmtmax))
 ! Coulomb energy from core states
 engyvcl=0.d0
 do ias=1,natmtot
@@ -63,7 +63,6 @@ do ias=1,natmtot
   end if
   engyvcl=engyvcl+rfmtinp(nr,nri,wrmt(:,is),rfmt,vclmt(:,ias))
 end do
-deallocate(rfmt)
 engykn=engykncr
 allocate(evecsv(nstsv,nstsv))
 do ik=1,nkpt
