@@ -38,10 +38,8 @@ do it=1,maxitc
   call rdmdkdc
 ! write the Coulomb matrix elements to file
   call writevclijjk
-! update evecsv, orthogonalise and write to file (MPI master process only)
-  if (mp_mpi) call rdmvaryc
-! synchronise MPI processes
-  call mpi_barrier(mpicom,ierror)
+! update evecsv, orthogonalise and write to file
+  call rdmvaryc
 ! calculate the energy
   call rdmenergy
 ! write energy to file
