@@ -10,6 +10,7 @@ subroutine rdmvaryc
 ! !USES:
 use modmain
 use modrdm
+use modmpi
 ! !DESCRIPTION:
 !   Calculates new {\tt evecsv} from old by using the derivatives of the total
 !   energy w.r.t. {\tt evecsv}. A single step of steepest-descent is made.
@@ -28,6 +29,8 @@ allocate(dedc(nstsv,nstsv,nkpt))
 call rdmdedc(dedc)
 allocate(evecsv(nstsv,nstsv))
 do ik=1,nkpt
+! distribute among MPI processes
+  if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
 ! get the eigenvectors from file
   call getevecsv(filext,ik,vkl(:,ik),evecsv)
 ! calculate new evecsv
@@ -39,6 +42,8 @@ do ik=1,nkpt
 ! end loop over k-points
 end do
 deallocate(dedc,evecsv)
+! synchronise MPI processes
+call mpi_barrier(mpicom,ierror)
 end subroutine
 !EOC
 
