@@ -3,12 +3,12 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine readdvs(iq,is,ia,ip)
+subroutine readdvs(iq,is,ia,ip,dvsmt,dvsir)
 use modmain
-use modphonon
 implicit none
 ! arguments
 integer, intent(in) :: iq,is,ia,ip
+complex(8), intent(out) :: dvsmt(npmtmax,natmtot),dvsir(ngtot)
 ! local variables
 integer js,jas,ios
 integer version_(3),nspecies_
@@ -18,16 +18,17 @@ character(256) fext,fname
 ! allocatable arrays
 complex(8), allocatable :: zfmt(:,:,:)
 allocate(zfmt(lmmaxo,nrmtmax,natmtot))
-call phfext(iq,is,ia,ip,fext)
+call dynfext(iq,is,ia,ip,fext)
 fname='DVS'//trim(fext)
-open(50,file=trim(fname),form='UNFORMATTED',status='OLD',iostat=ios)
+open(150,file=trim(fname),form='UNFORMATTED',action='READ',status='OLD', &
+ iostat=ios)
 if (ios.ne.0) then
   write(*,*)
   write(*,'("Error(readdvs): error opening ",A)') trim(fname)
   write(*,*)
   stop
 end if
-read(50) version_
+read(150) version_
 if ((version(1).ne.version_(1)).or.(version(2).ne.version_(2)) &
  .or.(version(3).ne.version_(3))) then
   write(*,*)
@@ -36,7 +37,7 @@ if ((version(1).ne.version_(1)).or.(version(2).ne.version_(2)) &
   write(*,'(" file    : ",I3.3,".",I3.3,".",I3.3)') version_
   write(*,'(" in file ",A)') trim(fname)
 end if
-read(50) nspecies_
+read(150) nspecies_
 if (nspecies.ne.nspecies_) then
   write(*,*)
   write(*,'("Error(readdvs): differing nspecies")')
@@ -46,7 +47,7 @@ if (nspecies.ne.nspecies_) then
   write(*,*)
   stop
 end if
-read(50) lmmaxo_
+read(150) lmmaxo_
 if (lmmaxo.ne.lmmaxo_) then
   write(*,*)
   write(*,'("Error(readdvs): differing lmmaxo")')
@@ -57,7 +58,7 @@ if (lmmaxo.ne.lmmaxo_) then
   stop
 end if
 do js=1,nspecies
-  read(50) natoms_
+  read(150) natoms_
   if (natoms(js).ne.natoms_) then
     write(*,*)
     write(*,'("Error(readdvs): differing natoms for species ",I4)') js
@@ -67,7 +68,7 @@ do js=1,nspecies
     write(*,*)
     stop
   end if
-  read(50) nrmt_
+  read(150) nrmt_
   if (nrmt(js).ne.nrmt_) then
     write(*,*)
     write(*,'("Error(readdvs): differing nrmt for species ",I4)') js
@@ -78,7 +79,7 @@ do js=1,nspecies
     stop
   end if
 end do
-read(50) ngridg_
+read(150) ngridg_
 if ((ngridg(1).ne.ngridg_(1)).or.(ngridg(2).ne.ngridg_(2)).or. &
  (ngridg(3).ne.ngridg_(3))) then
   write(*,*)
@@ -89,13 +90,12 @@ if ((ngridg(1).ne.ngridg_(1)).or.(ngridg(2).ne.ngridg_(2)).or. &
   write(*,*)
   stop
 end if
-read(50) zfmt,dvsir
+read(150) zfmt,dvsir
 do jas=1,natmtot
   js=idxis(jas)
   call zfmtpack(.true.,nrmt(js),nrmti(js),zfmt(:,:,jas),dvsmt(:,jas))
 end do
-close(50)
+close(150)
 deallocate(zfmt)
-return
 end subroutine
 
