@@ -6,6 +6,7 @@
 subroutine reademd(emds)
 use modmain
 use modpw
+use modtest
 implicit none
 ! arguments
 real(4), intent(out) :: emds(nhkmax,nkpt)
@@ -16,10 +17,10 @@ real(8) vkl_(3),t1
 real(8), allocatable :: emd(:)
 allocate(emd(nhkmax))
 ! find the record length
-inquire(iolength=recl) vkl(:,1),nhkmax,emd
-open(160,file='EMD.OUT',form='UNFORMATTED',access='DIRECT',recl=recl)
+inquire(iolength=recl) vkl_,nhk_,emd
+open(250,file='EMD.OUT',form='UNFORMATTED',access='DIRECT',recl=recl)
 do ik=1,nkpt
-  read(160,rec=ik) vkl_,nhk_,emd
+  read(250,rec=ik) vkl_,nhk_,emd
   t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
   if (t1.gt.epslat) then
     write(*,*)
@@ -31,17 +32,18 @@ do ik=1,nkpt
   end if
   if (nhk(1,ik).ne.nhk_) then
     write(*,*)
-    write(*,'("Error(getpmat): differing nhk for k-point ",I8)') ik
+    write(*,'("Error(reademd): differing nhk for k-point ",I8)') ik
     write(*,'(" current : ",I8)') nhk(1,ik)
     write(*,'(" EMD.OUT : ",I8)') nhk_
     write(*,*)
     stop
   end if
-! store momentum density in single precision array
+! store momentum density in single-precision array
   emds(:,ik)=real(emd(:))
 end do
-close(160)
+close(250)
+! write the EMD of the last k-point to test file if required
+call writetest(170,'electron momentum density',nv=nhkmax,tol=1.d-4,rva=emd)
 deallocate(emd)
-return
 end subroutine
 
