@@ -36,13 +36,13 @@ implicit none
 ! local variables
 logical lv
 integer is,ia,ias,ios
-integer i,j,k,l,n,p
+integer i,j,k,l
 real(8) sc,sc1,sc2,sc3
 real(8) scx,scy,scz
 real(8) scu,scu1,scu2,scu3
-real(8) solscf,zn,a,b
+real(8) solscf,zn
 real(8) axang(4),rot(3,3)
-real(8) v1(3),v2(3),t1
+real(8) v(3),t1
 character(256) block,symb,str
 
 !------------------------!
@@ -190,18 +190,16 @@ ndftu=0
 ujdu(:,:)=0.d0
 fdu(:,:)=0.d0
 edu(:,:)=0.d0
-lambdadu(:)=0.d0
+lamdu(:)=0.d0
 udufix(:)=0.d0
-lambdadu0(:)=0.d0
 tmwrite=.false.
-readadu=.false.
 rdmxctype=2
 rdmmaxscl=2
 maxitn=200
 maxitc=0
 taurdmn=0.5d0
 taurdmc=0.25d0
-rdmalpha=0.565d0
+rdmalpha=0.656d0
 rdmtemp=0.d0
 reducebf=1.d0
 ptnucl=.true.
@@ -219,7 +217,7 @@ test=.false.
 spincore=.false.
 solscf=1.d0
 emaxelnes=-1.2d0
-wsfac(1)=-1.d6; wsfac(2)=1.d6
+wsfac(1)=-1.1d6; wsfac(2)=1.1d6
 vhmat(:,:)=0.d0
 vhmat(1,1)=1.d0
 vhmat(2,2)=1.d0
@@ -259,8 +257,7 @@ npmae0=-1
 wrtvars=.false.
 ftmtype=0
 ntmfix=0
-tauftm=0.5d0
-ftmstep=1
+tauftm=0.1d0
 cmagz=.false.
 axang(:)=0.d0
 dncgga=1.d-8
@@ -308,10 +305,8 @@ tfav0=.true.
 rmtall=-1.d0
 maxthd=0
 maxthd1=0
-maxthdmkl=8
+maxthdmkl=0
 maxlvl=4
-taudft=.false.
-t0tdlr=0.d0
 tdphi=0.d0
 thetamld=45.d0*pi/180.d0
 ntsbackup=0
@@ -338,7 +333,25 @@ ephscf(2)=0.02d0
 anomalous=.false.
 tephde=.false.
 bdiag=.false.
-ramdisk=.false.
+ecutb=0.001d0
+ediag=.false.
+pwxpsn=2
+ramdisk=.true.
+wrtdsk=.true.
+epsdmat=1.d-8
+tm3old=.false.
+! batch calculation variable increments
+batch=.false.
+dngridk(:)=0
+dlmaxapw=0
+dlmaxo=0
+davec(:,:)=0.d0
+datposl(:,:,:)=0.d0
+drgkmax=0.d0
+dgmaxvr=0.d0
+dnempty0=0.d0
+dnrmtscf=0.d0
+dudufix(:)=0.d0
 
 !--------------------------!
 !     read from elk.in     !
@@ -391,6 +404,13 @@ case('fspecies')
     read(50,'(A256)',err=20) str
     if (trim(str).eq.'') goto 10
     read(str,*,iostat=ios) zn,symb
+    if (ios.ne.0) then
+      write(*,*)
+      write(*,'("Error(readinput): error reading fractional species")')
+      write(*,'("(blank line required after fspecies block)")')
+      write(*,*)
+      stop
+    end if
     if (zn.gt.-1.d0+epsocc) then
       write(*,*)
       write(*,'("Error(readinput): fractional nuclear Z > -1 : ",G18.10)') zn
@@ -404,9 +424,15 @@ case('fspecies')
   write(*,*)
   stop
 case('avec')
-  read(50,*,err=20) avec(:,1)
-  read(50,*,err=20) avec(:,2)
-  read(50,*,err=20) avec(:,3)
+  read(50,'(A256)',err=20) str
+  read(str,*,err=20) avec(:,1)
+  read(str,*,iostat=ios) avec(:,1),davec(:,1)
+  read(50,'(A256)',err=20) str
+  read(str,*,err=20) avec(:,2)
+  read(str,*,iostat=ios) avec(:,2),davec(:,2)
+  read(50,'(A256)',err=20) str
+  read(str,*,err=20) avec(:,3)
+  read(str,*,iostat=ios) avec(:,3),davec(:,3)
 case('scale')
   read(50,*,err=20) sc
 case('scale1')
@@ -444,7 +470,9 @@ case('radkpt')
     stop
   end if
 case('ngridk')
-  read(50,*,err=20) ngridk(:)
+  read(50,'(A256)',err=20) str
+  read(str,*,err=20) ngridk(:)
+  read(str,*,iostat=ios) ngridk(:),dngridk(:)
   if (any(ngridk(:).le.0)) then
     write(*,*)
     write(*,'("Error(readinput): invalid ngridk : ",3I8)') ngridk
@@ -474,7 +502,9 @@ case('ngridq')
 case('reduceq')
   read(50,*,err=20) reduceq
 case('rgkmax')
-  read(50,*,err=20) rgkmax
+  read(50,'(A256)',err=20) str
+  read(str,*,err=20) rgkmax
+  read(str,*,iostat=ios) rgkmax,drgkmax
   if (rgkmax.le.0.d0) then
     write(*,*)
     write(*,'("Error(readinput): rgkmax <= 0 : ",G18.10)') rgkmax
@@ -482,9 +512,13 @@ case('rgkmax')
     stop
   end if
 case('gmaxvr')
-  read(50,*,err=20) gmaxvr
+  read(50,'(A256)',err=20) str
+  read(str,*,err=20) gmaxvr
+  read(str,*,iostat=ios) gmaxvr,dgmaxvr
 case('lmaxapw')
-  read(50,*,err=20) lmaxapw
+  read(50,'(A256)',err=20) str
+  read(str,*,err=20) lmaxapw
+  read(str,*,iostat=ios) lmaxapw,dlmaxapw
   if (lmaxapw.lt.0) then
     write(*,*)
     write(*,'("Error(readinput): lmaxapw < 0 : ",I8)') lmaxapw
@@ -499,7 +533,9 @@ case('lmaxapw')
     stop
   end if
 case('lmaxo','lmaxvr')
-  read(50,*,err=20) lmaxo
+  read(50,'(A256)',err=20) str
+  read(str,*,err=20) lmaxo
+  read(str,*,iostat=ios) lmaxo,dlmaxo
   if (lmaxo.lt.3) then
     write(*,*)
     write(*,'("Error(readinput): lmaxo < 3 : ",I8)') lmaxo
@@ -580,7 +616,9 @@ case('epschg')
     stop
   end if
 case('nempty','nempty0')
-  read(50,*,err=20) nempty0
+  read(50,'(A256)',err=20) str
+  read(str,*,err=20) nempty0
+  read(str,*,iostat=ios) nempty0,dnempty0
   if (nempty0.le.0.d0) then
     write(*,*)
     write(*,'("Error(readinput): nempty <= 0 : ",G18.10)') nempty0
@@ -687,8 +725,8 @@ case('atoms')
     end if
     do ia=1,natoms(is)
       read(50,'(A256)',err=20) str
-      str=trim(str)//' 0.0 0.0 0.0'
-      read(str,*,err=20) atposl(:,ia,is),bfcmt0(:,ia,is)
+      read(str,*,err=20) atposl(:,ia,is)
+      read(str,*,iostat=ios) atposl(:,ia,is),bfcmt0(:,ia,is),datposl(:,ia,is)
     end do
   end do
 case('plot1d')
@@ -1061,8 +1099,9 @@ case('DFT+U','dft+u','lda+u')
     case(3)
       read(str,*,iostat=ios) is,l,(edu(k,i),k=0,l)
     case(4)
-      read(str,*,iostat=ios) is,l,lambdadu(i)
+      read(str,*,iostat=ios) is,l,lamdu(i)
     case(5)
+      read(str,*,iostat=ios) is,l,udufix(i),dudufix(i)
       read(str,*,iostat=ios) is,l,udufix(i)
     case default
       write(*,*)
@@ -1098,15 +1137,15 @@ case('DFT+U','dft+u','lda+u')
     end if
 ! check for repeated entries
     do j=1,i-1
-      if ((is.eq.idftu(1,j)).and.(l.eq.idftu(2,j))) then
+      if ((is.eq.isldu(1,j)).and.(l.eq.isldu(2,j))) then
         write(*,*)
         write(*,'("Error(readinput): repeated entry in DFT+U block")')
         write(*,*)
         stop
       end if
     end do
-    idftu(1,i)=is
-    idftu(2,i)=l
+    isldu(1,i)=is
+    isldu(2,i)=l
   end do
   write(*,*)
   write(*,'("Error(readinput): too many DFT+U entries")')
@@ -1116,7 +1155,9 @@ case('DFT+U','dft+u','lda+u')
 case('tmwrite','tmomlu')
   read(50,*,err=20) tmwrite
 case('readadu','readalu')
-  read(50,*,err=20) readadu
+  read(50,*,err=20)
+  write(*,*)
+  write(*,'("Info(readinput): variable ''readadu'' is no longer used")')
 case('rdmxctype')
   read(50,*,err=20) rdmxctype
 case('rdmmaxscl')
@@ -1128,12 +1169,6 @@ case('rdmmaxscl')
   end if
 case('maxitn')
   read(50,*,err=20) maxitn
-  if (maxitn.lt.1) then
-    write(*,*)
-    write(*,'("Error(readinput): maxitn < 1 : ",I8)') maxitn
-    write(*,*)
-    stop
-  end if
 case('maxitc')
   read(50,*,err=20) maxitc
 case('taurdmn')
@@ -1530,7 +1565,9 @@ case('lorbordc')
     stop
   end if
 case('nrmtscf')
-  read(50,*,err=20) nrmtscf
+  read(50,'(A256)',err=20) str
+  read(str,*,err=20) nrmtscf
+  read(str,*,iostat=ios) nrmtscf,dnrmtscf
   if (nrmtscf.lt.0.5d0) then
     write(*,*)
     write(*,'("Error(readinput): nrmtscf < 0.5 : ",G18.10)') nrmtscf
@@ -1568,6 +1605,12 @@ case('wrtvars')
 case('ftmtype')
   read(50,*,err=20) ftmtype
 case('tmomfix')
+  write(*,*)
+  write(*,'("Error(readinput): variable ''tmomfix'' is no longer used")')
+  write(*,'(" use tm3fix instead")')
+  write(*,*)
+  stop
+case('tm3fix')
   read(50,*,err=20) ntmfix
   if (ntmfix.le.0) then
     write(*,*)
@@ -1576,48 +1619,25 @@ case('tmomfix')
     stop
   end if
   if (allocated(itmfix)) deallocate(itmfix)
-  allocate(itmfix(8,ntmfix))
-  if (allocated(tmfix)) deallocate(tmfix)
-  allocate(tmfix(ntmfix))
-  if (allocated(rtmfix)) deallocate(rtmfix)
-  allocate(rtmfix(3,3,2,ntmfix))
+  allocate(itmfix(7,ntmfix))
+  if (allocated(wkprfix)) deallocate(wkprfix)
+  allocate(wkprfix(ntmfix))
   do i=1,ntmfix
-    read(50,*,err=20) is,ia,l,n
-    if ((is.le.0).or.(ia.le.0).or.(l.lt.0).or.((n.ne.2).and.(n.ne.3))) then
+    read(50,*,err=20) is,ia,l
+    if ((is.le.0).or.(ia.le.0).or.(l.lt.0)) then
       write(*,*)
-      write(*,'("Error(readinput): invalid is, ia, l or n in tmomfix block : ",&
-       &4I8)') is,ia,l,n
+      write(*,'("Error(readinput): invalid is, ia or l in tm3fix block : ",&
+       &4I8)') is,ia,l
       write(*,*)
       stop
     end if
     itmfix(1,i)=is
     itmfix(2,i)=ia
     itmfix(3,i)=l
-    itmfix(4,i)=n
-! read k, p, x, y for the 2-index tensor or k, p, r, t for the 3-index tensor
-    read(50,*,err=20) itmfix(5:8,i)
-! read tensor component
-    read(50,*,err=20) a,b
-    tmfix(i)=cmplx(a,b,8)
-! read parity and Euler angles of spatial and spin rotation matrices
-    read(50,'(A256)',err=20) str
-    str=trim(str)//' 0.0 0.0 0.0'
-    read(str,*,err=20) p,v1(:),v2(:)
-    if (abs(p).ne.1) then
-      write(*,*)
-      write(*,'("Error(readinput): parity should be -1 or 1 in tmomfix &
-       &block : ",I8)') p
-      write(*,*)
-      stop
-    end if
-! convert Euler angles from degrees to radians
-    v1(:)=v1(:)*pi/180.d0
-    v2(:)=v2(:)*pi/180.d0
-! compute the spatial and spin 3x3 rotation matrices from the Euler angles
-    call eulerrot(v1,rtmfix(:,:,1,i))
-    call eulerrot(v2,rtmfix(:,:,2,i))
-! multiply the spatial rotation matrix by the parity
-    rtmfix(:,:,1,i)=dble(p)*rtmfix(:,:,1,i)
+! read k, p, r, t for the 3-index tensor
+    read(50,*,err=20) itmfix(4:7,i)
+! read 3-index tensor component with conventional normalisation
+    read(50,*,err=20) wkprfix(i)
   end do
 case('tauftm')
   read(50,*,err=20) tauftm
@@ -1628,13 +1648,9 @@ case('tauftm')
     stop
   end if
 case('ftmstep')
-  read(50,*,err=20) ftmstep
-  if (ftmstep.lt.1) then
-    write(*,*)
-    write(*,'("Error(readinput): ftmstep < 1 : ",I8)') ftmstep
-    write(*,*)
-    stop
-  end if
+  read(50,*,err=20)
+  write(*,*)
+  write(*,'("Info(readinput): variable ''ftmstep'' is no longer used")')
 case('cmagz','forcecmag')
   read(50,*,err=20) cmagz
 case('rotavec')
@@ -1849,31 +1865,13 @@ case('stable')
     end if
   end if
 case('metagga')
-  read(50,*,err=20) lv
-  if (lv) then
-    nempty0=max(nempty0,10.d0)
-    lradstp=1
-    nrmtscf=max(nrmtscf,2.d0)
-    msmooth=max(msmooth,4)
-    if (mp_mpi) then
-      write(*,*)
-      write(*,'("Info(readinput): parameters set by metagga option")')
-      write(*,'(" nempty0 : ",G18.10)') nempty0
-      write(*,'(" lradstp : ",I4)') lradstp
-      write(*,'(" nrmtscf : ",G18.10)') nrmtscf
-      write(*,'(" msmooth : ",I4)') msmooth
-    end if
-  end if
-case('taudft')
-  read(50,*,err=20) taudft
+  read(50,*,err=20)
+  write(*,*)
+  write(*,'("Info(readinput): variable ''metagga'' is no longer used")')
 case('t0tdlr')
-  read(50,*,err=20) t0tdlr
-  if (t0tdlr.le.0.d0) then
-    write(*,*)
-    write(*,'("Error(readinput): t0tdlr <= 0 : ",G18.10)') t0tdlr
-    write(*,*)
-    stop
-  end if
+  read(50,*,err=20)
+  write(*,*)
+  write(*,'("Info(readinput): variable ''t0tdlr'' is no longer used")')
 case('tdphi')
   read(50,*,err=20) tdphi
 ! convert phase from degrees to radians
@@ -1957,8 +1955,34 @@ case('tephde')
   read(50,*,err=20) tephde
 case('bdiag')
   read(50,*,err=20) bdiag
+case('ecutb')
+  read(50,*,err=20) ecutb
+  if (ecutb.le.0.d0) then
+    write(*,*)
+    write(*,'("Error(readinput): ecutb <= 0 : ",G18.10)') ecutb
+    write(*,*)
+    stop
+  end if
+case('ediag')
+  read(50,*,err=20) ediag
+case('pwxpsn')
+  read(50,*,err=20) pwxpsn
+  if (pwxpsn.lt.1) then
+    write(*,*)
+    write(*,'("Error(readinput): pwxpsn < 1 : ",I8)') pwxpsn
+    write(*,*)
+    stop
+  end if
 case('ramdisk')
   read(50,*,err=20) ramdisk
+case('wrtdsk')
+  read(50,*,err=20) wrtdsk
+case('epsdmat')
+  read(50,*,err=20) epsdmat
+case('tm3old')
+  read(50,*,err=20) tm3old
+case('batch')
+  read(50,*,err=20) batch
 case('')
   goto 10
 case default
@@ -1992,8 +2016,8 @@ if (t1.ne.0.d0) then
   t1=t1*pi/180.d0
   call axangrot(axang(:),t1,rot)
   do i=1,3
-    v1(:)=avec(:,i)
-    call r3mv(rot,v1,avec(:,i))
+    v(:)=avec(:,i)
+    call r3mv(rot,v,avec(:,i))
   end do
 end if
 ! randomise lattice vectors if required
@@ -2011,8 +2035,8 @@ if (molecule) then
   call r3minv(avec,ainv)
   do is=1,nspecies
     do ia=1,natoms(is)
-      call r3mv(ainv,atposl(:,ia,is),v1)
-      atposl(:,ia,is)=v1(:)
+      call r3mv(ainv,atposl(:,ia,is),v)
+      atposl(:,ia,is)=v(:)
     end do
   end do
 end if
@@ -2021,12 +2045,12 @@ if (rndatposc.gt.0.d0) then
   call r3minv(avec,ainv)
   do is=1,nspecies
     do ia=1,natoms(is)
-      call r3mv(avec,atposl(:,ia,is),v1)
+      call r3mv(avec,atposl(:,ia,is),v)
       do i=1,3
         t1=rndatposc*(randomu()-0.5d0)
-        v1(i)=v1(i)+t1
+        v(i)=v(i)+t1
       end do
-      call r3mv(ainv,v1,atposl(:,ia,is))
+      call r3mv(ainv,v,atposl(:,ia,is))
     end do
   end do
 end if
@@ -2060,6 +2084,8 @@ subroutine addstr(slist)
 implicit none
 ! arguments
 character(256), intent(inout), allocatable :: slist(:)
+! local variables
+integer n
 ! allocatable arrays
 character(256), allocatable :: stmp(:)
 n=size(slist)
