@@ -13,7 +13,7 @@ integer io,jo,ko,l,i,j
 e0min=0.d0
 do is=1,nspecies
   open(50,file=trim(sppath)//trim(spfname(is)),status='OLD',form='FORMATTED', &
-   iostat=ios)
+   action='READ',iostat=ios)
   if (ios.ne.0) then
     write(*,*)
     write(*,'("Error(readspecies): error opening species file ",A)') &
@@ -335,6 +335,5 @@ if (rmtall.gt.0.d0) rmt(1:nspecies)=rmtall
 call addlorbcnd
 ! subtract 2 Hartree from the minimum energy
 e0min=e0min-2.d0
-return
 end subroutine
 
