@@ -11,7 +11,7 @@ implicit none
 integer iq,jq,ifq,jfq
 integer idm,i1,i2,i3
 integer version_(3),ios
-integer natmtot_,npcmtmax_,ngtot_
+integer natmtot_,npcmtmax_,ngtc_,ngtot_
 integer ndmag_,fsmtype_,nqpt_,nfqrz_
 complex(8) z1
 ! automatic arrays
@@ -19,14 +19,15 @@ complex(8) zv(natmtot)
 ! allocatable arrays
 integer, allocatable :: ivq_(:,:),iqrzf_(:),map(:)
 complex(8), allocatable :: zfmt(:,:),zfir(:)
-open(40,file='STATE_ULR.OUT',form='UNFORMATTED',status='OLD',iostat=ios)
+open(100,file='STATE_ULR.OUT',form='UNFORMATTED',action='READ',status='OLD', &
+ iostat=ios)
 if (ios.ne.0) then
   write(*,*)
   write(*,'("Error(readstulr): error opening STATE_ULR.OUT")')
   write(*,*)
   stop
 end if
-read(40) version_
+read(100) version_
 if ((version(1).ne.version_(1)).or.(version(2).ne.version_(2)).or. &
     (version(3).ne.version_(3))) then
   write(*,*)
@@ -34,7 +35,7 @@ if ((version(1).ne.version_(1)).or.(version(2).ne.version_(2)).or. &
   write(*,'(" current       : ",I3.3,".",I3.3,".",I3.3)') version
   write(*,'(" STATE_ULR.OUT : ",I3.3,".",I3.3,".",I3.3)') version_
 end if
-read(40) natmtot_
+read(100) natmtot_
 if (natmtot.ne.natmtot_) then
   write(*,*)
   write(*,'("Error(readstulr): differing natmtot")')
@@ -43,7 +44,7 @@ if (natmtot.ne.natmtot_) then
   write(*,*)
   stop
 end if
-read(40) npcmtmax_
+read(100) npcmtmax_
 if (npcmtmax.ne.npcmtmax_) then
   write(*,*)
   write(*,'("Error(readstulr): differing npcmtmax")')
@@ -52,7 +53,16 @@ if (npcmtmax.ne.npcmtmax_) then
   write(*,*)
   stop
 end if
-read(40) ngtot_
+read(100) ngtc_
+if (ngtc.ne.ngtc_) then
+  write(*,*)
+  write(*,'("Error(readstulr): differing ngtc")')
+  write(*,'(" current       : ",I8)') ngtc
+  write(*,'(" STATE_ULR.OUT : ",I8)') ngtc_
+  write(*,*)
+  stop
+end if
+read(100) ngtot_
 if (ngtot.ne.ngtot_) then
   write(*,*)
   write(*,'("Error(readstulr): differing ngtot")')
@@ -61,7 +71,7 @@ if (ngtot.ne.ngtot_) then
   write(*,*)
   stop
 end if
-read(40) ndmag_
+read(100) ndmag_
 if (ndmag.ne.ndmag_) then
   write(*,*)
   write(*,'("Error(readstulr): differing ndmag")')
@@ -70,7 +80,7 @@ if (ndmag.ne.ndmag_) then
   write(*,*)
   stop
 end if
-read(40) fsmtype_
+read(100) fsmtype_
 if (fsmtype.ne.fsmtype_) then
   write(*,*)
   write(*,'("Error(readstulr): differing fsmtype")')
@@ -79,14 +89,14 @@ if (fsmtype.ne.fsmtype_) then
   write(*,*)
   stop
 end if
-read(40) nqpt_
+read(100) nqpt_
 if (nqpt_.le.0) then
   write(*,*)
   write(*,'("Error(readstulr): nqpt_ <= 0 : ",I8)') nqpt_
   write(*,*)
   stop
 end if
-read(40) nfqrz_
+read(100) nfqrz_
 if (nfqrz_.le.0) then
   write(*,*)
   write(*,'("Error(readstulr): nfqrz_ <= 0 : ",I8)') nfqrz_
@@ -94,8 +104,8 @@ if (nfqrz_.le.0) then
   stop
 end if
 allocate(ivq_(3,nqpt_),iqrzf_(nfqrz_),map(nfqrz_))
-read(40) ivq_
-read(40) iqrzf_
+read(100) ivq_
+read(100) iqrzf_
 ! generate map from old Q-vector grid to new
 map(:)=0
 do ifq=1,nfqrz_
@@ -117,11 +127,11 @@ rhoqir(:,:)=0.d0
 do ifq=1,nfqrz_
   jfq=map(ifq)
   if (jfq.gt.0) then
-    read(40) rhoqmt(:,:,jfq)
-    read(40) rhoqir(:,jfq)
+    read(100) rhoqmt(:,:,jfq)
+    read(100) rhoqir(:,jfq)
   else
-    read(40) zfmt
-    read(40) zfir
+    read(100) zfmt
+    read(100) zfir(1:ngtc)
   end if
 end do
 ! read the Q-space Kohn-Sham potential
@@ -130,11 +140,11 @@ vsqir(:,:)=0.d0
 do ifq=1,nfqrz_
   jfq=map(ifq)
   if (jfq.gt.0) then
-    read(40) vsqmt(:,:,jfq)
-    read(40) vsqir(:,jfq)
+    read(100) vsqmt(:,:,jfq)
+    read(100) vsqir(:,jfq)
   else
-    read(40) zfmt
-    read(40) zfir
+    read(100) zfmt
+    read(100) zfir
   end if
 end do
 ! read the external Coulomb potential in Q-space
@@ -142,9 +152,9 @@ vclq(:)=0.d0
 do ifq=1,nfqrz_
   jfq=map(ifq)
   if (jfq.gt.0) then
-    read(40) vclq(jfq)
+    read(100) vclq(jfq)
   else
-    read(40) z1
+    read(100) z1
   end if
 end do
 if (spinpol) then
@@ -155,13 +165,13 @@ if (spinpol) then
     jfq=map(ifq)
     if (jfq.gt.0) then
       do idm=1,ndmag
-        read(40) magqmt(:,:,idm,jfq)
-        read(40) magqir(:,idm,jfq)
+        read(100) magqmt(:,:,idm,jfq)
+        read(100) magqir(:,idm,jfq)
       end do
     else
       do idm=1,ndmag
-        read(40) zfmt
-        read(40) zfir
+        read(100) zfmt
+        read(100) zfir(1:ngtc)
       end do
     end if
   end do
@@ -171,13 +181,13 @@ if (spinpol) then
     jfq=map(ifq)
     if (jfq.gt.0) then
       do idm=1,ndmag
-        read(40) bsqmt(:,:,idm,jfq)
-        read(40) bsqir(:,idm,jfq)
+        read(100) bsqmt(:,:,idm,jfq)
+        read(100) bsqir(:,idm,jfq)
       end do
     else
       do idm=1,ndmag
-        read(40) zfmt
-        read(40) zfir
+        read(100) zfmt
+        read(100) zfir
       end do
     end if
   end do
@@ -188,24 +198,23 @@ if (spinpol) then
     jfq=map(ifq)
     if (jfq.gt.0) then
       do idm=1,ndmag
-        read(40) bfcq(idm,jfq)
-        read(40) bfcmtq(:,idm,jfq)
+        read(100) bfcq(idm,jfq)
+        read(100) bfcmtq(:,idm,jfq)
       end do
     else
       do idm=1,ndmag
-        read(40) z1
-        read(40) zv
+        read(100) z1
+        read(100) zv
       end do
     end if
   end do
 ! read fixed spin moment effective fields
   if (fsmtype.ne.0) then
-    read(40) bfsmc
-    read(40) bfsmcmt
+    read(100) bfsmc
+    read(100) bfsmcmt
   end if
 end if
-close(40)
+close(100)
 deallocate(map,zfmt,zfir)
-return
 end subroutine
 
