@@ -3,12 +3,10 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine readtimes(itimes0)
+subroutine readtimes
 use modmain
 use modtddft
 implicit none
-! arguments
-integer, intent(out) :: itimes0
 ! local variables
 integer ios
 real(8) times_,t1
