@@ -34,14 +34,11 @@ implicit none
 real(8), intent(in) :: rfmt1(npmtmax,natmtot),rfir1(ngtot)
 real(8), intent(in) :: rfmt2(npmtmax,natmtot),rfir2(ngtot)
 ! local variables
-integer is,ias,ir,nthd
+integer is,ias,nthd
 ! external functions
 real(8), external :: rfmtinp
 ! interstitial contribution
-rfinp=0.d0
-do ir=1,ngtot
-  rfinp=rfinp+rfir1(ir)*rfir2(ir)*cfunir(ir)
-end do
+rfinp=sum(rfir1(1:ngtot)*rfir2(1:ngtot)*cfunir(1:ngtot))
 rfinp=rfinp*omega/dble(ngtot)
 ! muffin-tin contribution
 call holdthd(natmtot,nthd)
