@@ -7,14 +7,14 @@ real(8) function rfinpc(ld,rfmt1,rfir1,rfmt2,rfir2)
 use modmain
 use modomp
 implicit none
+! arguments
 integer, intent(in) :: ld
 real(8), intent(in) :: rfmt1(ld,natmtot),rfir1(ngtot)
 real(8), intent(in) :: rfmt2(ld,natmtot),rfir2(ngtot)
 ! local variables
 integer is,ias,ir,nthd
 ! external functions
-real(8) rfmtinp
-external rfmtinp
+real(8), external :: rfmtinp
 ! interstitial contribution
 rfinpc=0.d0
 do ir=1,ngtot
@@ -33,6 +33,5 @@ do ias=1,natmtot
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
-return
 end function
 
