@@ -6,14 +6,15 @@
 !BOP
 ! !ROUTINE: rfinterp
 ! !INTERFACE:
-subroutine rfinterp(ni,xi,fi,no,xo,fo)
+subroutine rfinterp(ni,xi,wci,fi,no,xo,fo)
 ! !INPUT/OUTPUT PARAMETERS:
-!   ni : number of input points (in,integer)
-!   xi : input abscissa array (in,real(ni))
-!   fi : input data array (in,real(ni)
-!   no : number of output points (in,integer)
-!   xo : output abscissa array (in,real(ni))
-!   fo : output interpolated function (out,real(no))
+!   ni  : number of input points (in,integer)
+!   xi  : input abscissa array (in,real(ni))
+!   wci : input spline coefficient weights (in,real(12,ni))
+!   fi  : input data array (in,real(ni))
+!   no  : number of output points (in,integer)
+!   xo  : output abscissa array (in,real(no))
+!   fo  : output interpolated function (out,real(no))
 ! !DESCRIPTION:
 !   Given a function defined on a set of input points, this routine uses a
 !   clamped cubic spline to interpolate the function on a different set of
@@ -27,7 +28,7 @@ subroutine rfinterp(ni,xi,fi,no,xo,fo)
 implicit none
 ! arguments
 integer, intent(in) :: ni
-real(8), intent(in) :: xi(ni),fi(ni)
+real(8), intent(in) :: xi(ni),wci(12,ni),fi(ni)
 integer, intent(in) :: no
 real(8), intent(in) :: xo(no)
 real(8), intent(out) :: fo(no)
@@ -53,7 +54,7 @@ if (ni.eq.1) then
   return
 end if
 ! compute the spline coefficients
-call spline(ni,xi,fi,cf)
+call splinew(ni,wci,fi,cf)
 ! evaluate spline at output points
 i=1
 do l=1,no
@@ -77,7 +78,6 @@ do l=1,no
   dx=x-xi(i)
   fo(l)=fi(i)+dx*(cf(1,i)+dx*(cf(2,i)+dx*cf(3,i)))
 end do
-return
 end subroutine
 !EOC
 
