@@ -9,22 +9,20 @@ implicit none
 ! arguments
 real(8), intent(in) :: rfirc(ngtc)
 real(8), intent(out) :: rfir(ngtot)
-! local variables
-integer ig
+! automatic arrays
+complex(8) zfftc(ngtc)
 ! allocatable arrays
-complex(8), allocatable :: zfftc(:),zfft(:)
-allocate(zfftc(ngtc),zfft(ngtot))
+complex(8), allocatable :: zfft(:)
+allocate(zfft(ngtot))
 ! Fourier transform function on coarse grid to G-space
 zfftc(:)=rfirc(:)
 call zfftifc(3,ngdgc,-1,zfftc)
 ! Fourier transform to fine real-space grid
 zfft(:)=0.d0
-do ig=1,ngvc
-  zfft(igfft(ig))=zfftc(igfc(ig))
-end do
+zfft(igfft(1:ngvc))=zfftc(igfc(1:ngvc))
 call zfftifc(3,ngridg,1,zfft)
 ! output real function
 rfir(:)=dble(zfft(:))
-deallocate(zfftc,zfft)
+deallocate(zfft)
 end subroutine
 
