@@ -24,19 +24,19 @@ implicit none
 ! arguments
 real(8), intent(inout) :: rfmt(npmtmax,natmtot)
 ! local variables
-integer is,ias,lm,nthd
-integer nr,nri,nro
-integer iro,ir,npi,i
-integer nrc,nrci,nrco
-integer irco,irc,npci
+integer is,ias,lm
+integer nr,nri,nro,iro
+integer nrc,nrci,nrco,irco
+integer i0,i1,nthd
 ! automatic arrays
-real(8) rfmt1(npcmtmax),fr(nrmtmax),frc(nrcmtmax)
+real(8) rfmt1(npcmtmax),fi(nrcmtmax),fo(nrmtmax)
 if (lradstp.eq.1) return
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
-!$OMP PRIVATE(rfmt1,fr,frc,is,nr,nri,nro) &
-!$OMP PRIVATE(iro,npi,nrc,nrci,nrco) &
-!$OMP PRIVATE(irco,npci,lm,i,irc,ir) &
+!$OMP PRIVATE(rfmt1,fi,fo,is) &
+!$OMP PRIVATE(nr,nri,nro,iro) &
+!$OMP PRIVATE(nrc,nrci,nrco,irco) &
+!$OMP PRIVATE(lm,i0,i1) &
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
@@ -44,50 +44,36 @@ do ias=1,natmtot
   nri=nrmti(is)
   nro=nr-nri
   iro=nri+1
-  npi=npmti(is)
   nrc=nrcmt(is)
   nrci=nrcmti(is)
   nrco=nrc-nrci
   irco=nrci+1
-  npci=npcmti(is)
 ! copy the input function
-  call dcopy(npcmt(is),rfmt(:,ias),1,rfmt1,1)
+  rfmt1(1:npcmt(is))=rfmt(1:npcmt(is),ias)
 ! interpolate up to lmaxi over entire muffin-tin
   do lm=1,lmmaxi
-    i=lm
-    do irc=1,nrci
-      frc(irc)=rfmt1(i)
-      i=i+lmmaxi
-    end do
-    do irc=irco,nrc
-      frc(irc)=rfmt1(i)
-      i=i+lmmaxo
-    end do
-    call rfinterp(nrc,rcmt(:,is),wcrcmt(:,:,is),frc,nr,rlmt(:,1,is),fr)
-    i=lm
-    do ir=1,nri
-      rfmt(i,ias)=fr(ir)
-      i=i+lmmaxi
-    end do
-    do ir=iro,nr
-      rfmt(i,ias)=fr(ir)
-      i=i+lmmaxo
-    end do
+    i1=lmmaxi*(nrci-1)+lm
+    fi(1:nrci)=rfmt1(lm:i1:lmmaxi)
+    i0=i1+lmmaxi
+    i1=lmmaxo*(nrc-irco)+i0
+    fi(irco:nrc)=rfmt1(i0:i1:lmmaxo)
+    call rfinterp(nrc,rcmt(:,is),wcrcmt(:,:,is),fi,nr,rlmt(:,1,is),fo)
+    i1=lmmaxi*(nri-1)+lm
+    rfmt(lm:i1:lmmaxi,ias)=fo(1:nri)
+    i0=i1+lmmaxi
+    i1=lmmaxo*(nr-iro)+i0
+    rfmt(i0:i1:lmmaxo,ias)=fo(iro:nr)
   end do
 ! interpolate up to lmaxo on outer part of muffin-tin
   do lm=lmmaxi+1,lmmaxo
-    i=npci+lm
-    do irc=irco,nrc
-      frc(irc)=rfmt1(i)
-      i=i+lmmaxo
-    end do
-    call rfinterp(nrco,rcmt(irco,is),wcrcmt(:,irco,is),frc(irco),nro, &
-     rsp(iro,is),fr(iro))
-    i=npi+lm
-    do ir=iro,nr
-      rfmt(i,ias)=fr(ir)
-      i=i+lmmaxo
-    end do
+    i0=lmmaxi*nrci+lm
+    i1=lmmaxo*(nrc-irco)+i0
+    fi(irco:nrc)=rfmt1(i0:i1:lmmaxo)
+    call rfinterp(nrco,rcmt(irco,is),wcrcmt(:,irco,is),fi(irco),nro, &
+     rsp(iro,is),fo(iro))
+    i0=lmmaxi*nri+lm
+    i1=lmmaxo*(nr-iro)+i0
+    rfmt(i0:i1:lmmaxo,ias)=fo(iro:nr)
   end do
 end do
 !$OMP END PARALLEL DO
