@@ -38,17 +38,19 @@ real(8), intent(in) :: rfmt1(*),rfmt2(*)
 integer n,ir,i
 ! compute the dot-products for each radial point and integrate over r
 rfmtinp=0.d0
-i=1
 if (lmaxi.eq.1) then
+!$OMP SIMD PRIVATE(i) REDUCTION(+:rfmtinp)
   do ir=1,nri
+    i=4*(ir-1)+1
     rfmtinp=rfmtinp+wr(ir) &
      *(rfmt1(i)*rfmt2(i) &
       +rfmt1(i+1)*rfmt2(i+1) &
       +rfmt1(i+2)*rfmt2(i+2) &
       +rfmt1(i+3)*rfmt2(i+3))
-    i=i+4
   end do
+  i=4*nri+1
 else
+  i=1
   n=lmmaxi-1
   do ir=1,nri
     rfmtinp=rfmtinp+wr(ir)*dot_product(rfmt1(i:i+n),rfmt2(i:i+n))
