@@ -11,25 +11,20 @@ integer, intent(in) :: lm,nr,nri
 real(8), intent(in) :: rfmt(npmtmax)
 real(8), intent(out) :: fr(nrmtmax)
 ! local variables
-integer iro,ir,i
+integer iro,i0,i1
 if (lm.gt.lmmaxi) then
   fr(1:nri)=0.d0
 else
-  i=lm
-  do ir=1,nri
-    fr(ir)=rfmt(i)
-    i=i+lmmaxi
-  end do
+  i1=lmmaxi*(nri-1)+lm
+  fr(1:nri)=rfmt(lm:i1:lmmaxi)
 end if
 iro=nri+1
 if (lm.gt.lmmaxo) then
   fr(iro:nr)=0.d0
 else
-  i=lmmaxi*nri+lm
-  do ir=iro,nr
-    fr(ir)=rfmt(i)
-    i=i+lmmaxo
-  end do
+  i0=lmmaxi*nri+lm
+  i1=lmmaxo*(nr-iro)+i0
+  fr(iro:nr)=rfmt(i0:i1:lmmaxo)
 end if
 end subroutine
 
