@@ -10,47 +10,29 @@ implicit none
 integer, intent(in) :: m,nr,nri
 real(8), intent(inout) :: rfmt(*)
 ! local variables
-integer nro,iro,ir
-integer lm,npi,i
+integer nro,iro,lm
+integer i1,j0,j1
 ! automatic arrays
 real(8) fr(nr)
 if (m.le.0) return
 nro=nr-nri
 iro=nri+1
-npi=lmmaxi*nri
 do lm=1,lmmaxi
-  i=lm
-  do ir=1,nri
-    fr(ir)=rfmt(i)
-    i=i+lmmaxi
-  end do
-  do ir=iro,nr
-    fr(ir)=rfmt(i)
-    i=i+lmmaxo
-  end do
+  i1=lmmaxi*(nri-1)+lm
+  j0=i1+lmmaxi
+  j1=lmmaxo*(nr-iro)+j0
+  fr(1:nri)=rfmt(lm:i1:lmmaxi)
+  fr(iro:nr)=rfmt(j0:j1:lmmaxo)
   call fsmooth(m,nr,fr)
-  i=lm
-  do ir=1,nri
-    rfmt(i)=fr(ir)
-    i=i+lmmaxi
-  end do
-  do ir=iro,nr
-    rfmt(i)=fr(ir)
-    i=i+lmmaxo
-  end do
+  rfmt(lm:i1:lmmaxi)=fr(1:nri)
+  rfmt(j0:j1:lmmaxo)=fr(iro:nr)
 end do
 do lm=lmmaxi+1,lmmaxo
-  i=npi+lm
-  do ir=iro,nr
-    fr(ir)=rfmt(i)
-    i=i+lmmaxo
-  end do
+  j0=lmmaxi*nri+lm
+  j1=lmmaxo*(nr-iro)+j0
+  fr(iro:nr)=rfmt(j0:j1:lmmaxo)
   call fsmooth(m,nro,fr(iro))
-  i=npi+lm
-  do ir=iro,nr
-    rfmt(i)=fr(ir)
-    i=i+lmmaxo
-  end do
+  rfmt(j0:j1:lmmaxo)=fr(iro:nr)
 end do
 end subroutine
 
