@@ -23,15 +23,15 @@ implicit none
 ! local variables
 integer ispn,idm,is,ias
 integer nr,nri,iro,ir,i
-real(8) v(ndmag),sum,t1
-! automatic arrays
-real(8) fr(nrmtmax)
+real(8) v(ndmag),sm,t1
+! external functions
+real(8), external :: rfmtint
 do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
   nri=nrmti(is)
   iro=nri+1
-  sum=0.d0
+  sm=0.d0
 ! loop over spin channels
   do ispn=1,nspncr
 ! add the core density to the muffin-tin density
@@ -46,17 +46,15 @@ do ias=1,natmtot
     end do
 ! compute the core charge inside the muffin-tins
     t1=dot_product(wrmt(1:nr,is),rhocr(1:nr,ias,ispn))
-    sum=sum+fourpi*y00*t1
+    sm=sm+fourpi*y00*t1
   end do
 ! core leakage charge
-  chgcrlk(ias)=chgcr(is)-sum
+  chgcrlk(ias)=chgcr(is)-sm
 ! add to the magnetisation in the case of a spin-polarised core
   if (spincore) then
 ! compute the moment in the muffin-tin
     do idm=1,ndmag
-      call rfmtlm(1,nr,nri,magmt(:,ias,idm),fr)
-      t1=dot_product(wrmt(1:nr,is),fr(1:nr))
-      v(idm)=fourpi*y00*t1
+      v(idm)=rfmtint(nr,nri,wrmt(:,is),magmt(:,ias,idm))
     end do
 ! normalise
     if (ncmag) then
@@ -68,18 +66,17 @@ do ias=1,natmtot
 ! add the core magnetisation to the total
     i=1
     do ir=1,nri
-      t1=abs(rhocr(ir,ias,1)-rhocr(ir,ias,2))
+      t1=rhocr(ir,ias,1)-rhocr(ir,ias,2)
       magmt(i,ias,:)=magmt(i,ias,:)+t1*v(:)
       i=i+lmmaxi
     end do
     do ir=iro,nr
-      t1=abs(rhocr(ir,ias,1)-rhocr(ir,ias,2))
+      t1=rhocr(ir,ias,1)-rhocr(ir,ias,2)
       magmt(i,ias,:)=magmt(i,ias,:)+t1*v(:)
       i=i+lmmaxo
     end do
   end if
 end do
-return
 end subroutine
 !EOC
 
