@@ -28,7 +28,7 @@ use modomp
 !   transform (SHT), the wavefunction is converted to real-space and the density
 !   obtained from its modulus squared. A similar proccess is used for the
 !   intersitial density in which the wavefunction in real-space is obtained from
-!   a Fourier transform of the APW functions. See routines {\tt wavefmt},
+!   a Fourier transform of the APW functions. See routines {\tt wfmtsv},
 !   {\tt genshtmat} and {\tt eveqn}.
 !
 ! !REVISION HISTORY:
@@ -47,99 +47,63 @@ real(8), intent(in) :: wppt,occsvp(nstsv)
 complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv)
 complex(8), intent(in) :: evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv)
 ! local variables
-integer ispn,jspn,ist
-integer is,ias,i,j,n,nthd
-integer nrc,nrci,npc
-real(8) wo
-real(8) ts0,ts1
-complex(8) zq(2),z1
+integer ispn,jspn,nst,ist
+integer is,ias,npc
+integer i,j,n,nthd
+real(8) wo,ts0,ts1
+complex(8) z1
 ! automatic arrays
-logical done(nstfv,nspnfv)
-complex(8) wfmt1(npcmtmax),wfmt2(npcmtmax,nspinor)
+integer idx(nstsv)
 complex(8) wfir(ngtc,nspinor),wfgp(ngkmax)
 ! allocatable arrays
-complex(8), allocatable :: wfmt3(:,:,:)
+complex(8), allocatable :: wfmt(:,:,:)
 call timesec(ts0)
 !----------------------------------------------!
 !     muffin-tin density and magnetisation     !
 !----------------------------------------------!
-call holdthd(natmtot,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfmt1,wfmt2,wfmt3) &
-!$OMP PRIVATE(is,nrc,nrci,npc) &
-!$OMP PRIVATE(zq,done,i,j,wo) &
-!$OMP PRIVATE(ispn,jspn,n,ist,z1) &
-!$OMP NUM_THREADS(nthd)
-if (tevecsv) allocate(wfmt3(npcmtmax,nstfv,nspnfv))
-!$OMP DO
+! number of and index to occupied states
+nst=0
+do ist=1,nstsv
+  if (abs(occsvp(ist)).gt.epsocc) then
+    nst=nst+1
+    idx(nst)=ist
+  end if
+end do
+allocate(wfmt(npcmtmax,nspinor,nst))
 do ias=1,natmtot
   is=idxis(ias)
-  nrc=nrcmt(is)
-  nrci=nrcmti(is)
   npc=npcmt(is)
-! de-phasing factor for spin-spirals
-  if (ssdph) then
-    zq(1)=zqss(ias)
-    zq(2)=conjg(zq(1))
-  end if
-  done(:,:)=.false.
-  do j=1,nstsv
-    wo=occsvp(j)
-    if (abs(wo).lt.epsocc) cycle
-    wo=wo*wppt
-    if (tevecsv) then
-! generate spinor wavefunction from second-variational eigenvectors
-      i=0
-      do ispn=1,nspinor
-        jspn=jspnfv(ispn)
-        n=ngp(jspn)
-        wfmt2(1:npc,ispn)=0.d0
-        do ist=1,nstfv
-          i=i+1
-          z1=evecsv(i,j)
-          if (abs(dble(z1))+abs(aimag(z1)).lt.epsocc) cycle
-          if (ssdph) z1=z1*zq(ispn)
-          if (.not.done(ist,jspn)) then
-            call wavefmt(lradstp,ias,n,apwalm(:,:,:,ias,jspn), &
-             evecfv(:,ist,jspn),wfmt1)
-! convert to spherical coordinates
-            call zbsht(nrc,nrci,wfmt1,wfmt3(:,ist,jspn))
-            done(ist,jspn)=.true.
-          end if
-! add to spinor wavefunction
-          call zaxpy(npc,z1,wfmt3(:,ist,jspn),1,wfmt2(:,ispn),1)
-        end do
-      end do
-    else
-! spin-unpolarised wavefunction
-      call wavefmt(lradstp,ias,ngp,apwalm(:,:,:,ias,1),evecfv(:,j,1),wfmt1)
-! convert to spherical coordinates
-      call zbsht(nrc,nrci,wfmt1,wfmt2)
-    end if
+  call wfmtsv(.false.,lradstp,is,ias,nst,idx,ngp,apwalm,evecfv,evecsv,npcmtmax,&
+   wfmt)
+  call holdthd(nst,nthd)
+!$OMP PARALLEL DO DEFAULT(SHARED) &
+!$OMP PRIVATE(j,wo) &
+!$OMP NUM_THREADS(nthd)
+  do i=1,nst
+    j=idx(i)
+    wo=occsvp(j)*wppt
 ! add to density and magnetisation
     call omp_set_lock(lock(ias))
     if (spinpol) then
 ! spin-polarised
       if (ncmag) then
 ! non-collinear
-        call rmk1(npc,wo,wfmt2,wfmt2(:,2),rhomt(:,ias),magmt(:,ias,1), &
+        call rmk1(npc,wo,wfmt(:,1,i),wfmt(:,2,i),rhomt(:,ias),magmt(:,ias,1), &
          magmt(:,ias,2),magmt(:,ias,3))
       else
 ! collinear
-        call rmk2(npc,wo,wfmt2,wfmt2(:,2),rhomt(:,ias),magmt(:,ias,1))
+        call rmk2(npc,wo,wfmt(:,1,i),wfmt(:,2,i),rhomt(:,ias),magmt(:,ias,1))
       end if
     else
 ! spin-unpolarised
-      call rmk3(npc,wo,wfmt2,rhomt(:,ias))
+      call rmk3(npc,wo,wfmt(:,1,i),rhomt(:,ias))
     end if
     call omp_unset_lock(lock(ias))
   end do
-! end loop over atoms
+!$OMP END PARALLEL DO
+  call freethd(nthd)
 end do
-!$OMP END DO
-if (tevecsv) deallocate(wfmt3)
-!$OMP END PARALLEL
-call freethd(nthd)
+deallocate(wfmt)
 !------------------------------------------------!
 !     interstitial density and magnetisation     !
 !------------------------------------------------!
