@@ -22,7 +22,7 @@ call holdthd(nfqrz,nthd)
 do ifq=1,nfqrz
   do ias=1,natmtot
     is=idxis(ias)
-    call zcopy(npcmt(is),rhoqmt(:,ias,ifq),1,zfmt,1)
+    zfmt(1:npcmt(is))=rhoqmt(1:npcmt(is),ias,ifq)
     call zfsht(nrcmt(is),nrcmti(is),zfmt,rhoqmt(:,ias,ifq))
   end do
 end do
@@ -40,7 +40,7 @@ do ifq=1,nfqrz
   do idm=1,ndmag
     do ias=1,natmtot
       is=idxis(ias)
-      call zcopy(npcmt(is),magqmt(:,ias,idm,ifq),1,zfmt,1)
+      zfmt(1:npcmt(is))=magqmt(1:npcmt(is),ias,idm,ifq)
       call zfsht(nrcmt(is),nrcmti(is),zfmt,magqmt(:,ias,idm,ifq))
     end do
   end do
