@@ -24,7 +24,7 @@ use modmain
 implicit none
 ! local variables
 integer is,ia,ias
-integer nr,nri,ir,i
+integer nr,nri,iro,i0,i1
 real(8) t1,t2
 if (.not.trhonorm) return
 ! check error in total charge
@@ -44,15 +44,12 @@ do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
   nri=nrmti(is)
-  i=1
-  do ir=1,nri
-    rhomt(i,ias)=rhomt(i,ias)+t2
-    i=i+lmmaxi
-  end do
-  do ir=nri+1,nr
-    rhomt(i,ias)=rhomt(i,ias)+t2
-    i=i+lmmaxo
-  end do
+  iro=nri+1
+  i1=lmmaxi*(nri-1)+1
+  rhomt(1:i1:lmmaxi,ias)=rhomt(1:i1:lmmaxi,ias)+t2
+  i0=i1+lmmaxi
+  i1=lmmaxo*(nr-iro)+i0
+  rhomt(i0:i1:lmmaxo,ias)=rhomt(i0:i1:lmmaxo,ias)+t2
 end do
 rhoir(1:ngtot)=rhoir(1:ngtot)+t1
 ! add the difference to the charges
