@@ -7,8 +7,7 @@ subroutine rotdmat(rspl,rspn,lmax,nspinor,ld,dmat1,dmat2)
 implicit none
 ! arguments
 real(8), intent(in) :: rspl(3,3),rspn(3,3)
-integer, intent(in) :: lmax,nspinor
-integer, intent(in) :: ld
+integer, intent(in) :: lmax,nspinor,ld
 complex(8), intent(in) :: dmat1(ld,nspinor,ld,nspinor)
 complex(8), intent(inout) :: dmat2(ld,nspinor,ld,nspinor)
 ! local variables
@@ -69,7 +68,7 @@ if (nspinor.eq.2) then
   call rotaxang(eps,rspn,det,v,th)
 ! find the SU(2) representation of the rotation matrix
   call axangsu2(v,th,su2)
-! apply SU(2) symmetry matrix as U*D*conjg(U*) andd add to dmat2
+! apply SU(2) symmetry matrix as U*D*U† and add to dmat2
   do lm1=1,lmmax
     do lm2=1,lmmax
       a(:,:)=dm(lm1,:,lm2,:)
