@@ -3,7 +3,7 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine sctovec(tp,v)
+pure subroutine sctovec(tp,v)
 implicit none
 ! arguments
 real(8), intent(in) :: tp(2)
@@ -14,6 +14,5 @@ t1=sin(tp(1))
 v(1)=t1*cos(tp(2))
 v(2)=t1*sin(tp(2))
 v(3)=cos(tp(1))
-return
 end subroutine
 
