@@ -24,10 +24,10 @@ real(8), intent(in) :: x
 real(8) t1
 if (abs(x).gt.50.d0) then
   sdelta_fd=0.d0
-  return
+else
+  t1=exp(-x)
+  sdelta_fd=t1/((1.d0+t1)**2)
 end if
-t1=exp(-x)
-sdelta_fd=t1/((1.d0+t1)**2)
 end function
 !EOC
 
