@@ -33,10 +33,9 @@ real(8), intent(in) :: x
 ! local variables
 integer i
 real(8), parameter :: sqpi=1.7724538509055160273d0
-real(8) sum,t1
+real(8) sm,t0,t1
 ! external functions
-real(8) factnm,hermite
-external factnm,hermite
+real(8), external :: factnm,hermite
 if (n.eq.0) then
   sdelta_mp=exp(-x**2)/sqpi
   return
@@ -57,14 +56,14 @@ if (abs(x).gt.12.d0) then
   sdelta_mp=0.d0
   return
 end if
-sum=0.d0
-do i=0,n
-  t1=1.d0/(factnm(i,1)*dble(4**i)*sqpi)
+t0=exp(-x**2)/sqpi
+sm=t0
+do i=1,n
+  t1=t0/(factnm(i,1)*dble(4**i))
   if (mod(i,2).ne.0) t1=-t1
-  sum=sum+t1*hermite(2*i,x)*exp(-x**2)
+  sm=sm+t1*hermite(2*i,x)
 end do
-sdelta_mp=sum
-return
+sdelta_mp=sm
 end function
 !EOC
 
