@@ -18,7 +18,7 @@ call init1
 ! read density and potentials from file
 call readstate
 ! use existing density if wsfac is default
-if ((wsfac(1).le.-1.d6).or.(wsfac(2).ge.1.d6)) goto 10
+if ((wsfac(1).le.-1.d6).and.(wsfac(2).ge.1.d6)) goto 10
 ! make a copy of the core state occupancies
 allocate(occcr0(nstspmax,natmtot))
 occcr0(:,:)=occcr(:,:)
