@@ -25,21 +25,16 @@ implicit none
 integer, intent(in) :: stype
 real(8), intent(in) :: x
 ! external functions
-real(8) stheta_mp,stheta_fd,stheta_sq,stheta_lr
-external stheta_mp,stheta_fd,stheta_sq,stheta_lr
+real(8), external :: stheta_mp,stheta_fd,stheta_sq,stheta_lr
 select case(stype)
 case(0)
   stheta=stheta_mp(0,x)
-  return
 case(1)
   stheta=stheta_mp(1,x)
-  return
 case(2)
   stheta=stheta_mp(2,x)
-  return
 case(3)
   stheta=stheta_fd(x)
-  return
 case(4)
   stheta=stheta_sq(x)
 case(5)
