@@ -22,13 +22,11 @@ implicit none
 real(8), intent(in) :: x
 if (x.gt.50.d0) then
   stheta_fd=1.d0
-  return
-end if
-if (x.lt.-50.d0) then
+else if (x.lt.-50.d0) then
   stheta_fd=0.d0
-  return
+else
+  stheta_fd=1.d0/(1.d0+exp(-x))
 end if
-stheta_fd=1.d0/(1.d0+exp(-x))
 end function
 !EOC
 
