@@ -22,11 +22,13 @@ call checkfsm
 ! check if real symmetric first-variational eigen solver can be used
 if (.not.tsyminv) tefvr=.false.
 ! write to VARIABLES.OUT
-call writevars('nsymlat',iv=nsymlat)
-call writevars('symlat',nv=9*nsymlat,iva=symlat)
-call writevars('nsymcrys',iv=nsymcrys)
-call writevars('vtlsymc',nv=3*nsymcrys,rva=vtlsymc)
-call writevars('lsplsymc',nv=nsymcrys,iva=lsplsymc)
-call writevars('lspnsymc',nv=nsymcrys,iva=lspnsymc)
+if (wrtvars) then
+  call writevars('nsymlat',iv=nsymlat)
+  call writevars('symlat',nv=9*nsymlat,iva=symlat)
+  call writevars('nsymcrys',iv=nsymcrys)
+  call writevars('vtlsymc',nv=3*nsymcrys,rva=vtlsymc)
+  call writevars('lsplsymc',nv=nsymcrys,iva=lsplsymc)
+  call writevars('lspnsymc',nv=nsymcrys,iva=lspnsymc)
+end if
 end subroutine
 
