@@ -6,7 +6,7 @@
 !BOP
 ! !ROUTINE: symrf
 ! !INTERFACE:
-subroutine symrf(nr,nri,np,ld,rfmt,rfir)
+subroutine symrf(nr,nri,np,ngdg,ngt,ngv,igf,ld,rfmt,rfir)
 ! !USES:
 use modmain
 use modomp
@@ -14,6 +14,10 @@ use modomp
 !   nr   : number of radial points for each species (in,integer(nspecies))
 !   nri  : number of radial points on the inner part (in,integer(nspecies))
 !   np   : total number of points in each muffin-tin (in,integer(nspecies))
+!   ngdg : G-vector grid sizes (in,integer(3))
+!   ngt  : total number of G-vectors (in,integer)
+!   ngv  : number of G-vectors within cut-off (in,integer)
+!   igf  : map from G-vector index to FFT array (in,integer(ngv))
 !   ld   : leading dimension (in,integer)
 !   rfmt : real muffin-tin function (inout,real(ld,natmtot))
 !   rfir : real intersitial function (inout,real(ngtot))
@@ -33,8 +37,9 @@ use modomp
 implicit none
 ! arguments
 integer, intent(in) :: nr(nspecies),nri(nspecies),np(nspecies)
+integer, intent(in) :: ngdg(3),ngt,ngv,igf(ngv)
 integer, intent(in) :: ld
-real(8), intent(inout) :: rfmt(ld,natmtot),rfir(ngtot)
+real(8), intent(inout) :: rfmt(ld,natmtot),rfir(ngt)
 ! local variables
 integer nthd
 call holdthd(2,nthd)
@@ -43,10 +48,9 @@ call holdthd(2,nthd)
 !$OMP SECTION
 call symrfmt(nr,nri,np,ld,rfmt)
 !$OMP SECTION
-call symrfir(rfir)
+call symrfir(ngdg,ngt,ngv,igf,rfir)
 !$OMP END PARALLEL SECTIONS
 call freethd(nthd)
-return
 end subroutine
 !EOC
 
