@@ -6,7 +6,7 @@
 !BOP
 ! !ROUTINE: symrvf
 ! !INTERFACE:
-subroutine symrvf(tspin,tnc,nr,nri,np,ld,rvfmt,rvfir)
+subroutine symrvf(tspin,tnc,nr,nri,np,ngdg,ngt,ngv,igf,ld1,rvfmt,ld2,rvfir)
 ! !USES:
 use modmain
 use modomp
@@ -17,9 +17,14 @@ use modomp
 !   nr    : number of radial points for each species (in,integer(nspecies))
 !   nri   : number of radial points on the inner part (in,integer(nspecies))
 !   np    : total number of points in each muffin-tin (in,integer(nspecies))
-!   ld    : leading dimension (in,integer)
-!   rvfmt : real muffin-tin vector field (in,real(ld,natmtot,*))
-!   rvfir : real interstitial vector field (in,real(ngtot,*))
+!   ngdg  : G-vector grid sizes (in,integer(3))
+!   ngt   : total number of G-vectors (in,integer)
+!   ngv   : number of G-vectors within cut-off (in,integer)
+!   igf   : map from G-vector index to FFT array (in,integer(ngv))
+!   ld1   : leading dimension (in,integer)
+!   rvfmt : real muffin-tin vector field (in,real(ld1,natmtot,*))
+!   ld2   : leading dimension (in,integer)
+!   rvfir : real interstitial vector field (in,real(ld2,*))
 ! !DESCRIPTION:
 !   Symmetrises a vector field defined over the entire unit cell using the full
 !   set of crystal symmetries. If a particular symmetry involves rotating atom
@@ -41,20 +46,22 @@ implicit none
 ! arguments
 logical, intent(in) :: tspin,tnc
 integer, intent(in) :: nr(nspecies),nri(nspecies),np(nspecies)
-integer, intent(in) :: ld
-real(8), intent(inout) :: rvfmt(ld,natmtot,*),rvfir(ngtot,*)
+integer, intent(in) :: ngdg(3),ngt,ngv,igf(ngv)
+integer, intent(in) :: ld1
+real(8), intent(inout) :: rvfmt(ld1,natmtot,*)
+integer, intent(in) :: ld2
+real(8), intent(inout) :: rvfir(ld2,*)
 ! local variables
 integer nthd
 call holdthd(2,nthd)
 !$OMP PARALLEL SECTIONS DEFAULT(SHARED) &
 !$OMP NUM_THREADS(nthd)
 !$OMP SECTION
-call symrvfmt(tspin,tnc,nr,nri,np,ld,rvfmt)
+call symrvfmt(tspin,tnc,nr,nri,np,ld1,rvfmt)
 !$OMP SECTION
-call symrvfir(tspin,tnc,rvfir)
+call symrvfir(tspin,tnc,ngdg,ngt,ngv,igf,ld2,rvfir)
 !$OMP END PARALLEL SECTIONS
 call freethd(nthd)
-return
 end subroutine
 !EOC
 
