@@ -7,6 +7,7 @@ subroutine tdbackup
 use modmain
 use modtddft
 use modmpi
+use modramdisk
 implicit none
 ! local variables
 integer ik
@@ -14,6 +15,9 @@ integer ik
 complex(8), allocatable :: evecsvt(:,:)
 if (ntsbackup.le.0) return
 if (mod(itimes-1,ntsbackup).ne.0) return
+! ensure eigenvectors are written to disk
+wrtdsk0=wrtdsk
+wrtdsk=.true.
 allocate(evecsvt(nstsv,nstsv))
 do ik=1,nkpt
 ! distribute among MPI processes
@@ -30,6 +34,7 @@ if (mp_mpi) then
   write(50,'(I8,G18.10)') itimes,times(itimes)
   close(50)
 end if
+wrtdsk=wrtdsk0
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
 end subroutine
