@@ -14,8 +14,8 @@ implicit none
 logical tq0
 integer, parameter :: maxit=500
 integer iq,ik,isym
-integer nm,i,j,l,n
-integer iw,it,nthd
+integer nm,it,i,j,n
+integer iw,ioc,nthd
 real(8) v(3),t1,t2
 complex(8) vfxcp,z1
 character(256) fname
@@ -174,9 +174,9 @@ do iw=1,nwrf
 end do
 ! write G = G' = 0 components to file
 if (mp_mpi) then
-  do l=1,noptcomp
-    i=optcomp(1,l)
-    j=optcomp(2,l)
+  do ioc=1,noptcomp
+    i=optcomp(1,ioc)
+    j=optcomp(2,ioc)
     write(fname,'("EPSILON_TDDFT_",2I1,".OUT")') i,j
     open(50,file=trim(fname),form='FORMATTED')
     write(fname,'("EPSINV_TDDFT_",2I1,".OUT")') i,j
@@ -203,9 +203,9 @@ if (mp_mpi.and.tq0) then
     call zminv(3,epsm(:,:,iw))
   end do
 ! write out the macroscopic components
-  do l=1,noptcomp
-    i=optcomp(1,l)
-    j=optcomp(2,l)
+  do ioc=1,noptcomp
+    i=optcomp(1,ioc)
+    j=optcomp(2,ioc)
     write(fname,'("EPSM_TDDFT_",2I1,".OUT")') i,j
     open(50,file=trim(fname),form='FORMATTED')
     do iw=2,nwrf
@@ -274,8 +274,8 @@ if (mp_mpi) then
     write(*,'(" Macroscopic part written to EPSM_TDDFT_ij.OUT")')
   end if
   write(*,'(" for components")')
-  do l=1,noptcomp
-    write(*,'("  i = ",I1,", j = ",I1)') optcomp(1:2,l)
+  do ioc=1,noptcomp
+    write(*,'("  i = ",I1,", j = ",I1)') optcomp(1:2,ioc)
   end do
   write(*,'(" q-vector (lattice coordinates) : ")')
   write(*,'(3G18.10)') vecql
