@@ -3,15 +3,13 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine tdrestart(itimes0)
+subroutine tdrestart
 use modmain
 use modtddft
 use moddftu
 implicit none
-! arguments
-integer, intent(out) :: itimes0
 ! last time step for which the eigenvectors were written to file
-call readtimes(itimes0)
+call readtimes
 ! generate the density and magnetisation
 call rhomag
 ! compute the time-dependent Kohn-Sham potentials and magnetic fields
