@@ -8,9 +8,7 @@ use modmain
 implicit none
 ! arguments
 logical, intent(in) :: tsh
-integer, intent(in) :: lrstp
-integer, intent(in) :: is,ia
-integer, intent(in) :: ist
+integer, intent(in) :: lrstp,is,ia,ist
 ! pass in m-1/2
 integer, intent(in) :: m
 integer, intent(in) :: ld
@@ -47,12 +45,12 @@ else
   c2=-t1
 end if
 if (abs(m).le.l) then
-  lm1=idxlm(l,m)
+  lm1=l*(l+1)+m+1
 else
   lm1=0
 end if
 if (abs(m+1).le.l) then
-  lm2=idxlm(l,m+1)
+  lm2=l*(l+1)+m+2
 else
   lm2=0
 end if
@@ -139,6 +137,5 @@ do ir=nri+lrstp,nr,lrstp
     i=i+lmmaxo
   end if
 end do
-return
 end subroutine
 
