@@ -12,8 +12,7 @@ implicit none
 integer ik,ist
 real(8) x,t1
 ! external functions
-real(8) sdelta
-external sdelta
+real(8), external :: sdelta
 ! initialise universal variables
 call init0
 call init1
@@ -62,10 +61,8 @@ else
     end do
   end do
 end if
-! core density should not be added
-rhocr(:,:,:)=0.d0
-! compute the charge density with the new occupancies
-call rhomag
+! compute the valence charge density with the new occupancies
+call rhomagv
 ! write the wavefunction modulus squared plot to file
 if (mp_mpi) then
   select case(task)
@@ -105,6 +102,5 @@ if (mp_mpi) then
     write(*,'(" for k-point ",I8," and state ",I6)') kstlist(1,1),kstlist(2,1)
   end if
 end if
-return
 end subroutine
 
