@@ -9,7 +9,8 @@ use modbog
 implicit none
 ! local variables
 integer ik,ist
-! write out the valence eigenvalues
+real(8) e
+! write out the fermionic eigenvalues
 open(50,file='EIGVALUV.OUT',form='FORMATTED',action='WRITE')
 write(50,'(I6," : nkpt")') nkpt
 write(50,'(I6," : nstsv")') nstsv
@@ -18,7 +19,9 @@ do ik=1,nkpt
   write(50,'(I6,3G18.10," : k-point, vkl")') ik,vkl(:,ik)
   write(50,'(" (state, eigenvalue, V-norm below)")')
   do ist=1,nstsv
-    write(50,'(I6,3G18.10)') ist,evaluv(ist,ik),vnorm(ist,ik)
+    e=evaluv(ist,ik)
+    if (vnorm(ist,ik).gt.0.5d0) e=-e
+    write(50,'(I6,2G18.10)') ist,e,vnorm(ist,ik)
   end do
   write(50,*)
 end do
