@@ -32,8 +32,7 @@ call genlofr
 allocate(jlgqr(njcmax,nspecies))
 allocate(ylmgq(lmmaxo),sfacgq(natmtot))
 allocate(expmt(npcmtmax,natmtot))
-ngrf=1
-call gengqrf(vecqc,vgqc,gqc,jlgqr,ylmgq,sfacgq)
+call gengqf(1,vecqc,vgqc,gqc,jlgqr,ylmgq,sfacgq)
 call genexpmt(1,jlgqr,ylmgq,1,sfacgq,expmt)
 expmt(:,:)=omega*expmt(:,:)
 deallocate(jlgqr,ylmgq,sfacgq)
@@ -74,7 +73,7 @@ do jk=1,nk
   call genexpmat(vkl(:,ik),expmt,emat)
   do i=1,nstsv
     write(50,*)
-    write(50,'(I6," : state i; state j, <...>, |<...>|^2 below")') i
+    write(50,'(I6," : state i; state j, <...>, |<...>|² below")') i
     do j=1,nstsv
       a=dble(emat(i,j))
       b=aimag(emat(i,j))
@@ -90,6 +89,5 @@ write(*,'(" < i,k+q | exp(iq.r) | j,k > matrix elements written to &
  &EXPIQR.OUT")')
 write(*,'(" for the q-vector in vecql and all k-points in kstlist")')
 deallocate(expmt,emat)
-return
 end subroutine
 
