@@ -20,10 +20,6 @@ write(fnum,'("Number of Matsubara frequencies : ",I6)') nwgw
 write(fnum,*)
 write(fnum,'("Maximum |G| for response function : ",G18.10)') gmaxrf
 write(fnum,'("Number of response-function G-vectors : ",I8)') ngrf
-write(fnum,*)
-write(fnum,'("Step size for inverting the Kohn-Sham equations : ",G18.10)') &
- tauksi
 flush(fnum)
-return
 end subroutine
 
