@@ -28,7 +28,7 @@ implicit none
 ! arguments
 integer fnum
 ! local variables
-integer i,is,ia,k,l
+integer is,ia,k,l,i
 character(10) dat,tim
 write(fnum,'("+----------------------------+")')
 write(fnum,'("| Elk version ",I1.1,".",I1.1,".",I2.2," started |")') version
@@ -308,9 +308,6 @@ if (dftu.ne.0) then
   else if (dftu.eq.2) then
     write(fnum,'(" around mean field (AMF)")')
     write(fnum,'(" see Phys. Rev. B 49, 14211 (1994)")')
-  else if (dftu.eq.3) then
-    write(fnum,'(" interpolation between FLL and AMF")')
-    write(fnum,'(" see Phys. Rev. B 67, 153106 (2003)")')
   else
     write(*,*)
     write(*,'("Error(writeinfo): dftu not defined : ",I8)') dftu
@@ -318,8 +315,8 @@ if (dftu.ne.0) then
     stop
   end if
   do i=1,ndftu
-    is=idftu(1,i)
-    l=idftu(2,i)
+    is=isldu(1,i)
+    l=isldu(2,i)
     if (inpdftu.eq.1) then
       write(fnum,'(" species : ",I4," (",A,")",", l = ",I2,", U = ",F12.8, &
        &", J = ",F12.8)') is,trim(spsymb(is)),l,ujdu(1,i),ujdu(2,i)
@@ -342,8 +339,8 @@ if (dftu.ne.0) then
        trim(spsymb(is)),l
       write(fnum,'(" Slater integrals are calculated by means of Yukawa &
        &potential")')
-      write(fnum,'(" Yukawa potential screening length (a.u^-1) : ",F12.8)') &
-       lambdadu(i)
+      write(fnum,'(" Yukawa potential screening length (a.u.⁻¹) : ",F12.8)') &
+       lamdu(i)
     else if(inpdftu.eq.5) then
       write(fnum,'(" species : ",I4," (",A,")",", l = ",I2)') is, &
        trim(spsymb(is)),l
