@@ -41,7 +41,7 @@ if (task.eq.15) then
 ! generate the density matrix in each muffin-tin
   call gendmat(.false.,.false.,0,lmaxo,lmmaxo,dmat)
   if (mp_mpi) then
-    open(50,file='LSJ.OUT',form='FORMATTED')
+    open(50,file='LSJ.OUT',form='FORMATTED',action='WRITE')
     write(50,*)
     write(50,'("Expectation values are computed only over the muffin-tin")')
 ! loop over species and atoms
@@ -72,7 +72,7 @@ if (task.eq.15) then
 else
 ! compute L, S and J for all states in kstlist
   if (mp_mpi) then
-    open(50,file='LSJ_KST.OUT',form='FORMATTED')
+    open(50,file='LSJ_KST.OUT',form='FORMATTED',action='WRITE')
     write(50,*)
     write(50,'("Expectation values are computed only over the muffin-tin")')
   end if
@@ -132,6 +132,5 @@ else
    tol=1.d-3,rva=xj)
 end if
 deallocate(xj,dmat)
-return
 end subroutine
 
