@@ -6,6 +6,7 @@
 subroutine writestress
 use modmain
 use modmpi
+use modtest
 implicit none
 ! local variables
 integer i,j,k
@@ -17,7 +18,7 @@ trdstate=.false.
 call genstress
 ! write the stress tensors to file
 if (mp_mpi) then
-  open(50,file='STRESS.OUT',form='FORMATTED')
+  open(50,file='STRESS.OUT',form='FORMATTED',action='WRITE')
   write(50,*)
   write(50,'("Lattice vector matrix, A, changed by")')
   write(50,*)
@@ -39,6 +40,7 @@ if (mp_mpi) then
   write(*,'("Info(writestress):")')
   write(*,'(" Stress tensor components written to STRESS.OUT")')
 end if
-return
+! write test file if required
+call writetest(440,'Stress tensor components',nv=nstrain,tol=1.d-2,rva=stress)
 end subroutine
 
