@@ -215,15 +215,7 @@ if (tdjr3d) then
 end if
 ! calculate and write tensor moments
 if (dftu.ne.0) then
-  if (tmwrite) then
-    open(50,file='TMDFTU'//trim(fext),form='FORMATTED',action='WRITE')
-    if (spinorb) then
-      call writetm3du(50)
-    else
-      call writetm2du(50)
-    end if
-    close(50)
-  end if
+  if (tmwrite) call writetm3td
 end if
 ! write time-dependent DOS
 if (tddos) then
