@@ -39,13 +39,12 @@ integer i
 real(8), parameter :: pi=3.1415926535897932385d0
 real(8), parameter :: thrd=1.d0/3.d0, thrd4=4.d0/3.d0
 real(8), parameter :: d2f0=1.709921d0
-real(8) a(3),a1(3),b1(3),b2(3),b3(3),b4(3)
-data a  / 0.0310907d0, 0.01554535d0, 0.0168869d0 /
-data a1 / 0.21370d0,   0.20548d0,    0.11125d0   /
-data b1 / 7.5957d0,   14.1189d0,    10.357d0     /
-data b2 / 3.5876d0,    6.1977d0,     3.6231d0    /
-data b3 / 1.6382d0,    3.3662d0,     0.88026d0   /
-data b4 / 0.49294d0,   0.62517d0,    0.49671d0   /
+real(8), parameter ::  a(3)=[ 0.0310907d0, 0.01554535d0, 0.0168869d0 ]
+real(8), parameter :: a1(3)=[ 0.21370d0,   0.20548d0,    0.11125d0   ]
+real(8), parameter :: b1(3)=[ 7.5957d0,   14.1189d0,    10.357d0     ]
+real(8), parameter :: b2(3)=[ 3.5876d0,    6.1977d0,     3.6231d0    ]
+real(8), parameter :: b3(3)=[ 1.6382d0,    3.3662d0,     0.88026d0   ]
+real(8), parameter :: b4(3)=[ 0.49294d0,   0.62517d0,    0.49671d0   ]
 real(8) p1,p2,p3,rup,rdn,r,ri,ri2
 real(8) rs,rs2,rs12,rs32,rsi,rs12i
 real(8) mz,z,z3,z4,drs,dzu,dzd
@@ -183,7 +182,6 @@ do i=1,n
   vcup(i)=ec(i)+r*deu
   vcdn(i)=ec(i)+r*ded
 end do
-return
 end subroutine
 !EOC
 
