@@ -15,12 +15,6 @@ real(8), parameter :: pi=3.1415926535897932385d0
 real(8), parameter :: thrd=1.d0/3.d0
 ! default PBE beta
 real(8), parameter :: beta=0.06672455060314922d0
-! maximum allowed |grad rho|
-real(8), parameter :: gmax=1.d6
-! maximum allowed grad^2 rho
-real(8), parameter :: g2max=1.d12
-! maximum allowed (grad rho).(grad |grad rho|)
-real(8), parameter :: g3max=1.d14
 real(8) r,grho_,g2rho_,g3rho_
 real(8) kf,s,u,v,rs,z,g
 real(8) ks,ksg,t,uu,vv,ww
@@ -30,10 +24,6 @@ do i=1,n
     grho_=grho(i)
     g2rho_=g2rho(i)
     g3rho_=g3rho(i)
-! check gradients are within range
-    if (grho_.gt.gmax) grho_=gmax
-    if (abs(g2rho_).gt.g2max) g2rho_=sign(g2max,g2rho_)
-    if (abs(g3rho_).gt.g3max) g3rho_=sign(g3max,g3rho_)
     kf=(r*3.d0*pi**2)**thrd
     s=grho_/(2.d0*kf*r)
     u=g3rho_/((r**2)*(2.d0*kf)**3)
@@ -58,6 +48,5 @@ do i=1,n
     vc(i)=0.d0
   end if
 end do
-return
 end subroutine
 
