@@ -35,16 +35,13 @@ implicit none
 complex(8), intent(in) :: zfmt1(npcmtmax,natmtot),zfir1(ngtc)
 complex(8), intent(in) :: zfmt2(npcmtmax,natmtot),zfir2(ngtc)
 ! local variables
-integer is,ias,ir,nthd
+integer is,ias,nthd
 ! external functions
-complex(8) zfmtinp
-external zfmtinp
-! interstitial contribution
-zfinp=0.d0
-do ir=1,ngtc
-  zfinp=zfinp+cfrc(ir)*conjg(zfir1(ir))*zfir2(ir)
-end do
-zfinp=zfinp*(omega/dble(ngtc))
+complex(8), external :: zdotc,zfmtinp
+! interstitial contribution (requires that one of the functions has been
+! multiplied by the characteristic function)
+zfinp=zdotc(ngtc,zfir1,1,zfir2,1)
+zfinp=zfinp*omega/dble(ngtc)
 ! muffin-tin contribution
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
@@ -57,7 +54,6 @@ do ias=1,natmtot
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
-return
 end function
 !EOC
 
