@@ -11,11 +11,9 @@ implicit none
 complex(8), intent(inout) :: zfmt(npmtmax,natmtot)
 ! local variables
 integer is,ias,lm
-integer nr,nri,nro
-integer iro,ir,npi
-integer nrc,nrci,nrco
-integer irco,irc,npci
-integer i,nthd
+integer nr,nri,nro,iro
+integer nrc,nrci,nrco,irco
+integer i0,i1,nthd
 ! automatic arrays
 real(8) fi1(nrcmtmax),fi2(nrcmtmax)
 real(8) fo1(nrmtmax),fo2(nrmtmax)
@@ -23,10 +21,10 @@ complex(8) zfmt1(npcmtmax)
 if (lradstp.eq.1) return
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
-!$OMP PRIVATE(zfmt1,fi1,fi2,fo1,fo2) &
-!$OMP PRIVATE(is,nr,nri,nro,iro,npi) &
-!$OMP PRIVATE(nrc,nrci,nrco,irco,npci) &
-!$OMP PRIVATE(lm,i,irc,ir) &
+!$OMP PRIVATE(zfmt1,fi1,fi2,fo1,fo2,is) &
+!$OMP PRIVATE(nr,nri,nro,iro) &
+!$OMP PRIVATE(nrc,nrci,nrco,irco) &
+!$OMP PRIVATE(lm,i0,i1) &
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
@@ -34,53 +32,42 @@ do ias=1,natmtot
   nri=nrmti(is)
   nro=nr-nri
   iro=nri+1
-  npi=npmti(is)
   nrc=nrcmt(is)
   nrci=nrcmti(is)
   nrco=nrc-nrci
   irco=nrci+1
-  npci=npcmti(is)
 ! copy the input function
-  call zcopy(npcmt(is),zfmt(:,ias),1,zfmt1,1)
+  zfmt1(1:npcmt(is))=zfmt(1:npcmt(is),ias)
 ! interpolate up to lmaxi over entire muffin-tin
   do lm=1,lmmaxi
-    i=lm
-    do irc=1,nrci
-      fi1(irc)=dble(zfmt1(i)); fi2(irc)=aimag(zfmt1(i))
-      i=i+lmmaxi
-    end do
-    do irc=irco,nrc
-      fi1(irc)=dble(zfmt1(i)); fi2(irc)=aimag(zfmt1(i))
-      i=i+lmmaxo
-    end do
+    i1=lmmaxi*(nrci-1)+lm
+    fi1(1:nrci)=dble(zfmt1(lm:i1:lmmaxi))
+    fi2(1:nrci)=aimag(zfmt1(lm:i1:lmmaxi))
+    i0=i1+lmmaxi
+    i1=lmmaxo*(nrc-irco)+i0
+    fi1(irco:nrc)=dble(zfmt1(i0:i1:lmmaxo))
+    fi2(irco:nrc)=aimag(zfmt1(i0:i1:lmmaxo))
     call rfinterp(nrc,rcmt(:,is),wcrcmt(:,:,is),fi1,nr,rlmt(:,1,is),fo1)
     call rfinterp(nrc,rcmt(:,is),wcrcmt(:,:,is),fi2,nr,rlmt(:,1,is),fo2)
-    i=lm
-    do ir=1,nri
-      zfmt(i,ias)=cmplx(fo1(ir),fo2(ir),8)
-      i=i+lmmaxi
-    end do
-    do ir=iro,nr
-      zfmt(i,ias)=cmplx(fo1(ir),fo2(ir),8)
-      i=i+lmmaxo
-    end do
+    i1=lmmaxi*(nri-1)+lm
+    zfmt(lm:i1:lmmaxi,ias)=cmplx(fo1(1:nri),fo2(1:nri),8)
+    i0=i1+lmmaxi
+    i1=lmmaxo*(nr-iro)+i0
+    zfmt(i0:i1:lmmaxo,ias)=cmplx(fo1(iro:nr),fo2(iro:nr),8)
   end do
 ! interpolate up to lmaxo on outer part of muffin-tin
   do lm=lmmaxi+1,lmmaxo
-    i=npci+lm
-    do irc=irco,nrc
-      fi1(irc)=dble(zfmt1(i)); fi2(irc)=aimag(zfmt1(i))
-      i=i+lmmaxo
-    end do
+    i0=lmmaxi*nrci+lm
+    i1=lmmaxo*(nrc-irco)+i0
+    fi1(irco:nrc)=dble(zfmt1(i0:i1:lmmaxo))
+    fi2(irco:nrc)=aimag(zfmt1(i0:i1:lmmaxo))
     call rfinterp(nrco,rcmt(irco,is),wcrcmt(:,irco,is),fi1(irco),nro, &
      rsp(iro,is),fo1(iro))
     call rfinterp(nrco,rcmt(irco,is),wcrcmt(:,irco,is),fi2(irco),nro, &
      rsp(iro,is),fo2(iro))
-    i=npi+lm
-    do ir=iro,nr
-      zfmt(i,ias)=cmplx(fo1(ir),fo2(ir),8)
-      i=i+lmmaxo
-    end do
+    i0=lmmaxi*nri+lm
+    i1=lmmaxo*(nr-iro)+i0
+    zfmt(i0:i1:lmmaxo,ias)=cmplx(fo1(iro:nr),fo2(iro:nr),8)
   end do
 end do
 !$OMP END PARALLEL DO
