@@ -6,7 +6,7 @@
 !BOP
 ! !ROUTINE: zfmtinp
 ! !INTERFACE:
-complex(8) function zfmtinp(nr,nri,wr,zfmt1,zfmt2)
+pure complex(8) function zfmtinp(nr,nri,wr,zfmt1,zfmt2)
 ! !USES:
 use modmain
 ! !INPUT/OUTPUT PARAMETERS:
@@ -37,29 +37,30 @@ integer, intent(in) :: nr,nri
 real(8), intent(in) :: wr(nr)
 complex(8), intent(in) :: zfmt1(*),zfmt2(*)
 ! local variables
-integer ir,i
-! external functions
-complex(8), external :: zdotc
+integer n,ir,i
 ! compute the dot-products for each radial point and integrate over r
 zfmtinp=0.d0
-i=1
 if (lmaxi.eq.1) then
   do ir=1,nri
+    i=4*(ir-1)+1
     zfmtinp=zfmtinp+wr(ir) &
      *(conjg(zfmt1(i))*zfmt2(i) &
       +conjg(zfmt1(i+1))*zfmt2(i+1) &
       +conjg(zfmt1(i+2))*zfmt2(i+2) &
       +conjg(zfmt1(i+3))*zfmt2(i+3))
-    i=i+4
   end do
+  i=4*nri+1
 else
+  i=1
+  n=lmmaxi-1
   do ir=1,nri
-    zfmtinp=zfmtinp+wr(ir)*zdotc(lmmaxi,zfmt1(i),1,zfmt2(i),1)
+    zfmtinp=zfmtinp+wr(ir)*dot_product(zfmt1(i:i+n),zfmt2(i:i+n))
     i=i+lmmaxi
   end do
 end if
+n=lmmaxo-1
 do ir=nri+1,nr
-  zfmtinp=zfmtinp+wr(ir)*zdotc(lmmaxo,zfmt1(i),1,zfmt2(i),1)
+  zfmtinp=zfmtinp+wr(ir)*dot_product(zfmt1(i:i+n),zfmt2(i:i+n))
   i=i+lmmaxo
 end do
 end function
