@@ -11,17 +11,13 @@ integer, intent(in) :: nr,nri
 real(8), intent(in) :: wr(nr)
 complex(8), intent(in) :: zfmt(*)
 ! local variables
-integer ir,i
-zfmtint=0.d0
-i=1
-do ir=1,nri
-  zfmtint=zfmtint+wr(ir)*zfmt(i)
-  i=i+lmmaxi
-end do
-do ir=nri+1,nr
-  zfmtint=zfmtint+wr(ir)*zfmt(i)
-  i=i+lmmaxo
-end do
+integer iro,i0,i1
+i1=lmmaxi*(nri-1)+1
+zfmtint=sum(wr(1:nri)*zfmt(1:i1:lmmaxi))
+iro=nri+1
+i0=i1+lmmaxi
+i1=lmmaxo*(nr-iro)+i0
+zfmtint=zfmtint+sum(wr(iro:nr)*zfmt(i0:i1:lmmaxo))
 zfmtint=fourpi*y00*zfmtint
 end function
 
