@@ -3,7 +3,7 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-complex(8) function zfpole(c,z)
+pure complex(8) function zfpole(c,z)
 use modgw
 implicit none
 ! arguments
@@ -20,6 +20,5 @@ do j=1,npole
   if (t1.gt.1.d-8) zfpole=zfpole+c(i+1)/z1
   i=i+2
 end do
-return
 end function
 
