@@ -107,7 +107,7 @@ do ig=1,ngtot
       z1=fourpi*zfft(ifg)*cmplx(cos(t1),sin(t1),8)
       lm=0
       do l=0,lmaxi
-        z2=z1*zil(l)
+        z2=z1*zil(mod(l,4))
         do m=-l,l
           lm=lm+1
           z3=z2*ylm(lm)
@@ -120,7 +120,7 @@ do ig=1,ngtot
       end do
       lm=0
       do l=0,lmaxo
-        z2=z1*zil(l)
+        z2=z1*zil(mod(l,4))
         do m=-l,l
           lm=lm+1
           z3=z2*ylm(lm)
@@ -169,7 +169,7 @@ do ip=1,npv
             i=i+1
             z2=z2+zfmt(i,ias)*ylm(lm)
           end do
-          z1=z1+jl(l,irc)*zilc(l)*z2
+          z1=z1+jl(l,irc)*zilc(mod(l,4))*z2
         end do
         zsm=zsm+wrcmt(irc,is)*z1
         if (irc.eq.nrci) lmax=lmaxo
