@@ -17,9 +17,9 @@ complex(8), intent(out) :: zfgp(ngp)
 ! local variables
 integer is,ia,ias,ig
 integer nrc,nrci,irco,irc
-integer l,m,lm,i,j
+integer l,lm,n,i,j
 real(8) t0,y0
-complex(8) zsm,z1,z2
+complex(8) zsm,z1
 ! automatic arrays
 complex(8) ylm(lmmaxo),zfft(ngtc)
 !-----------------------------------!
@@ -36,11 +36,9 @@ zfgp(1:ngp)=zfft(igfc(1:ngp))
 t0=fourpi/omega
 y0=t0*y00
 do ig=1,ngp
-  lm=1
   do l=1,lmaxo
-    z1=t0*zilc(l)
-    do m=-l,l
-      lm=lm+1
+    z1=t0*zilc(mod(l,4))
+    do lm=l**2+1,(l+1)**2
       ylm(lm)=z1*ylmgp(lm,ig)
     end do
   end do
@@ -53,7 +51,7 @@ do ig=1,ngp
       zsm=0.d0
       i=1
       j=1
-! inner part of muffin-tin
+! inner part of muffin-tin, note that lmaxi >= 1
       if (lmaxi.eq.1) then
         do irc=1,nrci
           zsm=zsm+wrcmt(irc,is)*(jlgpr(j,is,ig)*zfmt(i,ias)*y0+jlgpr(j+1,is,ig)&
@@ -63,41 +61,38 @@ do ig=1,ngp
         end do
       else
         do irc=1,nrci
-          z1=jlgpr(j,is,ig)*zfmt(i,ias)*y0
-          i=i+1
-          j=j+1
-          lm=1
-          do l=1,lmaxi
-            lm=lm+1
-            z2=zfmt(i,ias)*ylm(lm)
-            i=i+1
-            do m=1-l,l
-              lm=lm+1
-              z2=z2+zfmt(i,ias)*ylm(lm)
-              i=i+1
-            end do
-            z1=z1+jlgpr(j,is,ig)*z2
+          z1=jlgpr(j,is,ig)*zfmt(i,ias)*y0+jlgpr(j+1,is,ig) &
+           *(zfmt(i+1,ias)*ylm(2)+zfmt(i+2,ias)*ylm(3)+zfmt(i+3,ias)*ylm(4))
+          i=i+4
+          j=j+2
+          do l=2,lmaxi
+            n=2*l
+            lm=l**2+1
+            z1=z1+jlgpr(j,is,ig)*sum(zfmt(i:i+n,ias)*ylm(lm:lm+n))
+            i=i+n+1
             j=j+1
           end do
           zsm=zsm+wrcmt(irc,is)*z1
         end do
       end if
-! outer part of muffin-tin
+! outer part of muffin-tin, note that lmaxo >= 3
       do irc=irco,nrc
-        z1=jlgpr(j,is,ig)*zfmt(i,ias)*y0
-        i=i+1
-        j=j+1
-        lm=1
-        do l=1,lmaxo
-          lm=lm+1
-          z2=zfmt(i,ias)*ylm(lm)
-          i=i+1
-          do m=1-l,l
-            lm=lm+1
-            z2=z2+zfmt(i,ias)*ylm(lm)
-            i=i+1
-          end do
-          z1=z1+jlgpr(j,is,ig)*z2
+        z1=jlgpr(j,is,ig)*zfmt(i,ias)*y0+jlgpr(j+1,is,ig) &
+         *(zfmt(i+1,ias)*ylm(2)+zfmt(i+2,ias)*ylm(3)+zfmt(i+3,ias)*ylm(4)) &
+         +jlgpr(j+2,is,ig) &
+         *(zfmt(i+4,ias)*ylm(5)+zfmt(i+5,ias)*ylm(6)+zfmt(i+6,ias)*ylm(7) &
+          +zfmt(i+7,ias)*ylm(8)+zfmt(i+8,ias)*ylm(9)) &
+         +jlgpr(j+3,is,ig) &
+         *(zfmt(i+9,ias)*ylm(10)+zfmt(i+10,ias)*ylm(11)+zfmt(i+11,ias)*ylm(12) &
+          +zfmt(i+12,ias)*ylm(13)+zfmt(i+13,ias)*ylm(14)+zfmt(i+14,ias)*ylm(15)&
+          +zfmt(i+15,ias)*ylm(16))
+        i=i+16
+        j=j+4
+        do l=4,lmaxo
+          n=2*l
+          lm=l**2+1
+          z1=z1+jlgpr(j,is,ig)*sum(zfmt(i:i+n,ias)*ylm(lm:lm+n))
+          i=i+n+1
           j=j+1
         end do
         zsm=zsm+wrcmt(irc,is)*z1
