@@ -17,10 +17,10 @@ integer l2,i,j,nthd
 ! external functions
 real(8), external :: ddot
 complex(8), external :: zdotc
+l2=l*2
 call holdthd(n,nthd)
 if (tcr) then
 ! matrix c is real valued
-  l2=2*l
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(i) &
 !$OMP NUM_THREADS(nthd)
@@ -36,9 +36,10 @@ else
 !$OMP PRIVATE(i) &
 !$OMP NUM_THREADS(nthd)
   do j=1,n
-    do i=1,j
+    do i=1,j-1
       c(i,j)=c(i,j)+zdotc(l,a(:,i),1,b(:,j),1)
     end do
+    c(j,j)=c(j,j)+ddot(l2,a(:,j),1,b(:,j),1)
   end do
 !$OMP END PARALLEL DO
 end if
