@@ -10,13 +10,13 @@ implicit none
 integer, intent(in) :: n
 complex(8), intent(inout) :: a(n,n)
 ! local variables
-integer info,nthd
+integer info,nthd,nts
 ! automatic arrays
 integer ipiv(n)
 complex(8) work(n)
 ! enable MKL parallelism
 call holdthd(maxthdmkl,nthd)
-call mkl_set_num_threads(nthd)
+nts=mkl_set_num_threads_local(nthd)
 call zgetrf(n,n,a,n,ipiv,info)
 if (info.ne.0) then
   write(*,*)
@@ -33,8 +33,7 @@ if (info.ne.0) then
   write(*,*)
   stop
 end if
+nts=mkl_set_num_threads_local(0)
 call freethd(nthd)
-call mkl_set_num_threads(1)
-return
 end subroutine
 
